(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    973045,      19292]
NotebookOptionsPosition[    961398,      18917]
NotebookOutlinePosition[    961844,      18936]
CellTagsIndexPosition[    961801,      18933]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Frequency Difference Divider", "Title",
 CellChangeTimes->{{3.447176540308875*^9, 3.44717655098075*^9}}],

Cell["\<\
T0900138-v1
March 27, 2009
Daniel Sigg
\
\>", "Subsubtitle",
 CellChangeTimes->{
  3.4428679809275*^9, 3.446833023320875*^9, {3.4471765541995*^9, 
   3.447176573512*^9}, {3.44718802016825*^9, 3.447188020887*^9}}],

Cell[CellGroupData[{

Cell["Theory of Operations", "Subtitle"],

Cell[TextData[{
 "A frequency difference divider takes an input signal divides it down and \
adds it to a fixed frequency low noise reference. If the input signal \
experiences a high phase noise, the phase noise in the output signal is \
reduced by the divider ratio---assuming all other noise sources are \
negligible.",
 StyleBox["\n",
  FontFamily->"Times New Roman"]
}], "Text",
 CellChangeTimes->{{3.447176586012*^9, 3.447176720262*^9}, {
  3.4480244727608747`*^9, 3.4480244907921247`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Specifications", "Subtitle"],

Cell[TextData[{
 "TBD.",
 StyleBox["\n",
  FontFamily->"Times New Roman"]
}], "Text",
 CellChangeTimes->{{3.447176586012*^9, 3.447176720262*^9}, {3.447176765512*^9,
   3.447176766465125*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Needs", "[", "\"\<BarCharts`\>\"", "]"}], ";", 
  RowBox[{"Needs", "[", "\"\<Histograms`\>\"", "]"}], ";", 
  RowBox[{"Needs", "[", "\"\<PieCharts`\>\"", "]"}], ";", " ", 
  RowBox[{"Needs", "[", "\"\<ErrorBarPlots`\>\"", "]"}], ";", " ", 
  RowBox[{"Needs", "[", "\"\<PlotLegends`\>\"", "]"}], ";"}], "\n", 
 RowBox[{"Needs", "[", "\"\<Controls`LinearControl`\>\"", "]"}]}], "Input",
 CellChangeTimes->{{3.447186817308875*^9, 3.44718682460575*^9}, {
  3.448375377015625*^9, 3.4483753788125*^9}, {3.4483799034375*^9, 
  3.448379905703125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"$TextStyle", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
     RowBox[{"FontSize", "\[Rule]", "13"}]}], "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plotopt", "=", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"1", ",", "0", ",", "0"}], "]"}]}], "}"}], ",", "\n", 
      "\t\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0", ",", "0", ",", "1"}], "]"}]}], "}"}], ",", "\n", 
      "\t\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.1", ",", "0.7", ",", "0.2"}], "]"}]}], "}"}], ",", "\n", 
      "\t\t\t    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0.5", ",", "0.5", ",", "0.2"}], "]"}]}], "}"}]}], "}"}]}]}],
   ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Common Definitions", "Subtitle",
 CellChangeTimes->{{3.447176974183875*^9, 3.447176980652625*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FromdBc", "[", "x_", "]"}], ":=", " ", 
  SuperscriptBox["10", 
   RowBox[{
    RowBox[{"-", "x"}], "/", "20"}]]}]], "Input",
 CellChangeTimes->{{3.44717698429325*^9, 3.447177008996375*^9}, {
  3.447177168871375*^9, 3.447177169262*^9}, {3.448375416125*^9, 
  3.44837542875*^9}, {3.448380204390625*^9, 3.448380204875*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"NoiseLevelBottom", "[", "f_", "]"}], ":=", 
  RowBox[{"FromdBc", "[", "175", "]"}]}]], "Input",
 CellChangeTimes->{{3.447180482590125*^9, 3.447180488387*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Model", "Subtitle",
 CellChangeTimes->{{3.4471767958245*^9, 3.44717679679325*^9}}],

Cell[TextData[{
 "This model takes VCO (Synergy MCF91119-10) and sends it through a frequency \
difference divider. The VCO runs at 1.05 GHz and has a range of \
\[PlusMinus]125 MHz. The VCO signal is amplified first to 13dBm, then dvided \
by 8 to give a frequency of 131 MHz \[PlusMinus] 16 MHz. The target frequency \
is 80 MHz, so we can drive a standard acousto-optical modulator. The divided \
VCO signal is then sent to the frequency difference divider. The frequency \
difference divider will divide the signal by a further 16, amplifier it and \
send it to the RF input of a mixer. The LO input of the mixer is driven by \
the amplified output of a OCXO which runs at 71 MHz. The IF output of the \
mixer is sent through a filter to reject the lower image and then amplified \
to yield 13 dBm outputs at a nominal 80 MHz \[PlusMinus] 1 MHz. To lower the \
noise even further this output signal can be sent to a second frequency \
difference divider. This time the divider ratio is 10. This yields a nominal \
80 MHz \[PlusMinus] 0.1 MHz.\n\nThe result plot shows a comparison of the \
phase noise of the raw VCO, the VCO scaled to 80 MHz by direct division by \
13, the output of the first stage frequency difference divider and the output \
of the second stage frequency difference divider. As expected the scaled VCO \
phase noise is about 20 dB better than the raw VCO phase noise. The first \
stage output is another 20 dB lower and the output of the second stage \
reproduces the phase noise of the OCXO at lower frequencies. At higher \
frequencies beyond 20 kHz the noise level is about 12 dB higher due to the \
dividers, amplifiers and mixers.",
 StyleBox["\n",
  FontFamily->"Times New Roman"]
}], "Text",
 CellChangeTimes->{{3.447176586012*^9, 3.447176720262*^9}, {
  3.447186893308875*^9, 3.4471870025745*^9}, {3.447187050512*^9, 
  3.447187627715125*^9}, {3.447187701183875*^9, 3.447187744996375*^9}, {
  3.447187796746375*^9, 3.447187863465125*^9}, {3.4471879253245*^9, 
  3.447187965887*^9}}],

Cell[CellGroupData[{

Cell["Frequency Range", "Subsubtitle",
 CellChangeTimes->{{3.447186576652625*^9, 3.44718659091825*^9}, {
  3.447187881965125*^9, 3.447187883183875*^9}, {3.44837473065625*^9, 
  3.448374733171875*^9}}],

Cell["\<\
f0 : OCXO frequency
freq: Synergy MCF91119-10 frequency range
vcofreq[n]: VCO output frequency after n-th stage\
\>", "Text",
 CellChangeTimes->{{3.44837473728125*^9, 3.44837479821875*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"f0", "=", "71*^6"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"freq", "=", 
   RowBox[{"{", 
    RowBox[{"930*^6", ",", "1050*^6", ",", "1240*^6"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vcofreq", "[", "1", "]"}], ":=", 
  RowBox[{
   FractionBox["freq", 
    RowBox[{"8", " ", "16."}]], "+", "f0"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vcofreq", "[", "n_", "]"}], ":=", 
  RowBox[{
   FractionBox[
    RowBox[{"vcofreq", "[", 
     RowBox[{"n", "-", "1"}], "]"}], "10."], "+", 
   "f0"}]}], "\[IndentingNewLine]", 
 RowBox[{"freq", " ", "1*^-6"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vcofreq", "[", "1", "]"}], " ", "1*^-6"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vcofreq", "[", "2", "]"}], "1*^-6"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vcofreq", "[", "3", "]"}], "1*^-6"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vcofreq", "[", "100", "]"}], 
  "1*^-6"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.448373608609375*^9, 3.448373624359375*^9}, {
  3.44837372453125*^9, 3.44837408640625*^9}, {3.44837412103125*^9, 
  3.44837417884375*^9}, {3.4483743686875*^9, 3.448374371921875*^9}, {
  3.4483748271875*^9, 3.44837482796875*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"930", ",", "1050", ",", "1240"}], "}"}]], "Output",
 CellChangeTimes->{{3.448373834953125*^9, 3.44837385115625*^9}, 
   3.44837388271875*^9, {3.448373928078125*^9, 3.44837396921875*^9}, {
   3.44837400328125*^9, 3.448374086625*^9}, {3.44837412471875*^9, 
   3.4483741793125*^9}, {3.448374369625*^9, 3.448374378*^9}, 
   3.44837444103125*^9, 3.448374828984375*^9, 3.448374893265625*^9, 
   3.44837532196875*^9, 3.448375384296875*^9, 3.44837543784375*^9, {
   3.44837991390625*^9, 3.44837992665625*^9}, 3.44839879928125*^9, 
   3.44839885771875*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"78.265625`", ",", "79.203125`", ",", "80.6875`"}], "}"}]], "Output",\

 CellChangeTimes->{{3.448373834953125*^9, 3.44837385115625*^9}, 
   3.44837388271875*^9, {3.448373928078125*^9, 3.44837396921875*^9}, {
   3.44837400328125*^9, 3.448374086625*^9}, {3.44837412471875*^9, 
   3.4483741793125*^9}, {3.448374369625*^9, 3.448374378*^9}, 
   3.44837444103125*^9, 3.448374828984375*^9, 3.448374893265625*^9, 
   3.44837532196875*^9, 3.448375384296875*^9, 3.44837543784375*^9, {
   3.44837991390625*^9, 3.44837992665625*^9}, 3.44839879928125*^9, 
   3.448398857734375*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"78.8265625`", ",", "78.9203125`", ",", "79.06875`"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.448373834953125*^9, 3.44837385115625*^9}, 
   3.44837388271875*^9, {3.448373928078125*^9, 3.44837396921875*^9}, {
   3.44837400328125*^9, 3.448374086625*^9}, {3.44837412471875*^9, 
   3.4483741793125*^9}, {3.448374369625*^9, 3.448374378*^9}, 
   3.44837444103125*^9, 3.448374828984375*^9, 3.448374893265625*^9, 
   3.44837532196875*^9, 3.448375384296875*^9, 3.44837543784375*^9, {
   3.44837991390625*^9, 3.44837992665625*^9}, 3.44839879928125*^9, 
   3.448398857734375*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"78.88265625`", ",", "78.89203125`", ",", "78.906875`"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.448373834953125*^9, 3.44837385115625*^9}, 
   3.44837388271875*^9, {3.448373928078125*^9, 3.44837396921875*^9}, {
   3.44837400328125*^9, 3.448374086625*^9}, {3.44837412471875*^9, 
   3.4483741793125*^9}, {3.448374369625*^9, 3.448374378*^9}, 
   3.44837444103125*^9, 3.448374828984375*^9, 3.448374893265625*^9, 
   3.44837532196875*^9, 3.448375384296875*^9, 3.44837543784375*^9, {
   3.44837991390625*^9, 3.44837992665625*^9}, 3.44839879928125*^9, 
   3.448398857734375*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "78.88888888888889`", ",", "78.88888888888889`", ",", 
   "78.88888888888889`"}], "}"}]], "Output",
 CellChangeTimes->{{3.448373834953125*^9, 3.44837385115625*^9}, 
   3.44837388271875*^9, {3.448373928078125*^9, 3.44837396921875*^9}, {
   3.44837400328125*^9, 3.448374086625*^9}, {3.44837412471875*^9, 
   3.4483741793125*^9}, {3.448374369625*^9, 3.448374378*^9}, 
   3.44837444103125*^9, 3.448374828984375*^9, 3.448374893265625*^9, 
   3.44837532196875*^9, 3.448375384296875*^9, 3.44837543784375*^9, {
   3.44837991390625*^9, 3.44837992665625*^9}, 3.44839879928125*^9, 
   3.448398857734375*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generic Amplifier Noise", "Subsubtitle",
 CellChangeTimes->{{3.447186576652625*^9, 3.44718659091825*^9}, {
  3.447187881965125*^9, 3.447187883183875*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"AMPNoiseLow", "[", "f_", "]"}], ":=", 
  RowBox[{"FromdBc", "[", 
   RowBox[{"118", "+", 
    RowBox[{"20", " ", 
     RowBox[{"Log", "[", 
      RowBox[{"10", ",", "f"}], "]"}]}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AMPNoiseLevel", "[", "f_", "]"}], ":=", 
  RowBox[{"FromdBc", "[", "170", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AMPNoise", "[", "f_", "]"}], ":=", 
  SqrtBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"AMPNoiseLow", "[", "f", "]"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"AMPNoiseLevel", "[", "f", "]"}], "2"]}]]}]}], "Input",
 CellChangeTimes->{{3.44717687041825*^9, 3.44717694704325*^9}, {
   3.447177021371375*^9, 3.44717710041825*^9}, {3.44717717273075*^9, 
   3.44717719435575*^9}, {3.447177984637*^9, 3.447178025762*^9}, 
   3.447179169262*^9, 3.447179208496375*^9, 3.447179401808875*^9, 
   3.447179492965125*^9, {3.447180007027625*^9, 3.447180049902625*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogLinearPlot", "[", 
  RowBox[{
   RowBox[{"dB", "[", 
    RowBox[{"AMPNoise", "[", "f", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", "100", ",", "1*^6"}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
     "}"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "180"}], ",", 
      RowBox[{"-", "120"}]}], "}"}]}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Amplifier phase noise\>\""}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Offset Frequency (Hz)\>\"", ",", "\"\<Phase Noise (dBc/Hz)\>\""}], 
     "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.447178040887*^9, 3.447178087215125*^9}, {
   3.44717856066825*^9, 3.447178578996375*^9}, {3.447178693902625*^9, 
   3.447178697246375*^9}, {3.447178737058875*^9, 3.447178771871375*^9}, 
   3.447179197152625*^9, {3.44717928091825*^9, 3.44717929735575*^9}, {
   3.44717950954325*^9, 3.447179606762*^9}, {3.44718005885575*^9, 
   3.44718008598075*^9}, {3.447180977121375*^9, 3.447180981996375*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwd1nc81d8bAHAjUkmSPa67l5EkoeIhLSkzldRX3CtJSP0qUSojSRQaMrIy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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->NCache[{
     Log[100], -180}, {4.605170185988092, -180}],
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  Frame->True,
  FrameLabel->{
    FormBox["\"Offset Frequency (Hz)\"", TraditionalForm], 
    FormBox["\"Phase Noise (dBc/Hz)\"", TraditionalForm]},
  FrameTicks->
   FrontEndValueCache[{{Automatic, Automatic}, {{{4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["6", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
        FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}, {{
     Automatic, Automatic}, {{{4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["6", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
        FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}],
  GridLines->{{4.605170185988092, 6.907755278982137, 9.210340371976184, 
    11.512925464970229`, 13.815510557964274`, 5.298317366548036, 
    5.703782474656201, 5.991464547107982, 6.214608098422191, 
    6.396929655216146, 6.551080335043404, 6.684611727667927, 
    6.802394763324311, 7.600902459542082, 8.006367567650246, 
    8.294049640102028, 8.517193191416238, 8.699514748210191, 8.85366542803745,
     8.987196820661973, 9.104979856318357, 9.903487552536127, 
    10.308952660644293`, 10.596634733096073`, 10.819778284410283`, 
    11.002099841204238`, 11.156250521031495`, 11.289781913656018`, 
    11.407564949312402`, 12.206072645530174`, 12.611537753638338`, 
    12.89921982609012, 13.122363377404328`, 13.304684934198283`, 
    13.458835614025542`, 13.592367006650065`, 13.710150042306449`}, 
    Automatic},
  Method->{},
  PlotLabel->FormBox["\"Amplifier phase noise\"", TraditionalForm],
  PlotRange->NCache[{{
      Log[100], 
      Log[1000000]}, {-180, -120}}, {{4.605170185988092, 
     13.815510557964274`}, {-180, -120}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {None, None}},
  Ticks->{{{4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["4", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["5", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["6", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {5.298317366548036, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.903487552536127, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.308952660644293`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.596634733096073`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.819778284410283`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.002099841204238`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.156250521031495`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.289781913656018`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.407564949312402`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.206072645530174`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.611537753638338`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.89921982609012, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.122363377404328`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.304684934198283`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.458835614025542`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.592367006650065`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.710150042306449`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, Automatic}]], "Output",
 CellChangeTimes->{{3.44718005960575*^9, 3.44718008629325*^9}, 
   3.447180982527625*^9, 3.447186841652625*^9, 3.4475138514470177`*^9, 
   3.4480255153077497`*^9, 3.4481968972668753`*^9, 3.4483096759387503`*^9, 
   3.4483108171418753`*^9, 3.4483121487668753`*^9, 3.4483126303137503`*^9, 
   3.448375322765625*^9, {3.44837536203125*^9, 3.448375387765625*^9}, {
   3.448375434171875*^9, 3.448375437953125*^9}, {3.448379914046875*^9, 
   3.448379926765625*^9}, 3.448398799375*^9, 3.44839885784375*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["VCO (MCF91119-10) at 1.05 GHz", "Subsubtitle",
 CellChangeTimes->{{3.447176813277625*^9, 3.4471768245745*^9}, {
  3.447180627433875*^9, 3.44718064841825*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VCOdata", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "55"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"3", ",", "87"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"4", ",", "112"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"5", ",", "133"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"6", ",", "153"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"7", ",", "173"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"8", ",", "193"}], "}"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.447177216137*^9, 3.447177373121375*^9}, {
   3.447177468387*^9, 3.44717747904325*^9}, {3.447177772683875*^9, 
   3.447177787512*^9}, {3.447179262402625*^9, 3.44717926491825*^9}, 
   3.44717946641825*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "55"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "87"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "112"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "133"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "153"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7", ",", "173"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "193"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.447179265637*^9, 3.44717946735575*^9, 3.447186841715125*^9, 
   3.447513851665738*^9, 3.4480255153702497`*^9, 3.4481968973450003`*^9, 
   3.4483096760637503`*^9, 3.4483108172356253`*^9, 3.4483121488606253`*^9, 
   3.4483126303918753`*^9, 3.448375322828125*^9, 3.448375438015625*^9, {
   3.44837991409375*^9, 3.4483799268125*^9}, 3.4483987994375*^9, 
   3.448398857890625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"VCOfit", "[", "x_", "]"}], "=", 
  RowBox[{"Fit", "[", 
   RowBox[{"VCOdata", ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "x", ",", 
      SuperscriptBox["x", "2"], ",", 
      SuperscriptBox["x", "3"]}], "}"}], ",", "x"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.447177381808875*^9, 3.447177405371375*^9}, {
   3.447177501840125*^9, 3.447177509090125*^9}, {3.447177564746375*^9, 
   3.44717756523075*^9}, {3.44717761510575*^9, 3.447177638246375*^9}, {
   3.447177852340125*^9, 3.4471779131995*^9}, {3.4471786265745*^9, 
   3.44717868335575*^9}, {3.44717901516825*^9, 3.4471790203245*^9}, {
   3.447179103152625*^9, 3.447179106277625*^9}, 3.44717935998075*^9, {
   3.447179473871375*^9, 3.447179477012*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "31.785714285714477`"}], "+", 
  RowBox[{"53.52777777777786`", " ", "x"}], "-", 
  RowBox[{"5.619047619047644`", " ", 
   SuperscriptBox["x", "2"]}], "+", 
  RowBox[{"0.3055555555555578`", " ", 
   SuperscriptBox["x", "3"]}]}]], "Output",
 CellChangeTimes->{
  3.44717867098075*^9, 3.447179021262*^9, 3.44717910698075*^9, {
   3.447179238433875*^9, 3.447179270465125*^9}, 3.44717936104325*^9, {
   3.44717946854325*^9, 3.447179477496375*^9}, 3.44718684173075*^9, 
   3.4475138520563107`*^9, 3.4480255156514997`*^9, 3.4481968975950003`*^9, 
   3.4483096763137503`*^9, 3.4483108172825003`*^9, 3.4483121489075003`*^9, 
   3.4483126304075003`*^9, 3.448375323140625*^9, 3.448375438046875*^9, {
   3.448379914125*^9, 3.448379926828125*^9}, 3.448398799484375*^9, 
   3.448398857921875*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", 
    RowBox[{"VCOdata", ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"PointSize", " ", "[", "0.03", "]"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "7.2"}], "}"}], ",", "All"}], "}"}]}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}]}], "]"}], ",", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"VCOfit", "[", "x", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "1", ",", "7.2"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "7.2"}], "}"}], ",", "All"}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0", ",", "0", ",", "1"}], "]"}]}], "}"}]}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.447177537058875*^9, 3.4471776000745*^9}, {
   3.44717766185575*^9, 3.447177758340125*^9}, 3.447177919590125*^9, {
   3.44717824185575*^9, 3.4471782643245*^9}, {3.44717830066825*^9, 
   3.447178376277625*^9}, {3.44717845629325*^9, 3.4471784700745*^9}, {
   3.4471785131995*^9, 3.447178549090125*^9}, {3.447178646465125*^9, 
   3.447178647183875*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[1, 0, 0], PointSize[0.03], 
    PointBox[{{2., 55.}, {3., 87.}, {4., 112.}, {5., 133.}, {6., 153.}, {7., 
     173.}, {8., 193.}}]}, {{}, {}, 
    {RGBColor[0, 0, 1], Thickness[0.007], LineBox[CompressedData["
1:eJwVx3k41HkAx/EhV2jc17gebYUH26BQan4fdhTJ0Ti2GJVrkh4sJU8l245j
Y7WtjUq1TEk6pkSGjXIskeOxSnlK0ViMo2yjVWjEfvvj/byfl0VEAidankaj
+ZK+Xtts1oJGk1IrZauda+KYsFMtUOpQllJJOr776vlMeH5yeHtGQ0opzawJ
az7HRFp3fJWluZQavth8obWJick0yRY/lpSSj8mPrNSzx19vnh8oSpVSqYsf
Qswf2iPpcpVo07yUCsm+FOqv6ojeVUleRz5MU7+zolIZReuR/lrgKqbPUEd7
dNOn9F3hfNY8LkX5ExWrpvkiRRlg5WrUWH2apV6+Las7zXPHOsd7nW30z9QJ
Hvul/Rgba19fMz+3bIHa+e+yNJHtVhg5+bICVy5S9LvvH57J84IN715tgTEN
G71sLrL6vbG9cizZSFcOebH80cF3PhjtS9bPt5CHStAdi2C6P04s3OpbY7oM
Vzwmh3LVd4DdyChp1VGANU/oH7S0Aye4w4Fh5oqIKd1C71zioH4+YI26kRJM
lSb3Px4PwKEEs4EKS2W8K2zaJxoMREC6hSDKXgWHa5+3lLcHYd35Lv5a6+UQ
/xY/4V0cjFOZT7ZNr1eFSqk0j/nT9xg/mObQyVRDOsef6vXdibqNmUsXoY7B
SsHABqtdqClueXHEewV2/33MLXFuF6oVhU8S2HT47j/6H1UdAlv2VDmXowG+
1Mzz4I+heOr2to9pqQmnnnnOBmcuSpgLr+5f0URDom1R2xgXd9VqA+qttLBw
84fdGSVhYI15v+ou1cJSRIHVHr/dUCnPeR5ipw3hdPLAZqU9kDwaDYqr1IbX
DWFtYfUeeAzoSn75Vgf0wOkilu1eiMXS8dUiHQzQTifW8vdiYUQg63TQhdup
ie9Cn+6FnUtc/txtXfTzabuOm4fjQoqkWOCoh/TF5jvspHCcrHGsC7yrh/7C
8KON9eGoHLbzynDWxz9di6NzmhEI01yQNIj0cUHaX+wUFgHTXIkq394ALVrl
wXllETCcOX65ocYAmJgfkcxGoIA7sXX5ekN8yYjIqnCPhE+FXHj3A0NkFBqb
3DoTCUaQE43hboRrVUNCl+FIxMyzyhPrjRDaNKx93i4KH7JnetgeDGgmbJjL
TovCF0aa/KpmBnpMNdT4HVEwlX1Tm80yhnd4tVmKXjSOtB0eiW0xhmFFovnB
fdEIzv/DbKebCR6ls6fuVEUj3iexs/GxCVojy7ic5Tz4tgTKeoif8cQ5XGI7
VxebIWJ2rOl9HvE7q6UcuXYT5CSV6B0j3q9waps78bacN90lxFF119ubiaeG
Ddw/Eodai9taO0zw+Ua2zXlVHjYKmmf7iP/scw+5QswwKLMcI25UpGULiV8o
xP+s3GmCkdgsSSNxsFi2xZN4VUDz5QlizjmD1nbi8etfDF3VeHCgyz6+JN4u
N7vVg1grc3D1JPEQd+awH3FPUmmmapcJlMxkzyKJfXwdPbyJy9pd8nKJbR/p
J4cSZ23mNJ4lVt/0+eoBYoYo4b2AuMO6SSGXWFBe7SMivim4uu4S8W0HcWoD
cbbBySgh8c37K4TtxDG/Hsh/8NVs6lUvsaeiX0sXcW3vIdVB4v8Ba7Qsxg==

      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  Frame->True,
  GridLines->Automatic,
  PlotRange->{{1, 7.2}, All},
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{{3.44717759241825*^9, 3.447177759402625*^9}, {
   3.44717785735575*^9, 3.44717792041825*^9}, {3.44717824798075*^9, 
   3.44717826516825*^9}, {3.44717830866825*^9, 3.44717837710575*^9}, 
   3.4471784705745*^9, {3.44717851648075*^9, 3.447178549402625*^9}, {
   3.447178647746375*^9, 3.447178676402625*^9}, 3.4471791114495*^9, {
   3.447179242762*^9, 3.447179271871375*^9}, 3.447179362012*^9, {
   3.447179469871375*^9, 3.447179479558875*^9}, 3.447186841762*^9, 
   3.4475138520875564`*^9, 3.4480255156827497`*^9, 3.4481968976262503`*^9, 
   3.4483096763606253`*^9, 3.4483108173606253`*^9, 3.4483121489543753`*^9, 
   3.4483126304700003`*^9, 3.44837532321875*^9, 3.448375438078125*^9, {
   3.448379914140625*^9, 3.44837992684375*^9}, 3.448398799515625*^9, 
   3.4483988579375*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"VCONoiseLow", "[", "f_", "]"}], ":=", 
  RowBox[{"FromdBc", "[", 
   RowBox[{"VCOfit", "[", 
    RowBox[{"Log", "[", 
     RowBox[{"10", ",", "f"}], "]"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"VCONoiseLevel", "[", "f_", "]"}], ":=", 
  RowBox[{"FromdBc", "[", "165", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"VCONoise", "[", "f_", "]"}], ":=", 
  SqrtBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"VCONoiseLow", "[", "f", "]"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"VCONoiseLevel", "[", "f", "]"}], "2"]}]]}]}], "Input",
 CellChangeTimes->{{3.44717687041825*^9, 3.44717694704325*^9}, {
   3.447177021371375*^9, 3.44717710041825*^9}, {3.44717717273075*^9, 
   3.44717719435575*^9}, {3.447177984637*^9, 3.447178025762*^9}, 
   3.447179169262*^9, 3.447179208496375*^9, 3.447179401808875*^9, 
   3.447179492965125*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogLinearPlot", "[", 
  RowBox[{
   RowBox[{"dB", "[", 
    RowBox[{"VCONoise", "[", "f", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", "100", ",", "1*^7"}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
     "}"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "170"}], ",", 
      RowBox[{"-", "30"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<VCO phase noise (SSB)\>\""}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Offset Frequency (Hz)\>\"", ",", "\"\<Phase Noise (dBc/Hz)\>\""}], 
     "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.447178040887*^9, 3.447178087215125*^9}, {
   3.44717856066825*^9, 3.447178578996375*^9}, {3.447178693902625*^9, 
   3.447178697246375*^9}, {3.447178737058875*^9, 3.447178771871375*^9}, 
   3.447179197152625*^9, {3.44717928091825*^9, 3.44717929735575*^9}, {
   3.44717950954325*^9, 3.447179606762*^9}, {3.4471809514495*^9, 
   3.44718096791825*^9}, {3.44839870325*^9, 3.4483987045*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwV0nk81OkfAHBK2hwl1yg0YUKY75dVIuSjKGfGMO4cM1/lWDstiRTGUaFi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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->NCache[{
     Log[100], -170}, {4.605170185988092, -170}],
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  Frame->True,
  FrameLabel->{
    FormBox["\"Offset Frequency (Hz)\"", TraditionalForm], 
    FormBox["\"Phase Noise (dBc/Hz)\"", TraditionalForm]},
  FrameTicks->
   FrontEndValueCache[{{Automatic, Automatic}, {{{4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["6", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {16.11809565095832, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["7", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.508657738524219`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.914122846632385`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.201804919084164`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.424948470398375`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.60727002719233, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.761420707019587`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.89495209964411, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {16.012735135300492`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
        FormBox["\" \"", TraditionalForm]}, {16.11809565095832, 
        FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.508657738524219`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.914122846632385`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.201804919084164`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.424948470398375`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.60727002719233, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.761420707019587`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.89495209964411, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {16.012735135300492`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}, {{
     Automatic, Automatic}, {{{4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["6", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {16.11809565095832, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["7", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.508657738524219`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.914122846632385`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.201804919084164`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.424948470398375`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.60727002719233, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.761420707019587`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.89495209964411, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {16.012735135300492`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
        FormBox["\" \"", TraditionalForm]}, {16.11809565095832, 
        FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.508657738524219`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.914122846632385`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.201804919084164`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.424948470398375`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.60727002719233, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.761420707019587`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.89495209964411, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {16.012735135300492`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}],
  GridLines->{{4.605170185988092, 6.907755278982137, 9.210340371976184, 
    11.512925464970229`, 13.815510557964274`, 16.11809565095832, 
    5.298317366548036, 5.703782474656201, 5.991464547107982, 
    6.214608098422191, 6.396929655216146, 6.551080335043404, 
    6.684611727667927, 6.802394763324311, 7.600902459542082, 
    8.006367567650246, 8.294049640102028, 8.517193191416238, 
    8.699514748210191, 8.85366542803745, 8.987196820661973, 9.104979856318357,
     9.903487552536127, 10.308952660644293`, 10.596634733096073`, 
    10.819778284410283`, 11.002099841204238`, 11.156250521031495`, 
    11.289781913656018`, 11.407564949312402`, 12.206072645530174`, 
    12.611537753638338`, 12.89921982609012, 13.122363377404328`, 
    13.304684934198283`, 13.458835614025542`, 13.592367006650065`, 
    13.710150042306449`, 14.508657738524219`, 14.914122846632385`, 
    15.201804919084164`, 15.424948470398375`, 15.60727002719233, 
    15.761420707019587`, 15.89495209964411, 16.012735135300492`}, Automatic},
  Method->{},
  PlotLabel->FormBox["\"VCO phase noise (SSB)\"", TraditionalForm],
  PlotRange->NCache[{{
      Log[100], 
      Log[10000000]}, {-170, -30}}, {{4.605170185988092, 
     16.11809565095832}, {-170, -30}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {None, None}},
  Ticks->{{{4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["4", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["5", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["6", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {16.11809565095832, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["7", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {5.298317366548036, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.903487552536127, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.308952660644293`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.596634733096073`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.819778284410283`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.002099841204238`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.156250521031495`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.289781913656018`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.407564949312402`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.206072645530174`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.611537753638338`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.89921982609012, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.122363377404328`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.304684934198283`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.458835614025542`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.592367006650065`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.710150042306449`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {14.508657738524219`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {14.914122846632385`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.201804919084164`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.424948470398375`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.60727002719233, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.761420707019587`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.89495209964411, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {16.012735135300492`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, Automatic}]], "Output",
 CellChangeTimes->{
  3.447178053996375*^9, 3.447178580215125*^9, {3.44717868916825*^9, 
   3.447178697887*^9}, 3.447178737387*^9, {3.447178772808875*^9, 
   3.447178785933875*^9}, 3.447179117137*^9, {3.447179171340125*^9, 
   3.4471792103245*^9}, {3.447179248058875*^9, 3.447179297902625*^9}, 
   3.447179367762*^9, 3.447179403746375*^9, {3.44717948341825*^9, 
   3.447179510621375*^9}, {3.447179563965125*^9, 3.44717960748075*^9}, 
   3.4471809724495*^9, 3.44718684185575*^9, 3.447513852228163*^9, 
   3.4480255157921247`*^9, 3.4481968977512503`*^9, 3.4483096765793753`*^9, 
   3.4483108175168753`*^9, 3.4483121490950003`*^9, 3.4483126305950003`*^9, 
   3.448375323296875*^9, 3.4483754381875*^9, {3.448379914234375*^9, 
   3.448379926921875*^9}, 3.44839879959375*^9, 3.448398858015625*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["VCO scaled to 80 MHz", "Subsubtitle",
 CellChangeTimes->{{3.447176813277625*^9, 3.4471768245745*^9}, {
  3.447180627433875*^9, 3.44718064841825*^9}, {3.447186475887*^9, 
  3.4471864848245*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"VCOScaledNoiseLow", "[", "f_", "]"}], ":=", 
  FractionBox[
   SqrtBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"VCONoiseLow", "[", "f", "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"AMPNoiseLow", "[", "f", "]"}], "2"]}]], 
   "13"]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"VCOScaledNoiseLevel", "[", "f_", "]"}], ":=", 
  SqrtBox[
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"AMPNoiseLevel", "[", "f", "]"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"VCONoiseLevel", "[", "f", "]"}], "2"]}], "13"], "+", 
    RowBox[{"4", 
     SuperscriptBox[
      RowBox[{"NoiseLevelBottom", "[", "f", "]"}], 
      "2"]}]}]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"VCOScaledNoise", "[", "f_", "]"}], ":=", 
  SqrtBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"VCOScaledNoiseLow", "[", "f", "]"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"VCOScaledNoiseLevel", "[", "f", "]"}], "2"]}]]}]}], "Input",
 CellChangeTimes->{{3.44717687041825*^9, 3.44717694704325*^9}, {
   3.447177021371375*^9, 3.44717710041825*^9}, {3.44717717273075*^9, 
   3.44717719435575*^9}, {3.447177984637*^9, 3.447178025762*^9}, 
   3.447179169262*^9, 3.447179208496375*^9, 3.447179401808875*^9, 
   3.447179492965125*^9, {3.447186501933875*^9, 3.4471865160745*^9}, 
   3.44718655416825*^9, {3.447186600152625*^9, 3.44718663473075*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogLinearPlot", "[", 
  RowBox[{
   RowBox[{"dB", "[", 
    RowBox[{"VCOScaledNoise", "[", "f", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", "100", ",", "1*^7"}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
     "}"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "170"}], ",", 
      RowBox[{"-", "30"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Scaled VCO phase noise\>\""}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Offset Frequency (Hz)\>\"", ",", "\"\<Phase Noise (dBc/Hz)\>\""}], 
     "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.447178040887*^9, 3.447178087215125*^9}, {
   3.44717856066825*^9, 3.447178578996375*^9}, {3.447178693902625*^9, 
   3.447178697246375*^9}, {3.447178737058875*^9, 3.447178771871375*^9}, 
   3.447179197152625*^9, {3.44717928091825*^9, 3.44717929735575*^9}, {
   3.44717950954325*^9, 3.447179606762*^9}, {3.4471809514495*^9, 
   3.44718096791825*^9}, {3.447186643496375*^9, 3.447186658340125*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwV1Xk01U8UAHCVshRJ1qxFeOtXSEJ1RbaefYuU8OUnkhZlixTJUmSLirL1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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->NCache[{
     Log[100], -170}, {4.605170185988092, -170}],
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  Frame->True,
  FrameLabel->{
    FormBox["\"Offset Frequency (Hz)\"", TraditionalForm], 
    FormBox["\"Phase Noise (dBc/Hz)\"", TraditionalForm]},
  FrameTicks->
   FrontEndValueCache[{{Automatic, Automatic}, {{{4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["6", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {16.11809565095832, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["7", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.508657738524219`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.914122846632385`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.201804919084164`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.424948470398375`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.60727002719233, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.761420707019587`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.89495209964411, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {16.012735135300492`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
        FormBox["\" \"", TraditionalForm]}, {16.11809565095832, 
        FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.508657738524219`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.914122846632385`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.201804919084164`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.424948470398375`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.60727002719233, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.761420707019587`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.89495209964411, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {16.012735135300492`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}, {{
     Automatic, Automatic}, {{{4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["6", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {16.11809565095832, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["7", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.508657738524219`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.914122846632385`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.201804919084164`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.424948470398375`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.60727002719233, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.761420707019587`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.89495209964411, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {16.012735135300492`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
        FormBox["\" \"", TraditionalForm]}, {16.11809565095832, 
        FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.508657738524219`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.914122846632385`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.201804919084164`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.424948470398375`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.60727002719233, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.761420707019587`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.89495209964411, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {16.012735135300492`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}],
  GridLines->{{4.605170185988092, 6.907755278982137, 9.210340371976184, 
    11.512925464970229`, 13.815510557964274`, 16.11809565095832, 
    5.298317366548036, 5.703782474656201, 5.991464547107982, 
    6.214608098422191, 6.396929655216146, 6.551080335043404, 
    6.684611727667927, 6.802394763324311, 7.600902459542082, 
    8.006367567650246, 8.294049640102028, 8.517193191416238, 
    8.699514748210191, 8.85366542803745, 8.987196820661973, 9.104979856318357,
     9.903487552536127, 10.308952660644293`, 10.596634733096073`, 
    10.819778284410283`, 11.002099841204238`, 11.156250521031495`, 
    11.289781913656018`, 11.407564949312402`, 12.206072645530174`, 
    12.611537753638338`, 12.89921982609012, 13.122363377404328`, 
    13.304684934198283`, 13.458835614025542`, 13.592367006650065`, 
    13.710150042306449`, 14.508657738524219`, 14.914122846632385`, 
    15.201804919084164`, 15.424948470398375`, 15.60727002719233, 
    15.761420707019587`, 15.89495209964411, 16.012735135300492`}, Automatic},
  Method->{},
  PlotLabel->FormBox["\"Scaled VCO phase noise\"", TraditionalForm],
  PlotRange->NCache[{{
      Log[100], 
      Log[10000000]}, {-170, -30}}, {{4.605170185988092, 
     16.11809565095832}, {-170, -30}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {None, None}},
  Ticks->{{{4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["4", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["5", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["6", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {16.11809565095832, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["7", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {5.298317366548036, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.903487552536127, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.308952660644293`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.596634733096073`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.819778284410283`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.002099841204238`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.156250521031495`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.289781913656018`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.407564949312402`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.206072645530174`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.611537753638338`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.89921982609012, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.122363377404328`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.304684934198283`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.458835614025542`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.592367006650065`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.710150042306449`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {14.508657738524219`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {14.914122846632385`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.201804919084164`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.424948470398375`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.60727002719233, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.761420707019587`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.89495209964411, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {16.012735135300492`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, Automatic}]], "Output",
 CellChangeTimes->{
  3.447178053996375*^9, 3.447178580215125*^9, {3.44717868916825*^9, 
   3.447178697887*^9}, 3.447178737387*^9, {3.447178772808875*^9, 
   3.447178785933875*^9}, 3.447179117137*^9, {3.447179171340125*^9, 
   3.4471792103245*^9}, {3.447179248058875*^9, 3.447179297902625*^9}, 
   3.447179367762*^9, 3.447179403746375*^9, {3.44717948341825*^9, 
   3.447179510621375*^9}, {3.447179563965125*^9, 3.44717960748075*^9}, 
   3.4471809724495*^9, {3.447186644308875*^9, 3.44718665954325*^9}, 
   3.44718684216825*^9, 3.447513852493752*^9, 3.4480255160733747`*^9, 
   3.4481968980168753`*^9, 3.4483096769231253`*^9, 3.4483108177981253`*^9, 
   3.4483121493762503`*^9, 3.4483126308762503`*^9, 3.44837532340625*^9, 
   3.448375438390625*^9, {3.448379914453125*^9, 3.448379927109375*^9}, 
   3.448398799765625*^9, 3.4483988581875*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["VCO Output: 11dB amplification & Divide-by-8", "Subsubtitle",
 CellChangeTimes->{{3.447176813277625*^9, 3.4471768245745*^9}, {
  3.447179727465125*^9, 3.447179780527625*^9}, {3.44718061510575*^9, 
  3.447180618512*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"VCO8NoiseLow", "[", "f_", "]"}], ":=", 
  FractionBox[
   SqrtBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"VCONoiseLow", "[", "f", "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"AMPNoiseLow", "[", "f", "]"}], "2"]}]], 
   "8"]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"VCO8NoiseLevel", "[", "f_", "]"}], ":=", 
  SqrtBox[
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"AMPNoiseLevel", "[", "f", "]"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"VCONoiseLevel", "[", "f", "]"}], "2"]}], "8"], "+", 
    RowBox[{"4", 
     SuperscriptBox[
      RowBox[{"NoiseLevelBottom", "[", "f", "]"}], 
      "2"]}]}]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"VCO8Noise", "[", "f_", "]"}], ":=", 
  SqrtBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"VCO8NoiseLow", "[", "f", "]"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"VCO8NoiseLevel", "[", "f", "]"}], "2"]}]]}]}], "Input",
 CellChangeTimes->{{3.44717687041825*^9, 3.44717694704325*^9}, {
   3.447177021371375*^9, 3.44717710041825*^9}, {3.44717717273075*^9, 
   3.44717719435575*^9}, {3.447177984637*^9, 3.447178025762*^9}, 
   3.447179169262*^9, 3.447179208496375*^9, 3.447179401808875*^9, 
   3.447179492965125*^9, {3.44718018479325*^9, 3.4471803183245*^9}, {
   3.447180421012*^9, 3.447180424996375*^9}, {3.447180502371375*^9, 
   3.44718050604325*^9}, {3.447180562387*^9, 3.447180586527625*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogLinearPlot", "[", 
  RowBox[{
   RowBox[{"dB", "[", 
    RowBox[{"VCO8Noise", "[", "f", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", "100", ",", "1*^6"}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
     "}"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "180"}], ",", 
      RowBox[{"-", "60"}]}], "}"}]}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<VCO output phase noise\>\""}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Offset Frequency (Hz)\>\"", ",", "\"\<Phase Noise (dBc/Hz)\>\""}], 
     "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.447178040887*^9, 3.447178087215125*^9}, {
   3.44717856066825*^9, 3.447178578996375*^9}, {3.447178693902625*^9, 
   3.447178697246375*^9}, {3.447178737058875*^9, 3.447178771871375*^9}, 
   3.447179197152625*^9, {3.44717928091825*^9, 3.44717929735575*^9}, {
   3.44717950954325*^9, 3.447179606762*^9}, {3.44718005885575*^9, 
   3.44718008598075*^9}, 3.447180294887*^9, {3.447180324996375*^9, 
   3.447180338121375*^9}, 3.44718043004325*^9, {3.447180985777625*^9, 
   3.447181008058875*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwVz3tUjHkcBvA5JtcsmSS5pFKm3te602WNvrRy26R30EVTM81bZ9mUsCVG
SLqSlaKytTM0NWvK6sJQypdZsxUizWSFJLuStKmkJNv+9o/nPOfz13Me66Bw
JngEh8MRk/zfzT8x1cU/8GBMeUb8QiGDN6zVa8+E8aC0NG5VxxYGz5Vwa/ZH
8IBpV9fl+TDooy+rcYvigUNasbd5AIOPzM3vGmJ58CR3eO7g9wzqcp/e/5TF
A99qfdvVGAaLCtmGldU8SD6o14y/yKCsOrK53tYU5LKS4xRHiDyTDUxcpyls
u7xoueSaEBdcqB3xVjUZkjWVtLdkM3ppFcrzYjMILGuWLzDagjt67fM7+VNg
RqkiR1e8BY3Dt73qeDkFEjWGwr5NW1E5KIiRqc2hy89QEDW4FVea7jMWR0wF
dYbPP+053hgcJTJ8dLCAkpSuK9WLfTC2o2doVo8FuIFOmdTgg3z1YslQ4TR4
NFyfahfiiw/672podjroOza+TO31xfDNk0M7qRmQOXvdrchkPzw7NFoU9NcM
KHvxqbNv8jbUlKnV24tmwr0UAXNetQ2bPuW/0+62hEOnEksXOvrjsWSPHfXU
LDiy50vBV+X+6EDnrY7omQW986sm/b5ahGrjhnlBW63g6rRJJnN0IqwcW9i+
ucIKyqzuOFt5BuCmusszIyytoSjj2tG4hgAscDJ+/3q/Nbx6cMHCySMQP18U
dNu9sIY0d/1xtweBaKq981PVcht4lOTF2T9bjIWK6F8PZ9oAk7D3K5FIjCsT
R3YbD9nAy/m7RnqdE2P25LbG9z6zIeaz/0aRXoxdKnlHbuVs2P3WyUc6SYI6
bnx0pJUtLFmXnRD7nQQlRreUBTJb2LvevX8gVoID4/Wc8y224NFoHOdZKUFh
xfLBPoEdxEhUWoteCc5fUB+6J8sO5hS2nVnKD8IxRYIJ5UN2YNu+1HN8YBAq
Hwx7+PnOgaUpniGRaUG4YjDrhrZyDqxYE9UfUhOE52qTauKn8yFX0XOy5XMQ
RkuUnnui+KC/19sQPVeKQk6WkcNTPgj5ozRcsRS7v231dnKyB5cNZvI7qVI8
forbZJJjDwNjuNE5N6Woyttk4HEc4Lb77VLolGKiqDcszN8BJOMcHVaZscha
hjmeRgeIaS52FAhYNDq2IneSJQUDdxK7DQEs2pW4xFyPpuDjEhn3+QEWB0dE
rlpzgIKQwWejGRmLdcLiUQYZBUtM5VU64sg+/sn3hyh4Um/r9ttBFqudzOT8
eAqUtZYFskMsht7supWRRkHl1ZSGMUdZLLuXN3K3moJDgsPpr5NYdGubcIJ6
ToE9zezVnGHxUqpWk9NMQaKvOoJ3lsVpy/a1mrRQEGclpXcS98S9dOxvpSAt
c6LeOpNFuU1Zq/YNBfEir88JWSwOiXydRB8oaPy97dc1P5M9/YVXJ41p+NbK
9HG6gvy77eTS50yDND9TvV3N4uUaVVLCNzQkDaVJy4mX1099YiGgwco1++G4
QhaZloGoFUCDtxRqLxIf/vfalQR3GrL2THRtK2LxmYvzwmlCGq7kF61lLrOY
Xups7xpKw0Vf+2vdZSxylS5TknJp2FdlLhdVsvjx5rwZGcTjdMOxgcRvmmxs
FMQfzv8ZLCGuMzGed5347+f+dDBxtuzp6nbiCeLfroQSL9os+3HdLzQYGmR/
HCAWc6v0Y+U0+IdWvMgiFlqWNJkR31dV4Tlid+f8Fmviw9oSRQ7x3PDUd87E
2vSdUgVxf1OA0Q7izEtfv1YRp5YML64l/vTl8RsN8ZH7vc6NxN2u7dXXife+
aXNtJVawHaoKYj/LhxsGidd73/7+JrFdslxKKWhIaS9v0xFPVaZvX0ZssU74
RzXxOEwMX0WcfeJZfi3x+75dB/yIc3W3guuIX5kEHwkhvlQxc/VD4kbaN2E3
8cMzO2wfEde4e5yIId7oo+LqiW9IVp5OJg7jPG41EP8HezP2cw==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->NCache[{
     Log[100], -180}, {4.605170185988092, -180}],
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  Frame->True,
  FrameLabel->{
    FormBox["\"Offset Frequency (Hz)\"", TraditionalForm], 
    FormBox["\"Phase Noise (dBc/Hz)\"", TraditionalForm]},
  FrameTicks->
   FrontEndValueCache[{{Automatic, Automatic}, {{{4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["6", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
        FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}, {{
     Automatic, Automatic}, {{{4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["6", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
        FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}],
  GridLines->{{4.605170185988092, 6.907755278982137, 9.210340371976184, 
    11.512925464970229`, 13.815510557964274`, 5.298317366548036, 
    5.703782474656201, 5.991464547107982, 6.214608098422191, 
    6.396929655216146, 6.551080335043404, 6.684611727667927, 
    6.802394763324311, 7.600902459542082, 8.006367567650246, 
    8.294049640102028, 8.517193191416238, 8.699514748210191, 8.85366542803745,
     8.987196820661973, 9.104979856318357, 9.903487552536127, 
    10.308952660644293`, 10.596634733096073`, 10.819778284410283`, 
    11.002099841204238`, 11.156250521031495`, 11.289781913656018`, 
    11.407564949312402`, 12.206072645530174`, 12.611537753638338`, 
    12.89921982609012, 13.122363377404328`, 13.304684934198283`, 
    13.458835614025542`, 13.592367006650065`, 13.710150042306449`}, 
    Automatic},
  Method->{},
  PlotLabel->FormBox["\"VCO output phase noise\"", TraditionalForm],
  PlotRange->NCache[{{
      Log[100], 
      Log[1000000]}, {-180, -60}}, {{4.605170185988092, 
     13.815510557964274`}, {-180, -60}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {None, None}},
  Ticks->{{{4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["4", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["5", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["6", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {5.298317366548036, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.903487552536127, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.308952660644293`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.596634733096073`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.819778284410283`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.002099841204238`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.156250521031495`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.289781913656018`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.407564949312402`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.206072645530174`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.611537753638338`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.89921982609012, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.122363377404328`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.304684934198283`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.458835614025542`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.592367006650065`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.710150042306449`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, Automatic}]], "Output",
 CellChangeTimes->{{3.447180298246375*^9, 3.4471803384495*^9}, {
   3.447180427465125*^9, 3.447180430340125*^9}, 3.447180508402625*^9, {
   3.447180567715125*^9, 3.447180588902625*^9}, {3.44718100066825*^9, 
   3.447181008621375*^9}, 3.447186842340125*^9, 3.447513852728095*^9, 
   3.4480255162296247`*^9, 3.4481968982356253`*^9, 3.4483096771731253`*^9, 
   3.4483108180012503`*^9, 3.4483121495793753`*^9, 3.4483126311106253`*^9, 
   3.44837532353125*^9, 3.448375438546875*^9, {3.44837991459375*^9, 
   3.44837992725*^9}, 3.448398799890625*^9, 3.4483988583125*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mixer LO: Divide-by-16 & 7dB amplification ", "Subsubtitle",
 CellChangeTimes->{{3.447176813277625*^9, 3.4471768245745*^9}, {
  3.447179727465125*^9, 3.447179780527625*^9}, {3.44718061510575*^9, 
  3.447180618512*^9}, {3.4471807273245*^9, 3.447180773590125*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"LONoiseLow", ",", "LONoiseLevel", ",", "LONoise"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LONoiseLow", "[", 
   RowBox[{"f_", ",", "input_", ",", "ratio_"}], "]"}], ":=", 
  SqrtBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{"input", "[", "f", "]"}], "ratio"], ")"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"AMPNoiseLow", "[", "f", "]"}], 
     "2"]}]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LONoiseLevel", "[", 
   RowBox[{"f_", ",", "input_", ",", "ratio_"}], "]"}], ":=", 
  SqrtBox[
   RowBox[{
    FractionBox[
     SuperscriptBox[
      RowBox[{"input", "[", "f", "]"}], "2"], "ratio"], "+", 
    RowBox[{"4", 
     SuperscriptBox[
      RowBox[{"NoiseLevelBottom", "[", "f", "]"}], "2"]}], "+", 
    SuperscriptBox[
     RowBox[{"AMPNoiseLevel", "[", "f", "]"}], 
     "2"]}]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LONoise", "[", 
   RowBox[{"f_", ",", "in1_", ",", "in2_", ",", "r_"}], "]"}], ":=", 
  SqrtBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"LONoiseLow", "[", 
      RowBox[{"f", ",", "in1", ",", "r"}], "]"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"LONoiseLevel", "[", 
      RowBox[{"f", ",", "in2", ",", "r"}], "]"}], "2"]}]]}]}], "Input",
 CellChangeTimes->{{3.44717687041825*^9, 3.44717694704325*^9}, {
   3.447177021371375*^9, 3.44717710041825*^9}, {3.44717717273075*^9, 
   3.44717719435575*^9}, {3.447177984637*^9, 3.447178025762*^9}, 
   3.447179169262*^9, 3.447179208496375*^9, 3.447179401808875*^9, 
   3.447179492965125*^9, {3.44718018479325*^9, 3.4471803183245*^9}, {
   3.447180421012*^9, 3.447180424996375*^9}, {3.447180502371375*^9, 
   3.44718050604325*^9}, {3.447180562387*^9, 3.447180586527625*^9}, {
   3.447180834246375*^9, 3.447180934683875*^9}, {3.447181026121375*^9, 
   3.447181029090125*^9}, {3.44718152373075*^9, 3.447181524402625*^9}, {
   3.4471816176995*^9, 3.447181619027625*^9}, {3.44718230073075*^9, 
   3.447182317465125*^9}, {3.447182365387*^9, 3.447182395840125*^9}, {
   3.447182428433875*^9, 3.447182471137*^9}, {3.44718250491825*^9, 
   3.447182515637*^9}, {3.4471848568245*^9, 3.44718488535575*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"LONoiseLow", "[", "f_", "]"}], ":=", 
  RowBox[{"LONoiseLow", "[", 
   RowBox[{"f", ",", "VCO8NoiseLow", ",", "16"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LONoiseLevel", "[", "f_", "]"}], ":=", 
  RowBox[{"LONoiseLevel", "[", 
   RowBox[{"f", ",", "VCO8NoiseLevel", ",", "16"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LONoise", "[", "f_", "]"}], ":=", 
  SqrtBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"LONoiseLow", "[", "f", "]"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"LONoiseLevel", "[", "f", "]"}], "2"]}]]}]}], "Input",
 CellChangeTimes->{{3.44717687041825*^9, 3.44717694704325*^9}, {
   3.447177021371375*^9, 3.44717710041825*^9}, {3.44717717273075*^9, 
   3.44717719435575*^9}, {3.447177984637*^9, 3.447178025762*^9}, 
   3.447179169262*^9, 3.447179208496375*^9, 3.447179401808875*^9, 
   3.447179492965125*^9, {3.44718018479325*^9, 3.4471803183245*^9}, {
   3.447180421012*^9, 3.447180424996375*^9}, {3.447180502371375*^9, 
   3.44718050604325*^9}, {3.447180562387*^9, 3.447180586527625*^9}, {
   3.447180834246375*^9, 3.447180934683875*^9}, {3.447181026121375*^9, 
   3.447181029090125*^9}, {3.44718152373075*^9, 3.447181524402625*^9}, {
   3.4471816176995*^9, 3.447181619027625*^9}, {3.44718230073075*^9, 
   3.447182317465125*^9}, {3.447182350246375*^9, 3.447182360887*^9}, {
   3.447182409558875*^9, 3.447182422371375*^9}, {3.44718245354325*^9, 
   3.44718245773075*^9}, {3.44718511235575*^9, 3.447185134308875*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogLinearPlot", "[", 
  RowBox[{
   RowBox[{"dB", "[", 
    RowBox[{"LONoise", "[", "f", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", "100", ",", "1*^6"}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
     "}"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "180"}], ",", 
      RowBox[{"-", "60"}]}], "}"}]}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<LO phase noise\>\""}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Offset Frequency (Hz)\>\"", ",", "\"\<Phase Noise (dBc/Hz)\>\""}], 
     "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.447178040887*^9, 3.447178087215125*^9}, {
   3.44717856066825*^9, 3.447178578996375*^9}, {3.447178693902625*^9, 
   3.447178697246375*^9}, {3.447178737058875*^9, 3.447178771871375*^9}, 
   3.447179197152625*^9, {3.44717928091825*^9, 3.44717929735575*^9}, {
   3.44717950954325*^9, 3.447179606762*^9}, {3.44718005885575*^9, 
   3.44718008598075*^9}, 3.447180294887*^9, {3.447180324996375*^9, 
   3.447180338121375*^9}, 3.44718043004325*^9, {3.447181011527625*^9, 
   3.447181034371375*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwV1nc8Vl0cAHB7RDJCg8d61n0epGVk9CsjsqVInuJxyYuIFCIjQspqUimy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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->NCache[{
     Log[100], -180}, {4.605170185988092, -180}],
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  Frame->True,
  FrameLabel->{
    FormBox["\"Offset Frequency (Hz)\"", TraditionalForm], 
    FormBox["\"Phase Noise (dBc/Hz)\"", TraditionalForm]},
  FrameTicks->
   FrontEndValueCache[{{Automatic, Automatic}, {{{4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["6", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
        FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}, {{
     Automatic, Automatic}, {{{4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["6", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
        FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}],
  GridLines->{{4.605170185988092, 6.907755278982137, 9.210340371976184, 
    11.512925464970229`, 13.815510557964274`, 5.298317366548036, 
    5.703782474656201, 5.991464547107982, 6.214608098422191, 
    6.396929655216146, 6.551080335043404, 6.684611727667927, 
    6.802394763324311, 7.600902459542082, 8.006367567650246, 
    8.294049640102028, 8.517193191416238, 8.699514748210191, 8.85366542803745,
     8.987196820661973, 9.104979856318357, 9.903487552536127, 
    10.308952660644293`, 10.596634733096073`, 10.819778284410283`, 
    11.002099841204238`, 11.156250521031495`, 11.289781913656018`, 
    11.407564949312402`, 12.206072645530174`, 12.611537753638338`, 
    12.89921982609012, 13.122363377404328`, 13.304684934198283`, 
    13.458835614025542`, 13.592367006650065`, 13.710150042306449`}, 
    Automatic},
  Method->{},
  PlotLabel->FormBox["\"LO phase noise\"", TraditionalForm],
  PlotRange->NCache[{{
      Log[100], 
      Log[1000000]}, {-180, -60}}, {{4.605170185988092, 
     13.815510557964274`}, {-180, -60}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {None, None}},
  Ticks->{{{4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["4", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["5", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["6", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {5.298317366548036, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.903487552536127, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.308952660644293`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.596634733096073`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.819778284410283`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.002099841204238`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.156250521031495`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.289781913656018`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.407564949312402`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.206072645530174`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.611537753638338`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.89921982609012, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.122363377404328`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.304684934198283`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.458835614025542`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.592367006650065`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.710150042306449`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, Automatic}]], "Output",
 CellChangeTimes->{{3.447181016137*^9, 3.447181035152625*^9}, 
   3.447181529246375*^9, 3.447181621762*^9, 3.447182461433875*^9, 
   3.4471825211995*^9, 3.44718515723075*^9, 3.447186842715125*^9, 
   3.447513853087422*^9, 3.4480255165577497`*^9, 3.4481968985950003`*^9, 
   3.4483096776106253`*^9, 3.4483108184387503`*^9, 3.4483121499856253`*^9, 
   3.4483126315012503`*^9, 3.44837532365625*^9, 3.448375438796875*^9, {
   3.448379914859375*^9, 3.4483799275*^9}, 3.448398800109375*^9, 
   3.44839885853125*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mixer RF: Wenzel OCXO at 71 MHz & 10dB amplification", "Subsubtitle",
 CellChangeTimes->{{3.447176813277625*^9, 3.4471768245745*^9}, {
  3.447179727465125*^9, 3.447179780527625*^9}, {3.44718061510575*^9, 
  3.447180618512*^9}, {3.4471807273245*^9, 3.447180798715125*^9}, {
  3.44718143885575*^9, 3.447181444715125*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OCXOdata", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "90"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"2", ",", "110"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"3", ",", "140"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"4", ",", "160"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"5", ",", "180"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"6", ",", "200"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"7", ",", "220"}], "}"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.447177216137*^9, 3.447177373121375*^9}, {
   3.447177468387*^9, 3.44717747904325*^9}, {3.447177772683875*^9, 
   3.447177787512*^9}, {3.447179262402625*^9, 3.44717926491825*^9}, 
   3.44717946641825*^9, {3.44718110098075*^9, 3.447181104371375*^9}, {
   3.447181138777625*^9, 3.44718118373075*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "90"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "110"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "140"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "160"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "180"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "200"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7", ",", "220"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.447179265637*^9, 3.44717946735575*^9, 3.447181184340125*^9, 
   3.44718162929325*^9, 3.44718517198075*^9, 3.4471868428245*^9, 
   3.447513853149914*^9, 3.4480255166202497`*^9, 3.4481968986887503`*^9, 
   3.4483096777512503`*^9, 3.4483108185325003`*^9, 3.4483121500793753`*^9, 
   3.4483126315950003`*^9, 3.44837532371875*^9, 3.448375438875*^9, {
   3.4483799149375*^9, 3.448379927546875*^9}, 3.44839880015625*^9, 
   3.448398858578125*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"OCXOfit", "[", "x_", "]"}], "=", 
  RowBox[{"Fit", "[", 
   RowBox[{"OCXOdata", ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "x", ",", 
      SuperscriptBox["x", "2"], ",", 
      SuperscriptBox["x", "3"]}], "}"}], ",", "x"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.447177381808875*^9, 3.447177405371375*^9}, {
   3.447177501840125*^9, 3.447177509090125*^9}, {3.447177564746375*^9, 
   3.44717756523075*^9}, {3.44717761510575*^9, 3.447177638246375*^9}, {
   3.447177852340125*^9, 3.4471779131995*^9}, {3.4471786265745*^9, 
   3.44717868335575*^9}, {3.44717901516825*^9, 3.4471790203245*^9}, {
   3.447179103152625*^9, 3.447179106277625*^9}, 3.44717935998075*^9, {
   3.447179473871375*^9, 3.447179477012*^9}, {3.447181108371375*^9, 
   3.447181111777625*^9}}],

Cell[BoxData[
 RowBox[{"62.857142857143174`", "\[InvisibleSpace]", "+", 
  RowBox[{"26.54761904761876`", " ", "x"}], "-", 
  RowBox[{"0.5952380952380174`", " ", 
   SuperscriptBox["x", "2"]}], "-", 
  RowBox[{"6.343908861559235`*^-15", " ", 
   SuperscriptBox["x", "3"]}]}]], "Output",
 CellChangeTimes->{
  3.44717867098075*^9, 3.447179021262*^9, 3.44717910698075*^9, {
   3.447179238433875*^9, 3.447179270465125*^9}, 3.44717936104325*^9, {
   3.44717946854325*^9, 3.447179477496375*^9}, 3.447181186527625*^9, 
   3.44718162935575*^9, 3.447185172058875*^9, 3.44718684285575*^9, 
   3.4475138531811595`*^9, 3.4480255166358747`*^9, 3.4481968987200003`*^9, 
   3.4483096777981253`*^9, 3.4483108185793753`*^9, 3.4483121501418753`*^9, 
   3.4483126316262503`*^9, 3.44837532375*^9, 3.44837543890625*^9, {
   3.448379914953125*^9, 3.4483799275625*^9}, 3.4483988001875*^9, 
   3.44839885859375*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", 
    RowBox[{"VCOdata", ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"PointSize", " ", "[", "0.03", "]"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "7.2"}], "}"}], ",", "All"}], "}"}]}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}]}], "]"}], ",", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"VCOfit", "[", "x", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "1", ",", "7.2"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "7.2"}], "}"}], ",", "All"}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"RGBColor", " ", "[", 
         RowBox[{"0", ",", "0", ",", "1"}], "]"}]}], "}"}]}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.447177537058875*^9, 3.4471776000745*^9}, {
   3.44717766185575*^9, 3.447177758340125*^9}, 3.447177919590125*^9, {
   3.44717824185575*^9, 3.4471782643245*^9}, {3.44717830066825*^9, 
   3.447178376277625*^9}, {3.44717845629325*^9, 3.4471784700745*^9}, {
   3.4471785131995*^9, 3.447178549090125*^9}, {3.447178646465125*^9, 
   3.447178647183875*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[1, 0, 0], PointSize[0.03], 
    PointBox[{{2., 55.}, {3., 87.}, {4., 112.}, {5., 133.}, {6., 153.}, {7., 
     173.}, {8., 193.}}]}, {{}, {}, 
    {RGBColor[0, 0, 1], Thickness[0.007], LineBox[CompressedData["
1:eJwVx3k41HkAx/EhV2jc17gebYUH26BQan4fdhTJ0Ti2GJVrkh4sJU8l245j
Y7WtjUq1TEk6pkSGjXIskeOxSnlK0ViMo2yjVWjEfvvj/byfl0VEAidankaj
+ZK+Xtts1oJGk1IrZauda+KYsFMtUOpQllJJOr776vlMeH5yeHtGQ0opzawJ
az7HRFp3fJWluZQavth8obWJick0yRY/lpSSj8mPrNSzx19vnh8oSpVSqYsf
Qswf2iPpcpVo07yUCsm+FOqv6ojeVUleRz5MU7+zolIZReuR/lrgKqbPUEd7
dNOn9F3hfNY8LkX5ExWrpvkiRRlg5WrUWH2apV6+Las7zXPHOsd7nW30z9QJ
Hvul/Rgba19fMz+3bIHa+e+yNJHtVhg5+bICVy5S9LvvH57J84IN715tgTEN
G71sLrL6vbG9cizZSFcOebH80cF3PhjtS9bPt5CHStAdi2C6P04s3OpbY7oM
Vzwmh3LVd4DdyChp1VGANU/oH7S0Aye4w4Fh5oqIKd1C71zioH4+YI26kRJM
lSb3Px4PwKEEs4EKS2W8K2zaJxoMREC6hSDKXgWHa5+3lLcHYd35Lv5a6+UQ
/xY/4V0cjFOZT7ZNr1eFSqk0j/nT9xg/mObQyVRDOsef6vXdibqNmUsXoY7B
SsHABqtdqClueXHEewV2/33MLXFuF6oVhU8S2HT47j/6H1UdAlv2VDmXowG+
1Mzz4I+heOr2to9pqQmnnnnOBmcuSpgLr+5f0URDom1R2xgXd9VqA+qttLBw
84fdGSVhYI15v+ou1cJSRIHVHr/dUCnPeR5ipw3hdPLAZqU9kDwaDYqr1IbX
DWFtYfUeeAzoSn75Vgf0wOkilu1eiMXS8dUiHQzQTifW8vdiYUQg63TQhdup
ie9Cn+6FnUtc/txtXfTzabuOm4fjQoqkWOCoh/TF5jvspHCcrHGsC7yrh/7C
8KON9eGoHLbzynDWxz9di6NzmhEI01yQNIj0cUHaX+wUFgHTXIkq394ALVrl
wXllETCcOX65ocYAmJgfkcxGoIA7sXX5ekN8yYjIqnCPhE+FXHj3A0NkFBqb
3DoTCUaQE43hboRrVUNCl+FIxMyzyhPrjRDaNKx93i4KH7JnetgeDGgmbJjL
TovCF0aa/KpmBnpMNdT4HVEwlX1Tm80yhnd4tVmKXjSOtB0eiW0xhmFFovnB
fdEIzv/DbKebCR6ls6fuVEUj3iexs/GxCVojy7ic5Tz4tgTKeoif8cQ5XGI7
VxebIWJ2rOl9HvE7q6UcuXYT5CSV6B0j3q9waps78bacN90lxFF119ubiaeG
Ddw/Eodai9taO0zw+Ua2zXlVHjYKmmf7iP/scw+5QswwKLMcI25UpGULiV8o
xP+s3GmCkdgsSSNxsFi2xZN4VUDz5QlizjmD1nbi8etfDF3VeHCgyz6+JN4u
N7vVg1grc3D1JPEQd+awH3FPUmmmapcJlMxkzyKJfXwdPbyJy9pd8nKJbR/p
J4cSZ23mNJ4lVt/0+eoBYoYo4b2AuMO6SSGXWFBe7SMivim4uu4S8W0HcWoD
cbbBySgh8c37K4TtxDG/Hsh/8NVs6lUvsaeiX0sXcW3vIdVB4v8Ba7Qsxg==

      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  Frame->True,
  GridLines->Automatic,
  PlotRange->{{1, 7.2}, All},
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{{3.44717759241825*^9, 3.447177759402625*^9}, {
   3.44717785735575*^9, 3.44717792041825*^9}, {3.44717824798075*^9, 
   3.44717826516825*^9}, {3.44717830866825*^9, 3.44717837710575*^9}, 
   3.4471784705745*^9, {3.44717851648075*^9, 3.447178549402625*^9}, {
   3.447178647746375*^9, 3.447178676402625*^9}, 3.4471791114495*^9, {
   3.447179242762*^9, 3.447179271871375*^9}, 3.447179362012*^9, {
   3.447179469871375*^9, 3.447179479558875*^9}, 3.4471811921995*^9, 
   3.447181629402625*^9, 3.447185172121375*^9, 3.447186842902625*^9, 
   3.4475138532280283`*^9, 3.4480255166671247`*^9, 3.4481968987668753`*^9, 
   3.4483096778606253`*^9, 3.4483108186575003`*^9, 3.4483121502043753`*^9, 
   3.4483126316731253`*^9, 3.44837532378125*^9, 3.4483754389375*^9, {
   3.448379914984375*^9, 3.44837992759375*^9}, 3.44839880021875*^9, 
   3.448398858625*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"OCXONoiseLow", "[", "f_", "]"}], ":=", 
  RowBox[{"FromdBc", "[", 
   RowBox[{"OCXOfit", "[", 
    RowBox[{"Log", "[", 
     RowBox[{"10", ",", "f"}], "]"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"OCXONoiseLevel", "[", "f_", "]"}], ":=", 
  RowBox[{"FromdBc", "[", "175", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"OCXONoise", "[", "f_", "]"}], ":=", 
  SqrtBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"OCXONoiseLow", "[", "f", "]"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"OCXONoiseLevel", "[", "f", "]"}], "2"]}]]}]}], "Input",
 CellChangeTimes->{{3.44717687041825*^9, 3.44717694704325*^9}, {
   3.447177021371375*^9, 3.44717710041825*^9}, {3.44717717273075*^9, 
   3.44717719435575*^9}, {3.447177984637*^9, 3.447178025762*^9}, 
   3.447179169262*^9, 3.447179208496375*^9, 3.447179401808875*^9, 
   3.447179492965125*^9, {3.447181213762*^9, 3.4471812279495*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogLinearPlot", "[", 
  RowBox[{
   RowBox[{"dB", "[", 
    RowBox[{"OCXONoise", "[", "f", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", "100", ",", "1*^6"}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
     "}"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "180"}], ",", 
      RowBox[{"-", "80"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<OCXO phase noise (SSB)\>\""}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Offset Frequency (Hz)\>\"", ",", "\"\<Phase Noise (dBc/Hz)\>\""}], 
     "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.447178040887*^9, 3.447178087215125*^9}, {
   3.44717856066825*^9, 3.447178578996375*^9}, {3.447178693902625*^9, 
   3.447178697246375*^9}, {3.447178737058875*^9, 3.447178771871375*^9}, 
   3.447179197152625*^9, {3.44717928091825*^9, 3.44717929735575*^9}, {
   3.44717950954325*^9, 3.447179606762*^9}, {3.4471809514495*^9, 
   3.44718096791825*^9}, {3.447181236012*^9, 3.44718128110575*^9}, {
   3.448398881109375*^9, 3.4483988823125*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwV1nk8VdsXAHCZKmQq8xByz73n3pJKhkjLk15CSirJzPF6EkUZ4lcqSuoh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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->NCache[{
     Log[100], -180}, {4.605170185988092, -180}],
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  Frame->True,
  FrameLabel->{
    FormBox["\"Offset Frequency (Hz)\"", TraditionalForm], 
    FormBox["\"Phase Noise (dBc/Hz)\"", TraditionalForm]},
  FrameTicks->
   FrontEndValueCache[{{Automatic, Automatic}, {{{4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["6", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
        FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}, {{
     Automatic, Automatic}, {{{4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["6", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
        FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}],
  GridLines->{{4.605170185988092, 6.907755278982137, 9.210340371976184, 
    11.512925464970229`, 13.815510557964274`, 5.298317366548036, 
    5.703782474656201, 5.991464547107982, 6.214608098422191, 
    6.396929655216146, 6.551080335043404, 6.684611727667927, 
    6.802394763324311, 7.600902459542082, 8.006367567650246, 
    8.294049640102028, 8.517193191416238, 8.699514748210191, 8.85366542803745,
     8.987196820661973, 9.104979856318357, 9.903487552536127, 
    10.308952660644293`, 10.596634733096073`, 10.819778284410283`, 
    11.002099841204238`, 11.156250521031495`, 11.289781913656018`, 
    11.407564949312402`, 12.206072645530174`, 12.611537753638338`, 
    12.89921982609012, 13.122363377404328`, 13.304684934198283`, 
    13.458835614025542`, 13.592367006650065`, 13.710150042306449`}, 
    Automatic},
  Method->{},
  PlotLabel->FormBox["\"OCXO phase noise (SSB)\"", TraditionalForm],
  PlotRange->NCache[{{
      Log[100], 
      Log[1000000]}, {-180, -80}}, {{4.605170185988092, 
     13.815510557964274`}, {-180, -80}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {None, None}},
  Ticks->{{{4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["4", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["5", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["6", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {5.298317366548036, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.903487552536127, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.308952660644293`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.596634733096073`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.819778284410283`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.002099841204238`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.156250521031495`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.289781913656018`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.407564949312402`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.206072645530174`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.611537753638338`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.89921982609012, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.122363377404328`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.304684934198283`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.458835614025542`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.592367006650065`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.710150042306449`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, Automatic}]], "Output",
 CellChangeTimes->{
  3.447178053996375*^9, 3.447178580215125*^9, {3.44717868916825*^9, 
   3.447178697887*^9}, 3.447178737387*^9, {3.447178772808875*^9, 
   3.447178785933875*^9}, 3.447179117137*^9, {3.447179171340125*^9, 
   3.4471792103245*^9}, {3.447179248058875*^9, 3.447179297902625*^9}, 
   3.447179367762*^9, 3.447179403746375*^9, {3.44717948341825*^9, 
   3.447179510621375*^9}, {3.447179563965125*^9, 3.44717960748075*^9}, 
   3.4471809724495*^9, {3.447181238965125*^9, 3.44718128148075*^9}, 
   3.447181629558875*^9, 3.447185172308875*^9, 3.447186843027625*^9, 
   3.44751385339988*^9, 3.4480255168077497`*^9, 3.4481968989231253`*^9, 
   3.4483096780481253`*^9, 3.4483108188293753`*^9, 3.4483121503606253`*^9, 
   3.4483126318293753`*^9, 3.448375323859375*^9, 3.44837543903125*^9, {
   3.44837991509375*^9, 3.4483799276875*^9}, 3.448398800328125*^9, {
   3.448398858703125*^9, 3.44839888325*^9}}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"RFNoiseLow", "[", "f_", "]"}], ":=", 
  SqrtBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"OCXONoiseLow", "[", "f", "]"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"AMPNoiseLow", "[", "f", "]"}], 
     "2"]}]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RFNoiseLevel", "[", "f_", "]"}], ":=", 
  SqrtBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"OCXONoiseLevel", "[", "f", "]"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"AMPNoiseLevel", "[", "f", "]"}], 
     "2"]}]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RFNoise", "[", "f_", "]"}], ":=", 
  SqrtBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"RFNoiseLow", "[", "f", "]"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"RFNoiseLevel", "[", "f", "]"}], "2"]}]]}]}], "Input",
 CellChangeTimes->{{3.44717687041825*^9, 3.44717694704325*^9}, {
   3.447177021371375*^9, 3.44717710041825*^9}, {3.44717717273075*^9, 
   3.44717719435575*^9}, {3.447177984637*^9, 3.447178025762*^9}, 
   3.447179169262*^9, 3.447179208496375*^9, 3.447179401808875*^9, 
   3.447179492965125*^9, {3.44718018479325*^9, 3.4471803183245*^9}, {
   3.447180421012*^9, 3.447180424996375*^9}, {3.447180502371375*^9, 
   3.44718050604325*^9}, {3.447180562387*^9, 3.447180586527625*^9}, {
   3.447180834246375*^9, 3.447180934683875*^9}, {3.447181026121375*^9, 
   3.447181029090125*^9}, {3.447181461933875*^9, 3.447181500715125*^9}, {
   3.447181601621375*^9, 3.4471816023245*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogLinearPlot", "[", 
  RowBox[{
   RowBox[{"dB", "[", 
    RowBox[{"RFNoise", "[", "f", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", "100", ",", "1*^6"}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
     "}"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "180"}], ",", 
      RowBox[{"-", "60"}]}], "}"}]}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<RF phase noise\>\""}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Offset Frequency (Hz)\>\"", ",", "\"\<Phase Noise (dBc/Hz)\>\""}], 
     "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.447178040887*^9, 3.447178087215125*^9}, {
   3.44717856066825*^9, 3.447178578996375*^9}, {3.447178693902625*^9, 
   3.447178697246375*^9}, {3.447178737058875*^9, 3.447178771871375*^9}, 
   3.447179197152625*^9, {3.44717928091825*^9, 3.44717929735575*^9}, {
   3.44717950954325*^9, 3.447179606762*^9}, {3.44718005885575*^9, 
   3.44718008598075*^9}, 3.447180294887*^9, {3.447180324996375*^9, 
   3.447180338121375*^9}, 3.44718043004325*^9, {3.447181011527625*^9, 
   3.447181034371375*^9}, {3.447181581527625*^9, 3.447181583808875*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwV1nc4V+8bB3AhX1KIzLI/+6NSyQrdksyUUUl25+PX1yahKCpJEu2IbDIK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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->NCache[{
     Log[100], -180}, {4.605170185988092, -180}],
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  Frame->True,
  FrameLabel->{
    FormBox["\"Offset Frequency (Hz)\"", TraditionalForm], 
    FormBox["\"Phase Noise (dBc/Hz)\"", TraditionalForm]},
  FrameTicks->
   FrontEndValueCache[{{Automatic, Automatic}, {{{4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["6", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
        FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}, {{
     Automatic, Automatic}, {{{4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["6", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
        FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}],
  GridLines->{{4.605170185988092, 6.907755278982137, 9.210340371976184, 
    11.512925464970229`, 13.815510557964274`, 5.298317366548036, 
    5.703782474656201, 5.991464547107982, 6.214608098422191, 
    6.396929655216146, 6.551080335043404, 6.684611727667927, 
    6.802394763324311, 7.600902459542082, 8.006367567650246, 
    8.294049640102028, 8.517193191416238, 8.699514748210191, 8.85366542803745,
     8.987196820661973, 9.104979856318357, 9.903487552536127, 
    10.308952660644293`, 10.596634733096073`, 10.819778284410283`, 
    11.002099841204238`, 11.156250521031495`, 11.289781913656018`, 
    11.407564949312402`, 12.206072645530174`, 12.611537753638338`, 
    12.89921982609012, 13.122363377404328`, 13.304684934198283`, 
    13.458835614025542`, 13.592367006650065`, 13.710150042306449`}, 
    Automatic},
  Method->{},
  PlotLabel->FormBox["\"RF phase noise\"", TraditionalForm],
  PlotRange->NCache[{{
      Log[100], 
      Log[1000000]}, {-180, -60}}, {{4.605170185988092, 
     13.815510557964274`}, {-180, -60}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {None, None}},
  Ticks->{{{4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["4", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["5", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["6", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {5.298317366548036, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.903487552536127, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.308952660644293`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.596634733096073`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.819778284410283`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.002099841204238`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.156250521031495`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.289781913656018`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.407564949312402`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.206072645530174`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.611537753638338`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.89921982609012, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.122363377404328`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.304684934198283`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.458835614025542`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.592367006650065`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.710150042306449`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, Automatic}]], "Output",
 CellChangeTimes->{{3.44718157829325*^9, 3.447181629808875*^9}, 
   3.44718517254325*^9, 3.44718684323075*^9, 3.447513853634224*^9, 
   3.4480255170421247`*^9, 3.4481968991887503`*^9, 3.4483096782981253`*^9, 
   3.4483108191106253`*^9, 3.4483121506106253`*^9, 3.4483126321106253`*^9, 
   3.448375323953125*^9, 3.448375439203125*^9, {3.44837991528125*^9, 
   3.448379927859375*^9}, 3.44839880046875*^9, 3.4483988589375*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mixer IF: Sum of LO and RF", "Subsubtitle",
 CellChangeTimes->{{3.447176813277625*^9, 3.4471768245745*^9}, {
  3.447179727465125*^9, 3.447179780527625*^9}, {3.44718061510575*^9, 
  3.447180618512*^9}, {3.4471807273245*^9, 3.447180798715125*^9}, {
  3.44718143885575*^9, 3.447181444715125*^9}, {3.447181666152625*^9, 
  3.447181689246375*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"IFNoiseLow", "[", 
   RowBox[{"f_", ",", "in_", ",", "r_"}], "]"}], ":=", 
  SqrtBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"LONoiseLow", "[", 
      RowBox[{"f", ",", "in", ",", "r"}], "]"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"RFNoiseLow", "[", "f", "]"}], 
     "2"]}]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"IFNoiseLevel", "[", 
   RowBox[{"f_", ",", "in_", ",", "r_"}], "]"}], ":=", 
  SqrtBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"LONoiseLevel", "[", 
      RowBox[{"f", ",", "in", ",", "r"}], "]"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"RFNoiseLevel", "[", "f", "]"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"NoiseLevelBottom", "[", "f", "]"}], 
     "2"]}]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"IFNoise", "[", 
   RowBox[{"f_", ",", "in1_", ",", "in2_", ",", "r_"}], "]"}], ":=", 
  SqrtBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"IFNoiseLow", "[", 
      RowBox[{"f", ",", "in1", ",", "r"}], "]"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"IFNoiseLevel", "[", 
      RowBox[{"f", ",", "in2", ",", "r"}], "]"}], "2"]}]]}]}], "Input",
 CellChangeTimes->{{3.44717687041825*^9, 3.44717694704325*^9}, {
   3.447177021371375*^9, 3.44717710041825*^9}, {3.44717717273075*^9, 
   3.44717719435575*^9}, {3.447177984637*^9, 3.447178025762*^9}, 
   3.447179169262*^9, 3.447179208496375*^9, 3.447179401808875*^9, 
   3.447179492965125*^9, {3.44718018479325*^9, 3.4471803183245*^9}, {
   3.447180421012*^9, 3.447180424996375*^9}, {3.447180502371375*^9, 
   3.44718050604325*^9}, {3.447180562387*^9, 3.447180586527625*^9}, {
   3.447180834246375*^9, 3.447180934683875*^9}, {3.447181026121375*^9, 
   3.447181029090125*^9}, {3.447181461933875*^9, 3.447181500715125*^9}, {
   3.447181601621375*^9, 3.4471816023245*^9}, {3.447181705058875*^9, 
   3.447181769137*^9}, {3.447182553590125*^9, 3.447182589808875*^9}, {
   3.4471849338245*^9, 3.447184979058875*^9}, {3.447185804308875*^9, 
   3.44718580460575*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"IFNoiseLow", "[", "f_", "]"}], ":=", 
  SqrtBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"LONoiseLow", "[", "f", "]"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"RFNoiseLow", "[", "f", "]"}], 
     "2"]}]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"IFNoiseLevel", "[", "f_", "]"}], ":=", 
  SqrtBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"LONoiseLevel", "[", "f", "]"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"RFNoiseLevel", "[", "f", "]"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"NoiseLevelBottom", "[", "f", "]"}], 
     "2"]}]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"IFNoise", "[", "f_", "]"}], ":=", 
  SqrtBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"IFNoiseLow", "[", "f", "]"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"IFNoiseLevel", "[", "f", "]"}], "2"]}]]}]}], "Input",
 CellChangeTimes->{{3.44717687041825*^9, 3.44717694704325*^9}, {
   3.447177021371375*^9, 3.44717710041825*^9}, {3.44717717273075*^9, 
   3.44717719435575*^9}, {3.447177984637*^9, 3.447178025762*^9}, 
   3.447179169262*^9, 3.447179208496375*^9, 3.447179401808875*^9, 
   3.447179492965125*^9, {3.44718018479325*^9, 3.4471803183245*^9}, {
   3.447180421012*^9, 3.447180424996375*^9}, {3.447180502371375*^9, 
   3.44718050604325*^9}, {3.447180562387*^9, 3.447180586527625*^9}, {
   3.447180834246375*^9, 3.447180934683875*^9}, {3.447181026121375*^9, 
   3.447181029090125*^9}, {3.447181461933875*^9, 3.447181500715125*^9}, {
   3.447181601621375*^9, 3.4471816023245*^9}, {3.447181705058875*^9, 
   3.447181769137*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogLinearPlot", "[", 
  RowBox[{
   RowBox[{"dB", "[", 
    RowBox[{"IFNoise", "[", "f", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", "100", ",", "1*^6"}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
     "}"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "180"}], ",", 
      RowBox[{"-", "60"}]}], "}"}]}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<IF phase noise\>\""}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Offset Frequency (Hz)\>\"", ",", "\"\<Phase Noise (dBc/Hz)\>\""}], 
     "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.447178040887*^9, 3.447178087215125*^9}, {
   3.44717856066825*^9, 3.447178578996375*^9}, {3.447178693902625*^9, 
   3.447178697246375*^9}, {3.447178737058875*^9, 3.447178771871375*^9}, 
   3.447179197152625*^9, {3.44717928091825*^9, 3.44717929735575*^9}, {
   3.44717950954325*^9, 3.447179606762*^9}, {3.44718005885575*^9, 
   3.44718008598075*^9}, 3.447180294887*^9, {3.447180324996375*^9, 
   3.447180338121375*^9}, 3.44718043004325*^9, {3.447181011527625*^9, 
   3.447181034371375*^9}, {3.447181581527625*^9, 3.447181583808875*^9}, 
   3.44718173385575*^9, 3.4471817960745*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwV1Xk4Vs0bB3AJkcqSpcXu2c7zIEtZsnSXV4Uo9ArZHSpEluxZCkllyZ6y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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->NCache[{
     Log[100], -180}, {4.605170185988092, -180}],
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  Frame->True,
  FrameLabel->{
    FormBox["\"Offset Frequency (Hz)\"", TraditionalForm], 
    FormBox["\"Phase Noise (dBc/Hz)\"", TraditionalForm]},
  FrameTicks->
   FrontEndValueCache[{{Automatic, Automatic}, {{{4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["6", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
        FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}, {{
     Automatic, Automatic}, {{{4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["6", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
        FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}],
  GridLines->{{4.605170185988092, 6.907755278982137, 9.210340371976184, 
    11.512925464970229`, 13.815510557964274`, 5.298317366548036, 
    5.703782474656201, 5.991464547107982, 6.214608098422191, 
    6.396929655216146, 6.551080335043404, 6.684611727667927, 
    6.802394763324311, 7.600902459542082, 8.006367567650246, 
    8.294049640102028, 8.517193191416238, 8.699514748210191, 8.85366542803745,
     8.987196820661973, 9.104979856318357, 9.903487552536127, 
    10.308952660644293`, 10.596634733096073`, 10.819778284410283`, 
    11.002099841204238`, 11.156250521031495`, 11.289781913656018`, 
    11.407564949312402`, 12.206072645530174`, 12.611537753638338`, 
    12.89921982609012, 13.122363377404328`, 13.304684934198283`, 
    13.458835614025542`, 13.592367006650065`, 13.710150042306449`}, 
    Automatic},
  Method->{},
  PlotLabel->FormBox["\"IF phase noise\"", TraditionalForm],
  PlotRange->NCache[{{
      Log[100], 
      Log[1000000]}, {-180, -60}}, {{4.605170185988092, 
     13.815510557964274`}, {-180, -60}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {None, None}},
  Ticks->{{{4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["4", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["5", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["6", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {5.298317366548036, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.903487552536127, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.308952660644293`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.596634733096073`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.819778284410283`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.002099841204238`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.156250521031495`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.289781913656018`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.407564949312402`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.206072645530174`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.611537753638338`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.89921982609012, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.122363377404328`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.304684934198283`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.458835614025542`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.592367006650065`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.710150042306449`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, Automatic}]], "Output",
 CellChangeTimes->{{3.44718157829325*^9, 3.447181629808875*^9}, {
   3.44718177273075*^9, 3.4471817969495*^9}, 3.44718259491825*^9, 
   3.447185182262*^9, 3.447186843808875*^9, 3.4475138541966476`*^9, 
   3.4480255175264997`*^9, 3.4481968997043753`*^9, 3.4483096787981253`*^9, 
   3.4483108196887503`*^9, 3.4483121511887503`*^9, 3.4483126327043753`*^9, 
   3.448375324125*^9, 3.448375439578125*^9, {3.448379915671875*^9, 
   3.44837992825*^9}, 3.4483988008125*^9, 3.44839885925*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Output: Mixer IF & filter & 12 dB attenuation & 2-way splitter\
\>", "Subsubtitle",
 CellChangeTimes->{{3.447176813277625*^9, 3.4471768245745*^9}, {
  3.447179727465125*^9, 3.447179780527625*^9}, {3.44718061510575*^9, 
  3.447180618512*^9}, {3.4471807273245*^9, 3.447180798715125*^9}, {
  3.44718143885575*^9, 3.447181444715125*^9}, {3.447181666152625*^9, 
  3.447181689246375*^9}, {3.447182003121375*^9, 3.4471820653245*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"OutputNoiseLow", "[", 
   RowBox[{"f_", ",", "in_", ",", "r_"}], "]"}], ":=", 
  SqrtBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"IFNoiseLow", "[", 
      RowBox[{"f", ",", "in", ",", "r"}], "]"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"AMPNoiseLow", "[", "f", "]"}], 
     "2"]}]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"OutputNoiseLevel", "[", 
   RowBox[{"f_", ",", "in_", ",", "r_"}], "]"}], ":=", 
  SqrtBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"IFNoiseLevel", "[", 
      RowBox[{"f", ",", "in", ",", "r"}], "]"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"AMPNoiseLevel", "[", "f", "]"}], "2"], "+", 
    RowBox[{"4", 
     SuperscriptBox[
      RowBox[{"NoiseLevelBottom", "[", "f", "]"}], 
      "2"]}]}]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"OutputNoise", "[", 
   RowBox[{"f_", ",", "in1_", ",", "in2_", ",", "r_"}], "]"}], ":=", 
  SqrtBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"OutputNoiseLow", "[", 
      RowBox[{"f", ",", "in1", ",", "r"}], "]"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"OutputNoiseLevel", "[", 
      RowBox[{"f", ",", "in2", ",", "r"}], "]"}], "2"]}]]}]}], "Input",
 CellChangeTimes->{{3.44717687041825*^9, 3.44717694704325*^9}, {
   3.447177021371375*^9, 3.44717710041825*^9}, {3.44717717273075*^9, 
   3.44717719435575*^9}, {3.447177984637*^9, 3.447178025762*^9}, 
   3.447179169262*^9, 3.447179208496375*^9, 3.447179401808875*^9, 
   3.447179492965125*^9, {3.44718018479325*^9, 3.4471803183245*^9}, {
   3.447180421012*^9, 3.447180424996375*^9}, {3.447180502371375*^9, 
   3.44718050604325*^9}, {3.447180562387*^9, 3.447180586527625*^9}, {
   3.447180834246375*^9, 3.447180934683875*^9}, {3.447181026121375*^9, 
   3.447181029090125*^9}, {3.447181461933875*^9, 3.447181500715125*^9}, {
   3.447181601621375*^9, 3.4471816023245*^9}, {3.447181705058875*^9, 
   3.447181769137*^9}, {3.4471820948245*^9, 3.447182147090125*^9}, {
   3.44718262579325*^9, 3.44718265941825*^9}, {3.447184983152625*^9, 
   3.447185005012*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"OutputNoiseLow", "[", "f_", "]"}], ":=", 
  SqrtBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"IFNoiseLow", "[", "f", "]"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"AMPNoiseLow", "[", "f", "]"}], 
     "2"]}]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"OutputNoiseLevel", "[", "f_", "]"}], ":=", 
  SqrtBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"IFNoiseLevel", "[", "f", "]"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"AMPNoiseLevel", "[", "f", "]"}], "2"], "+", 
    RowBox[{"4", 
     SuperscriptBox[
      RowBox[{"NoiseLevelBottom", "[", "f", "]"}], 
      "2"]}]}]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"OutputNoise", "[", "f_", "]"}], ":=", 
  SqrtBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"OutputNoiseLow", "[", "f", "]"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"OutputNoiseLevel", "[", "f", "]"}], "2"]}]]}]}], "Input",
 CellChangeTimes->{{3.44717687041825*^9, 3.44717694704325*^9}, {
   3.447177021371375*^9, 3.44717710041825*^9}, {3.44717717273075*^9, 
   3.44717719435575*^9}, {3.447177984637*^9, 3.447178025762*^9}, 
   3.447179169262*^9, 3.447179208496375*^9, 3.447179401808875*^9, 
   3.447179492965125*^9, {3.44718018479325*^9, 3.4471803183245*^9}, {
   3.447180421012*^9, 3.447180424996375*^9}, {3.447180502371375*^9, 
   3.44718050604325*^9}, {3.447180562387*^9, 3.447180586527625*^9}, {
   3.447180834246375*^9, 3.447180934683875*^9}, {3.447181026121375*^9, 
   3.447181029090125*^9}, {3.447181461933875*^9, 3.447181500715125*^9}, {
   3.447181601621375*^9, 3.4471816023245*^9}, {3.447181705058875*^9, 
   3.447181769137*^9}, {3.4471820948245*^9, 3.447182147090125*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogLinearPlot", "[", 
  RowBox[{
   RowBox[{"dB", "[", 
    RowBox[{"OutputNoise", "[", "f", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", "100", ",", "1*^6"}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
     "}"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "180"}], ",", 
      RowBox[{"-", "60"}]}], "}"}]}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Output phase noise\>\""}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Offset Frequency (Hz)\>\"", ",", "\"\<Phase Noise (dBc/Hz)\>\""}], 
     "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.447178040887*^9, 3.447178087215125*^9}, {
   3.44717856066825*^9, 3.447178578996375*^9}, {3.447178693902625*^9, 
   3.447178697246375*^9}, {3.447178737058875*^9, 3.447178771871375*^9}, 
   3.447179197152625*^9, {3.44717928091825*^9, 3.44717929735575*^9}, {
   3.44717950954325*^9, 3.447179606762*^9}, {3.44718005885575*^9, 
   3.44718008598075*^9}, 3.447180294887*^9, {3.447180324996375*^9, 
   3.447180338121375*^9}, 3.44718043004325*^9, {3.447181011527625*^9, 
   3.447181034371375*^9}, {3.447181581527625*^9, 3.447181583808875*^9}, 
   3.44718173385575*^9, 3.4471817960745*^9, {3.4471820833245*^9, 
   3.44718208860575*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwV1Xk01VsUB3CZMiWRMa7pzpeSZB52g4pKGZ5kKNzL60mSFKKbRKFMpUEJ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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->NCache[{
     Log[100], -180}, {4.605170185988092, -180}],
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  Frame->True,
  FrameLabel->{
    FormBox["\"Offset Frequency (Hz)\"", TraditionalForm], 
    FormBox["\"Phase Noise (dBc/Hz)\"", TraditionalForm]},
  FrameTicks->
   FrontEndValueCache[{{Automatic, Automatic}, {{{4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["6", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
        FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}, {{
     Automatic, Automatic}, {{{4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["6", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
        FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}],
  GridLines->{{4.605170185988092, 6.907755278982137, 9.210340371976184, 
    11.512925464970229`, 13.815510557964274`, 5.298317366548036, 
    5.703782474656201, 5.991464547107982, 6.214608098422191, 
    6.396929655216146, 6.551080335043404, 6.684611727667927, 
    6.802394763324311, 7.600902459542082, 8.006367567650246, 
    8.294049640102028, 8.517193191416238, 8.699514748210191, 8.85366542803745,
     8.987196820661973, 9.104979856318357, 9.903487552536127, 
    10.308952660644293`, 10.596634733096073`, 10.819778284410283`, 
    11.002099841204238`, 11.156250521031495`, 11.289781913656018`, 
    11.407564949312402`, 12.206072645530174`, 12.611537753638338`, 
    12.89921982609012, 13.122363377404328`, 13.304684934198283`, 
    13.458835614025542`, 13.592367006650065`, 13.710150042306449`}, 
    Automatic},
  Method->{},
  PlotLabel->FormBox["\"Output phase noise\"", TraditionalForm],
  PlotRange->NCache[{{
      Log[100], 
      Log[1000000]}, {-180, -60}}, {{4.605170185988092, 
     13.815510557964274`}, {-180, -60}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {None, None}},
  Ticks->{{{4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["4", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["5", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["6", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {5.298317366548036, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.903487552536127, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.308952660644293`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.596634733096073`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.819778284410283`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.002099841204238`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.156250521031495`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.289781913656018`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.407564949312402`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.206072645530174`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.611537753638338`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.89921982609012, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.122363377404328`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.304684934198283`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.458835614025542`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.592367006650065`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.710150042306449`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, Automatic}]], "Output",
 CellChangeTimes->{{3.447182141746375*^9, 3.44718214966825*^9}, 
   3.447182609996375*^9, 3.447185187340125*^9, 3.44718568816825*^9, 
   3.44718684448075*^9, 3.447513854837187*^9, 3.4480255185889997`*^9, 
   3.4481969003137503`*^9, 3.4483096794387503`*^9, 3.4483108203293753`*^9, 
   3.4483121518293753`*^9, 3.4483126333762503`*^9, 3.448375324328125*^9, 
   3.448375440046875*^9, {3.448379916140625*^9, 3.44837992871875*^9}, 
   3.44839880121875*^9, 3.448398859625*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Output after second frequency difference divider", "Subsubtitle",
 CellChangeTimes->{{3.447176813277625*^9, 3.4471768245745*^9}, {
  3.447179727465125*^9, 3.447179780527625*^9}, {3.44718061510575*^9, 
  3.447180618512*^9}, {3.4471807273245*^9, 3.447180798715125*^9}, {
  3.44718143885575*^9, 3.447181444715125*^9}, {3.447181666152625*^9, 
  3.447181689246375*^9}, {3.447182003121375*^9, 3.4471820653245*^9}, {
  3.447182676512*^9, 3.447182687840125*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Output2NoiseLow", "[", "f_", "]"}], ":=", 
  SqrtBox[
   SuperscriptBox[
    RowBox[{"OutputNoiseLow", "[", 
     RowBox[{"f", ",", "OutputNoiseLow", ",", "10"}], "]"}], 
    "2"]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Output2NoiseLevel", "[", "f_", "]"}], ":=", 
  SqrtBox[
   SuperscriptBox[
    RowBox[{"OutputNoiseLevel", "[", 
     RowBox[{"f", ",", "OutputNoiseLevel", ",", "10"}], "]"}], 
    "2"]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Output2Noise", "[", "f_", "]"}], ":=", 
  SqrtBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"Output2NoiseLow", "[", "f", "]"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"Output2NoiseLevel", "[", "f", "]"}], "2"]}]]}]}], "Input",
 CellChangeTimes->{{3.44717687041825*^9, 3.44717694704325*^9}, {
   3.447177021371375*^9, 3.44717710041825*^9}, {3.44717717273075*^9, 
   3.44717719435575*^9}, {3.447177984637*^9, 3.447178025762*^9}, 
   3.447179169262*^9, 3.447179208496375*^9, 3.447179401808875*^9, 
   3.447179492965125*^9, {3.44718018479325*^9, 3.4471803183245*^9}, {
   3.447180421012*^9, 3.447180424996375*^9}, {3.447180502371375*^9, 
   3.44718050604325*^9}, {3.447180562387*^9, 3.447180586527625*^9}, {
   3.447180834246375*^9, 3.447180934683875*^9}, {3.447181026121375*^9, 
   3.447181029090125*^9}, {3.447181461933875*^9, 3.447181500715125*^9}, {
   3.447181601621375*^9, 3.4471816023245*^9}, {3.447181705058875*^9, 
   3.447181769137*^9}, {3.4471820948245*^9, 3.447182147090125*^9}, {
   3.447182702340125*^9, 3.447182704433875*^9}, {3.4471827378245*^9, 
   3.447182777496375*^9}, {3.447182882308875*^9, 3.44718288723075*^9}, {
   3.44718503304325*^9, 3.447185036058875*^9}, {3.44718521616825*^9, 
   3.447185217402625*^9}, {3.44718584060575*^9, 3.4471858424495*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogLinearPlot", "[", 
  RowBox[{
   RowBox[{"dB", "[", 
    RowBox[{"Output2Noise", "[", "f", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", "100", ",", "1*^6"}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
     "}"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "180"}], ",", 
      RowBox[{"-", "60"}]}], "}"}]}], ",", 
   RowBox[{
   "PlotLabel", "\[Rule]", "\"\<Second stage output phase noise\>\""}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Offset Frequency (Hz)\>\"", ",", "\"\<Phase Noise (dBc/Hz)\>\""}], 
     "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.447178040887*^9, 3.447178087215125*^9}, {
   3.44717856066825*^9, 3.447178578996375*^9}, {3.447178693902625*^9, 
   3.447178697246375*^9}, {3.447178737058875*^9, 3.447178771871375*^9}, 
   3.447179197152625*^9, {3.44717928091825*^9, 3.44717929735575*^9}, {
   3.44717950954325*^9, 3.447179606762*^9}, {3.44718005885575*^9, 
   3.44718008598075*^9}, 3.447180294887*^9, {3.447180324996375*^9, 
   3.447180338121375*^9}, 3.44718043004325*^9, {3.447181011527625*^9, 
   3.447181034371375*^9}, {3.447181581527625*^9, 3.447181583808875*^9}, 
   3.44718173385575*^9, 3.4471817960745*^9, {3.4471820833245*^9, 
   3.44718208860575*^9}, 3.447182784637*^9, {3.447182902590125*^9, 
   3.44718291398075*^9}, {3.447185247371375*^9, 3.447185254340125*^9}, 
   3.447185818902625*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwd1Hc8Vm0YB3C7oSIiqYxnD6SSiHRJsre8kv08UkKSoojKTFkRiYyMCCUj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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->NCache[{
     Log[100], -180}, {4.605170185988092, -180}],
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  Frame->True,
  FrameLabel->{
    FormBox["\"Offset Frequency (Hz)\"", TraditionalForm], 
    FormBox["\"Phase Noise (dBc/Hz)\"", TraditionalForm]},
  FrameTicks->
   FrontEndValueCache[{{Automatic, Automatic}, {{{4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["6", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
        FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}, {{
     Automatic, Automatic}, {{{4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["6", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
        FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}],
  GridLines->{{4.605170185988092, 6.907755278982137, 9.210340371976184, 
    11.512925464970229`, 13.815510557964274`, 5.298317366548036, 
    5.703782474656201, 5.991464547107982, 6.214608098422191, 
    6.396929655216146, 6.551080335043404, 6.684611727667927, 
    6.802394763324311, 7.600902459542082, 8.006367567650246, 
    8.294049640102028, 8.517193191416238, 8.699514748210191, 8.85366542803745,
     8.987196820661973, 9.104979856318357, 9.903487552536127, 
    10.308952660644293`, 10.596634733096073`, 10.819778284410283`, 
    11.002099841204238`, 11.156250521031495`, 11.289781913656018`, 
    11.407564949312402`, 12.206072645530174`, 12.611537753638338`, 
    12.89921982609012, 13.122363377404328`, 13.304684934198283`, 
    13.458835614025542`, 13.592367006650065`, 13.710150042306449`}, 
    Automatic},
  Method->{},
  PlotLabel->FormBox["\"Second stage output phase noise\"", TraditionalForm],
  PlotRange->NCache[{{
      Log[100], 
      Log[1000000]}, {-180, -60}}, {{4.605170185988092, 
     13.815510557964274`}, {-180, -60}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {None, None}},
  Ticks->{{{4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["4", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["5", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["6", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {5.298317366548036, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.903487552536127, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.308952660644293`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.596634733096073`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.819778284410283`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.002099841204238`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.156250521031495`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.289781913656018`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.407564949312402`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.206072645530174`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.611537753638338`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.89921982609012, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.122363377404328`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.304684934198283`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.458835614025542`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.592367006650065`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.710150042306449`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, Automatic}]], "Output",
 CellChangeTimes->{
  3.447186137012*^9, 3.447186845527625*^9, 3.447513855899544*^9, 
   3.4480255204952497`*^9, 3.4481969013606253`*^9, 3.4483096804856253`*^9, 
   3.4483108214231253`*^9, 3.4483121529075003`*^9, 3.4483126343918753`*^9, 
   3.4483753245625*^9, 3.448375440796875*^9, {3.44837991690625*^9, 
   3.448379929484375*^9}, 3.448398801890625*^9, 3.44839886028125*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.447182141746375*^9, 3.44718214966825*^9}, 
   3.447182609996375*^9, 3.447182785933875*^9, {3.44718289154325*^9, 
   3.447182915652625*^9}, 3.44718504216825*^9, 3.447185144387*^9, {
   3.44718519291825*^9, 3.447185255058875*^9}, 3.447185503215125*^9, {
   3.4471858126995*^9, 3.44718584985575*^9}, {3.44718613048075*^9, 
   3.447186134058875*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Comparison", "Subsubtitle",
 CellChangeTimes->{{3.447176813277625*^9, 3.4471768245745*^9}, {
  3.447179727465125*^9, 3.447179780527625*^9}, {3.44718061510575*^9, 
  3.447180618512*^9}, {3.4471807273245*^9, 3.447180798715125*^9}, {
  3.44718143885575*^9, 3.447181444715125*^9}, {3.447181666152625*^9, 
  3.447181689246375*^9}, {3.447182003121375*^9, 3.4471820653245*^9}, {
  3.447182676512*^9, 3.447182687840125*^9}, {3.447182951777625*^9, 
  3.447182954871375*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ShowLegend", "[", 
   RowBox[{
    RowBox[{"LogLinearPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"dB", "[", 
         RowBox[{"VCONoise", "[", "f", "]"}], "]"}], ",", 
        RowBox[{"dB", "[", 
         RowBox[{"VCOScaledNoise", "[", "f", "]"}], "]"}], ",", 
        RowBox[{"dB", "[", 
         RowBox[{"OCXONoise", "[", "f", "]"}], "]"}], ",", 
        RowBox[{"dB", "[", 
         RowBox[{"OutputNoise", "[", "f", "]"}], "]"}], ",", 
        RowBox[{"dB", "[", 
         RowBox[{"Output2Noise", "[", "f", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"f", ",", "100", ",", "1*^6"}], "}"}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
           RowBox[{"Darker", "[", "Brown", "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Brown"}],
           "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
           RowBox[{"Darker", "[", "Green", "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Blue"}], 
          "}"}]}], "}"}]}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "180"}], ",", 
         RowBox[{"-", "60"}]}], "}"}]}], ",", 
      RowBox[{
      "PlotLabel", "\[Rule]", "\"\<Phase noise comparison (SSB)\>\""}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Offset Frequency (Hz)\>\"", ",", 
         "\"\<Phase Noise (dBc/Hz)\>\""}], "}"}]}], ",", 
      RowBox[{"ImageSize", "\[Rule]", 
       RowBox[{"Scaled", "[", "0.85", "]"}]}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Darker", "[", "Brown", "]"}], ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<VCO\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Brown", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<Scaled VCO\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Darker", "[", "Green", "]"}], ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<OCXO\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Red", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<First stage\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Blue", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<Second stage\>\""}], "}"}]}], "}"}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
         RowBox[{"FontSize", "\[Rule]", "10"}]}], "}"}]}], ",", 
      RowBox[{"LegendPosition", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0.7", ",", 
         RowBox[{"-", "0.0"}]}], "}"}]}], ",", 
      RowBox[{"LegendSize", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0.5", ",", "0.3"}], "}"}]}], ",", 
      RowBox[{"LegendTextSpace", "\[Rule]", "5"}], ",", 
      RowBox[{"LegendShadow", "\[Rule]", "None"}]}], "}"}]}], "]"}], "//", 
  "Quiet"}]], "Input",
 CellChangeTimes->{{3.447178040887*^9, 3.447178087215125*^9}, {
   3.44717856066825*^9, 3.447178578996375*^9}, {3.447178693902625*^9, 
   3.447178697246375*^9}, {3.447178737058875*^9, 3.447178771871375*^9}, 
   3.447179197152625*^9, {3.44717928091825*^9, 3.44717929735575*^9}, {
   3.44717950954325*^9, 3.447179606762*^9}, {3.44718005885575*^9, 
   3.44718008598075*^9}, 3.447180294887*^9, {3.447180324996375*^9, 
   3.447180338121375*^9}, 3.44718043004325*^9, {3.447181011527625*^9, 
   3.447181034371375*^9}, {3.447181581527625*^9, 3.447181583808875*^9}, 
   3.44718173385575*^9, 3.4471817960745*^9, {3.4471820833245*^9, 
   3.44718208860575*^9}, 3.447182784637*^9, {3.447182902590125*^9, 
   3.44718291398075*^9}, {3.447182968090125*^9, 3.447183054371375*^9}, {
   3.447183096512*^9, 3.447183100590125*^9}, {3.44718313610575*^9, 
   3.447183175637*^9}, {3.447183209246375*^9, 3.447183275262*^9}, {
   3.447183352121375*^9, 3.447183358965125*^9}, {3.447183421996375*^9, 
   3.447183486777625*^9}, {3.44718357891825*^9, 3.447183618465125*^9}, {
   3.44718368448075*^9, 3.44718376041825*^9}, {3.447183832371375*^9, 
   3.4471838706995*^9}, {3.447184048871375*^9, 3.447184072762*^9}, {
   3.447184117433875*^9, 3.44718412060575*^9}, {3.447184165433875*^9, 
   3.447184179887*^9}, {3.447184217121375*^9, 3.44718421873075*^9}, {
   3.447184253465125*^9, 3.44718435710575*^9}, {3.44718442904325*^9, 
   3.44718453448075*^9}, {3.447184581527625*^9, 3.44718458866825*^9}, {
   3.447184624402625*^9, 3.447184704762*^9}, 3.447185885808875*^9, {
   3.447186034637*^9, 3.4471860470745*^9}, {3.44718621960575*^9, 
   3.4471862815745*^9}, {3.447186678496375*^9, 3.447186734246375*^9}, 
   3.447188144715125*^9, {3.448375889296875*^9, 3.44837588953125*^9}, {
   3.448398896984375*^9, 3.44839889828125*^9}}],

Cell[BoxData[
 GraphicsBox[{InsetBox[
    GraphicsBox[{{}, {}, 
      {RGBColor[0.4, 0.2666666666666667, 0.13333333333333336`], Thickness[
       0.007], LineBox[CompressedData["
1:eJwd030wFHgYB/CNvaJtnMtLKW1Wu9hdqssk66weSc6Z9bpZltXuinDGttyR
Mk66hLsaFXNhbkPWyy1T9jQi9JSjo5ScTK1zdXRRlMXI0Xbud/fMfOc7n/n+
/TDkitA4IwqF4kfyXxvNPG2Nb7YAyv8XiOvNA0K/fWMBp5Zqk54mBOLOK31G
r+ssYUPbr/7dbUEY0lWprpJawfUrZps8c4Ixad6p5o2jNexpGbcedAlBmiJq
fOpPawhp2+2wqj8E1cv87CzNBvA0VTBOpYeit8UxmlS5Ec64ixIWbMIwLkPy
+B3bBqoFRTuHroZh7tScYeucDQhmihklQUJ01LjKDA2bYMgjZ92nY0J8uHiv
hXt4M9SOUuVlioOoEFomv+HYwi1lpl/u6nD8wbBGIn9hC9Nj5VmrzodjS7NG
k9i4BaxzFmYamSLULdVMd6XSYSDobiL/ZxGeLhQkPeJsheqXhlwbtwhkc6t9
lXNb4fiTeueB2xGoof22XR5uBznCpYJd+yKxw7ThlfCmHTg94olc7kVi8INr
W5R0BvTcq6q8ECTGWnea/uVxBkynSTV+vWJ8/xN/lvWMAV77dhQdDIhCi67u
ok5Pe5Dq7QpMu6KwoTKzPueSPexluQ4PuUWjd/5HszSDPTRaNkV0a6OxzHJi
WB+xDX7/uNf4NVOCM3UVU6qObRBZeHjS9LIEe4zzMtPtmBD8uVIXZxWDMupt
dW0WE2g+Mu2J3Bj8e90Qpeo5E+RfWnUlLcZg2E3P5QU+C6LT8gLFsYdwx85H
yWmlLBi0ynWzuH8ITRr5Zm0GFvTVl/ccoEtR/XBFII50gEHngbnPQqXotVza
3tXhADUFx6+tKZRieV9Bb95mR8jubRLXd0gxU6YOSstwhJMfePWjM1IMo5RS
2SOOIFl9hDPGkuHs/jGRu7sT9At4UZMiGX5/3lhn/qMT/NKUO339rAzrqoMf
r6ewYS591wX7OzLMl8ynpESzIWP+/f2rczI8TE/ZcxHZoB3kf6d3kCP1tJfq
EzoHEr6YfSIUyZGl9chuzeTAqt1RC9F5cvSZMDvLGeWA2IddrrtB9jvuHgs8
Lrxt1wvFE3I0VntYF6i4cCzepfmvjbH47tZ22xLidKp70RTxpM7evpJYf8Qr
eZb4gTlteyvxrWwv5gfisqwR31fEoxO0YkubWNwlzPra/zIXaPkjqT7EUuPO
IdMKLvkvgUslcRhdq7Mizlw9YFJLfIBX85xB/Ed/4IsGYmfFuWkecZ9qb/kN
4kVdDDWJ2Mn3rckA8Tntimsf8eipb8b/IT7ZP88bJi4909lJ3RSLX01O7B0j
fu2/VLqWWEwfCFgmfmwqD7YmZhVWxHIquaBKpXS4EG9UFye6ETsf2XLJlXgt
5iv2EbvYuKXxiPULR0+IiVeaxWxf4nHzuJPxxHmqeGoA8TA38kwq8eT+lGfB
xL0HBGezidfVKdvCidtl3hcLie/ePVoSTfwvjnoMWw==
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], Thickness[0.007], LineBox[CompressedData["
1:eJwV03s01FsbB3DHKGnkdcati8REY36/UifvqSGcB130ilONk1sjM34saRq6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        "]]}, 
      {RGBColor[0, 
        NCache[
         Rational[2, 3], 0.6666666666666666], 0], Thickness[0.007], 
       LineBox[CompressedData["
1:eJwV1nk8VdsXAHCZKmQq8xByz73n3pJKhkjLk15CSirJzPF6EkUZ4lcqSuoh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        "]]}, 
      {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwV1Xk01VsUB3CZMiWRMa7pzpeSZB52g4pKGZ5kKNzL60mSFKKbRKFMpUEJ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        "]]}, 
      {RGBColor[0, 0, 1], Thickness[0.007], LineBox[CompressedData["
1:eJwd1Hc8Vm0YB3C7oSIiqYxnD6SSiHRJsre8kv08UkKSoojKTFkRiYyMCCUj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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->NCache[{
        Log[100], -180}, {4.605170185988092, -180}],
     BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
     Frame->True,
     FrameLabel->{
       FormBox["\"Offset Frequency (Hz)\"", TraditionalForm], 
       FormBox["\"Phase Noise (dBc/Hz)\"", TraditionalForm]},
     FrameTicks->
      FrontEndValueCache[{{Automatic, Automatic}, {{{4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {9.210340371976184, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["4", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["5", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["6", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.206072645530174`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.611537753638338`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.89921982609012, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.122363377404328`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.304684934198283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.458835614025542`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.592367006650065`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.710150042306449`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
           FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
           FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
           FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.206072645530174`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.611537753638338`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.89921982609012, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.122363377404328`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.304684934198283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.458835614025542`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.592367006650065`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.710150042306449`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}}, {{
        Automatic, Automatic}, {{{4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {9.210340371976184, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["4", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["5", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["6", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.206072645530174`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.611537753638338`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.89921982609012, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.122363377404328`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.304684934198283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.458835614025542`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.592367006650065`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.710150042306449`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
           FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
           FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
           FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.206072645530174`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.611537753638338`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.89921982609012, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.122363377404328`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.304684934198283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.458835614025542`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.592367006650065`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.710150042306449`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}}],
     GridLines->{{4.605170185988092, 6.907755278982137, 9.210340371976184, 
       11.512925464970229`, 13.815510557964274`, 5.298317366548036, 
       5.703782474656201, 5.991464547107982, 6.214608098422191, 
       6.396929655216146, 6.551080335043404, 6.684611727667927, 
       6.802394763324311, 7.600902459542082, 8.006367567650246, 
       8.294049640102028, 8.517193191416238, 8.699514748210191, 
       8.85366542803745, 8.987196820661973, 9.104979856318357, 
       9.903487552536127, 10.308952660644293`, 10.596634733096073`, 
       10.819778284410283`, 11.002099841204238`, 11.156250521031495`, 
       11.289781913656018`, 11.407564949312402`, 12.206072645530174`, 
       12.611537753638338`, 12.89921982609012, 13.122363377404328`, 
       13.304684934198283`, 13.458835614025542`, 13.592367006650065`, 
       13.710150042306449`}, Automatic},
     ImageSize->Scaled[0.85],
     Method->{},
     PlotLabel->FormBox["\"Phase noise comparison (SSB)\"", TraditionalForm],
     PlotRange->NCache[{{
         Log[100], 
         Log[1000000]}, {-180, -60}}, {{4.605170185988092, 
        13.815510557964274`}, {-180, -60}}],
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], {None, None}},
     Ticks->{{{4.605170185988092, 
         FormBox["100", TraditionalForm]}, {6.907755278982137, 
         FormBox["1000", TraditionalForm]}, {9.210340371976184, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox["4", Power, Editable -> True, Selectable -> True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox["5", Power, Editable -> True, Selectable -> True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox["6", Power, Editable -> True, Selectable -> True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.396929655216146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.551080335043404, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.684611727667927, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.802394763324311, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {7.600902459542082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.006367567650246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.294049640102028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.517193191416238, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.699514748210191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.85366542803745, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.987196820661973, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {9.104979856318357, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {9.903487552536127, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.308952660644293`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.596634733096073`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.819778284410283`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.002099841204238`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.156250521031495`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.289781913656018`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.407564949312402`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {12.206072645530174`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {12.611537753638338`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {12.89921982609012, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {13.122363377404328`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {13.304684934198283`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {13.458835614025542`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {13.592367006650065`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {13.710150042306449`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, Automatic}], {-1, -0.6180339887498948}, {
    Left, Bottom}, {2, 1.2360679774997896`}], InsetBox[
    GraphicsBox[{{{InsetBox[
         GraphicsBox[
          {RGBColor[0, 0, 1], RectangleBox[{1, 1}]}], {0.08, 0.08}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"Second stage\"\>", {1.21, 0.58}, {-1, 0}, Automatic, {1,
          0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[1, 0, 0], RectangleBox[{1, 1}]}], {0.08, 1.24}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"First stage\"\>", {1.21, 1.74}, {-1, 0}, Automatic, {1, 
         0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[0, 
            NCache[
             Rational[2, 3], 0.6666666666666666], 0], 
           RectangleBox[{1, 1}]}], {0.08, 2.4}, {Left, Bottom}, {1, 1}], 
        InsetBox["\<\"OCXO\"\>", {1.21, 2.9}, {-1, 0}, Automatic, {1, 0}]}, {
        InsetBox[
         GraphicsBox[
          {RGBColor[0.6, 0.4, 0.2], RectangleBox[{1, 1}]}], {0.08, 3.56}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"Scaled VCO\"\>", {1.21, 4.0600000000000005`}, {-1, 0}, 
         Automatic, {1, 0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[0.4, 0.2666666666666667, 0.13333333333333336`], 
           RectangleBox[{1, 1}]}], {0.08, 4.72}, {Left, Bottom}, {1, 1}], 
        InsetBox["\<\"VCO\"\>", {1.21, 5.22}, {-1, 0}, Automatic, {1, 
         0}]}}, {}},
     AspectRatio->0.6,
     BaseStyle->{FontFamily -> "Helvetica", FontSize -> 10},
     PlotRange->{{-0.1, 6.26}, {-0.1, 5.8999999999999995`}}], {0.7, 0.}, {
    Left, Bottom}, {0.5, 0.3}]},
  AspectRatio->Automatic,
  Background->None,
  ColorOutput->Automatic,
  ImageSize->Scaled[0.85],
  PlotRange->All]], "Output",
 CellChangeTimes->{
  3.4471861155745*^9, {3.447186234371375*^9, 3.447186284371375*^9}, 
   3.447186698871375*^9, 3.447186737902625*^9, 3.44718684885575*^9, 
   3.447188147933875*^9, 3.4475138596021714`*^9, 3.4480255238389997`*^9, 
   3.4481969048450003`*^9, 3.4483096837200003`*^9, 3.4483108247981253`*^9, 
   3.4483121563606253`*^9, 3.4483126377512503`*^9, 3.448375325*^9, 
   3.44837544359375*^9, 3.448375892625*^9, {3.448379919890625*^9, 
   3.448379932359375*^9}, 3.448398804*^9, 3.44839886234375*^9, 
   3.44839890090625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ShowLegend", "[", 
   RowBox[{
    RowBox[{"LogLogPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"2", "f", " ", 
         RowBox[{"VCONoise", "[", "f", "]"}]}], ",", 
        RowBox[{"2", "f", " ", 
         RowBox[{"VCOScaledNoise", "[", "f", "]"}]}], ",", 
        RowBox[{"2", "f", " ", 
         RowBox[{"OCXONoise", "[", "f", "]"}]}], ",", 
        RowBox[{"2", "f", " ", 
         RowBox[{"OutputNoise", "[", "f", "]"}]}], ",", 
        RowBox[{"2", "f", " ", 
         RowBox[{"Output2Noise", "[", "f", "]"}]}], ",", 
        RowBox[{
         RowBox[{"50*^-3", 
          FractionBox["100", "f"]}], "+", "10*^-3"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"f", ",", "100", ",", "1*^5"}], "}"}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
           RowBox[{"Darker", "[", "Brown", "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Brown"}],
           "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
           RowBox[{"Darker", "[", "Green", "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Blue"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Black"}],
           "}"}]}], "}"}]}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"1*^-4", ",", "1"}], "}"}]}], ",", 
      RowBox[{
      "PlotLabel", "\[Rule]", 
       "\"\<Frequency noise comparison (double pass AOM)\>\""}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Offset Frequency (Hz)\>\"", ",", 
         "\"\<Frequency Noise (Hz/\!\(\*SqrtBox[\(Hz\)]\))\>\""}], "}"}]}], 
      ",", 
      RowBox[{"ImageSize", "\[Rule]", 
       RowBox[{"Scaled", "[", "0.85", "]"}]}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Darker", "[", "Brown", "]"}], ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<VCO\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Brown", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<Scaled VCO\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Darker", "[", "Green", "]"}], ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<OCXO\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Red", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<First stage\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Blue", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<Second stage\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Black", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<Current\>\""}], "}"}]}], "}"}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
         RowBox[{"FontSize", "\[Rule]", "10"}]}], "}"}]}], ",", 
      RowBox[{"LegendPosition", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0.8", ",", 
         RowBox[{"-", "0.0"}]}], "}"}]}], ",", 
      RowBox[{"LegendSize", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0.5", ",", "0.3"}], "}"}]}], ",", 
      RowBox[{"LegendTextSpace", "\[Rule]", "5"}], ",", 
      RowBox[{"LegendShadow", "\[Rule]", "None"}]}], "}"}]}], "]"}], "//", 
  "Quiet"}]], "Input",
 CellChangeTimes->{{3.447178040887*^9, 3.447178087215125*^9}, {
   3.44717856066825*^9, 3.447178578996375*^9}, {3.447178693902625*^9, 
   3.447178697246375*^9}, {3.447178737058875*^9, 3.447178771871375*^9}, 
   3.447179197152625*^9, {3.44717928091825*^9, 3.44717929735575*^9}, {
   3.44717950954325*^9, 3.447179606762*^9}, {3.44718005885575*^9, 
   3.44718008598075*^9}, 3.447180294887*^9, {3.447180324996375*^9, 
   3.447180338121375*^9}, 3.44718043004325*^9, {3.447181011527625*^9, 
   3.447181034371375*^9}, {3.447181581527625*^9, 3.447181583808875*^9}, 
   3.44718173385575*^9, 3.4471817960745*^9, {3.4471820833245*^9, 
   3.44718208860575*^9}, 3.447182784637*^9, {3.447182902590125*^9, 
   3.44718291398075*^9}, {3.447182968090125*^9, 3.447183054371375*^9}, {
   3.447183096512*^9, 3.447183100590125*^9}, {3.44718313610575*^9, 
   3.447183175637*^9}, {3.447183209246375*^9, 3.447183275262*^9}, {
   3.447183352121375*^9, 3.447183358965125*^9}, {3.447183421996375*^9, 
   3.447183486777625*^9}, {3.44718357891825*^9, 3.447183618465125*^9}, {
   3.44718368448075*^9, 3.44718376041825*^9}, {3.447183832371375*^9, 
   3.4471838706995*^9}, {3.447184048871375*^9, 3.447184072762*^9}, {
   3.447184117433875*^9, 3.44718412060575*^9}, {3.447184165433875*^9, 
   3.447184179887*^9}, {3.447184217121375*^9, 3.44718421873075*^9}, {
   3.447184253465125*^9, 3.44718435710575*^9}, {3.44718442904325*^9, 
   3.44718453448075*^9}, {3.447184581527625*^9, 3.44718458866825*^9}, {
   3.447184624402625*^9, 3.447184704762*^9}, 3.447185885808875*^9, {
   3.447186034637*^9, 3.4471860470745*^9}, {3.44718621960575*^9, 
   3.4471862815745*^9}, {3.447186678496375*^9, 3.447186734246375*^9}, 
   3.447188144715125*^9, {3.448375231609375*^9, 3.44837531384375*^9}, {
   3.448375460984375*^9, 3.44837550709375*^9}, {3.448375565625*^9, 
   3.448375571640625*^9}, {3.448375694421875*^9, 3.448375698671875*^9}, {
   3.4483757501875*^9, 3.448375756234375*^9}, {3.448375796609375*^9, 
   3.448375862875*^9}, {3.44837589746875*^9, 3.44837589771875*^9}, {
   3.448376229484375*^9, 3.448376252359375*^9}, {3.44837631034375*^9, 
   3.448376326328125*^9}, {3.448376821171875*^9, 3.448376830421875*^9}, {
   3.448376953703125*^9, 3.44837707390625*^9}, {3.448398786171875*^9, 
   3.44839879225*^9}, {3.44839892409375*^9, 3.448398939375*^9}, {
   3.448399242875*^9, 3.448399245515625*^9}}],

Cell[BoxData[
 GraphicsBox[{InsetBox[
    GraphicsBox[{{}, {}, 
      {RGBColor[0.4, 0.2666666666666667, 0.13333333333333336`], Thickness[
       0.007], LineBox[CompressedData["
1:eJwV0Xk41XkXAHC7+7O9de27e6/7Q2pmKEtZOtfMKE/lcm01tpslsgzJEkUR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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], Thickness[0.007], LineBox[CompressedData["
1:eJwV1nk4VG0UAPCEEGMZXGTJMPctSUpSIh2lRQuSRCmytpAWUnxkq9QXJUkS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        "]]}, 
      {RGBColor[0, 
        NCache[
         Rational[2, 3], 0.6666666666666666], 0], Thickness[0.007], 
       LineBox[CompressedData["
1:eJwd13k8VdsXAHApaaCQWbrH2eeaCik/5JGlQRpIZEiJZ06UlAxFFJWiiUIq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        "]]}, 
      {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwV1nk8VdsXAPCikodCpot7uPtcFUIaKIXVJHk/FCFFhCgVSkVIQkTmFDKk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        "]]}, 
      {RGBColor[0, 0, 1], Thickness[0.007], LineBox[CompressedData["
1:eJwV13k4VVsUAHBDpkhcQ+a7z8UtQyOJMixS1EtCoVSUyFBIpqRSRMYUGSKU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        "]]}, 
      {GrayLevel[0], Thickness[0.007], LineBox[CompressedData["
1:eJwVzns01HkYBnA7MWJmMvPNyHUYYybEEnazKr1sxTnbskuLUlHTKHJru0wq
VG7LSjJIK0qT7sSOytLlFSprFSutsytdVLq5RYp2td/fH+95zuc85znnFa+L
C1CwtLS0/Ogx+cZrTnP1JgKPbUyzHuxlo6oyRvoghkBJ3nmtXWls9DCrSpse
T8BRtE1inMnGn8bcloZtJTAvzinm+1w2Sk553uImEnDw+MDDUjau5Aa0bMgh
IN7nE7W/no237u9os6gmcEWZWNs/xsbjm252ZY4TgKJ7Y6oIXQwsKz9vsH8m
DDVb6PNDpuMZf52RYhND0FT81jjkooc3Tsk2RagNgYNrnf5k6WMXJ/tcr7sQ
BlSqaz49+pjzYvOK1U1CuC50fvT5UQ56dRS3ZYYawUPBgmDLSC5ekmcox4aM
YEj0TJQh5WFH7GiOYucs2NWeEW31Bw/709TRqXxjKKpXbknZPgPVwnuXzxwx
hnMu12IbOAYo9r/pzpOZwKslup1N+QZ4OP/fZFG9CZxQHE5NMeDj5QCN25dL
TeFD7DF3p2/4eNe88sLHHlPwbdMUadL5eCY3KvxTvBl0337nY3CFj3aJp5L0
PpqB+tBuhx0v+Xhim628IdccKhWqUBcjATY/t7uYbG4Bb43GQgfmC/CRPK7t
tcYCnKs8vS+FC/Bq1nazQl8RfJU/5TaxR4BgP3V/aacIoj3r/ntaTPuulpDy
SEvQ054KfHGR7ieEvvrjlrC8sc0xoVWAfX0HL91fZAW6z3rSlvUKsLPdwyE5
ywpqAyP3hg8L0GhS3W3fbgW231ZqLf4kwCA7p40VZmLYPNO8agePoNKxmNxV
iOHaQmVqhQnB1zG3RkfPimFJ3fXnlRKCq2qEtUPvxDBj1YMQV0eCVvNsNIPz
raGoLG9qwo1gc87Mluw91vDE1iO6cj7BDW9sbnzWag2Dw/1qrjfdp4+PJPAl
MPI+LHuhD0F/2SvtllAJuGVHqmTLCBawSv3MjktAO6VaIP2O4BWNi4bbLwHu
4hBXVSDBR1EvJ+/NtYF3rzi/dwQRDF4TnnBMaQO9qtamrSsItgZP/O3daANh
Dxt4I6H0P9mW4FSeFL7IefyQt4bgbecK/ZYAKSTZn7ZrDiMY46VX9rRECn0O
rir5WoKKHGnstKdSWOn3DDXrCHpWWQc12MqAZf28p1NO0LDbSxy0RQal495v
+9YTXLhALBmslUG30Pc8KgjKT1pPX609G3QuWKbnRhD8pe4wN4JaK29uCeP2
O3xBHHUy7+saxgveT5nspda9s/4JY0Pff+aUU+/ZpvY8SH3zpcp/gPp4GO89
Y3tHnUOJOrPBu0K1QUUd7rW7OJ36o7ooiXHhD6NHD1DHu5YUMJ6W9Ph0GXW+
eXkj4547V+uaqcdnVVnmU++P397LY8+Guppf/2LclDrwxIhax716kPFk0fp+
S2q75Rd0CqgjGgKG51Kzgs+6MvYkTqwgallG8QHGW2Un2WHUGzsKTzI+62HB
2UidW3PwKuNZco7hTuojS9JfM/ZT7jNOoU4ZTWYVUqf+PGGeTb3CI8GEcd3R
eHEBtcj0R2fGw5p+aSl1V16UD+P/AVraI0I=
        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->NCache[{
        Log[100], -9.210340371976184}, {
       4.605170185988092, -9.210340371976184}],
     BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
     Frame->True,
     FrameLabel->{
       FormBox["\"Offset Frequency (Hz)\"", TraditionalForm], 
       FormBox[
       "\"Frequency Noise (Hz/\\!\\(\\*SqrtBox[\\(Hz\\)]\\))\"", 
        TraditionalForm]},
     FrameTicks->FrontEndValueCache[{{{{-9.210340371976182, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox[
               RowBox[{"-", "4"}], Power, Editable -> True, Selectable -> 
               True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0., 
           FormBox["1", TraditionalForm]}, {-8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.111728083308073, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.824046010856292, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.418580902748127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.264430222920869, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.1308988302963465`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.013115794639964, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{-9.210340371976182, 
           FormBox["\" \"", TraditionalForm]}, {-6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
           FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["\" \"", TraditionalForm]}, {0., 
           FormBox["\" \"", TraditionalForm]}, {-8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.111728083308073, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.824046010856292, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.418580902748127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.264430222920869, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.1308988302963465`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.013115794639964, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}, {{{9.210340371976184, 
           FormBox[
            InterpretationBox[
             RowBox[{"1", "\[Times]", 
               TagBox[
                SuperscriptBox[
                 TagBox["10", Power, Editable -> True, Selectable -> True], 
                 TagBox["4", Power, Editable -> True, Selectable -> True]], 
                InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
                Selectable -> False]}], 
             Row[{1., 
               Superscript[10., 4]}, "\[Times]"]], TraditionalForm]}, {
          10.819778284410283`, 
           FormBox[
            InterpretationBox[
             RowBox[{"5", "\[Times]", 
               TagBox[
                SuperscriptBox[
                 TagBox["10", Power, Editable -> True, Selectable -> True], 
                 TagBox["4", Power, Editable -> True, Selectable -> True]], 
                InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
                Selectable -> False]}], 
             Row[{5., 
               Superscript[10., 4]}, "\[Times]"]], TraditionalForm]}, {
          11.512925464970229`, 
           FormBox[
            InterpretationBox[
             RowBox[{"1", "\[Times]", 
               TagBox[
                SuperscriptBox[
                 TagBox["10", Power, Editable -> True, Selectable -> True], 
                 TagBox["5", Power, Editable -> True, Selectable -> True]], 
                InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
                Selectable -> False]}], 
             Row[{1., 
               Superscript[10., 5]}, "\[Times]"]], TraditionalForm]}, {
          13.122363377404328`, 
           FormBox[
            InterpretationBox[
             RowBox[{"5", "\[Times]", 
               TagBox[
                SuperscriptBox[
                 TagBox["10", Power, Editable -> True, Selectable -> True], 
                 TagBox["5", Power, Editable -> True, Selectable -> True]], 
                InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
                Selectable -> False]}], 
             Row[{5., 
               Superscript[10., 5]}, "\[Times]"]], TraditionalForm]}, {
          4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.214608098422191, 
           FormBox["500", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {8.517193191416238, 
           FormBox["5000", TraditionalForm]}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.206072645530174`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.611537753638338`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.89921982609012, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{9.210340371976184, 
           FormBox["\" \"", TraditionalForm]}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
           FormBox["\" \"", TraditionalForm]}, {13.122363377404328`, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.206072645530174`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.611537753638338`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.89921982609012, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}}, {{{{-9.210340371976182, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox[
               RowBox[{"-", "4"}], Power, Editable -> True, Selectable -> 
               True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0., 
           FormBox["1", TraditionalForm]}, {-8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.111728083308073, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.824046010856292, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.418580902748127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.264430222920869, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.1308988302963465`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.013115794639964, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{-9.210340371976182, 
           FormBox["\" \"", TraditionalForm]}, {-6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
           FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["\" \"", TraditionalForm]}, {0., 
           FormBox["\" \"", TraditionalForm]}, {-8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.111728083308073, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.824046010856292, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.418580902748127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.264430222920869, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.1308988302963465`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.013115794639964, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}, {{{9.210340371976184, 
           FormBox[
            InterpretationBox[
             RowBox[{"1", "\[Times]", 
               TagBox[
                SuperscriptBox[
                 TagBox["10", Power, Editable -> True, Selectable -> True], 
                 TagBox["4", Power, Editable -> True, Selectable -> True]], 
                InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
                Selectable -> False]}], 
             Row[{1., 
               Superscript[10., 4]}, "\[Times]"]], TraditionalForm]}, {
          10.819778284410283`, 
           FormBox[
            InterpretationBox[
             RowBox[{"5", "\[Times]", 
               TagBox[
                SuperscriptBox[
                 TagBox["10", Power, Editable -> True, Selectable -> True], 
                 TagBox["4", Power, Editable -> True, Selectable -> True]], 
                InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
                Selectable -> False]}], 
             Row[{5., 
               Superscript[10., 4]}, "\[Times]"]], TraditionalForm]}, {
          11.512925464970229`, 
           FormBox[
            InterpretationBox[
             RowBox[{"1", "\[Times]", 
               TagBox[
                SuperscriptBox[
                 TagBox["10", Power, Editable -> True, Selectable -> True], 
                 TagBox["5", Power, Editable -> True, Selectable -> True]], 
                InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
                Selectable -> False]}], 
             Row[{1., 
               Superscript[10., 5]}, "\[Times]"]], TraditionalForm]}, {
          13.122363377404328`, 
           FormBox[
            InterpretationBox[
             RowBox[{"5", "\[Times]", 
               TagBox[
                SuperscriptBox[
                 TagBox["10", Power, Editable -> True, Selectable -> True], 
                 TagBox["5", Power, Editable -> True, Selectable -> True]], 
                InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
                Selectable -> False]}], 
             Row[{5., 
               Superscript[10., 5]}, "\[Times]"]], TraditionalForm]}, {
          4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.214608098422191, 
           FormBox["500", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {8.517193191416238, 
           FormBox["5000", TraditionalForm]}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.206072645530174`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.611537753638338`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.89921982609012, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{9.210340371976184, 
           FormBox["\" \"", TraditionalForm]}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
           FormBox["\" \"", TraditionalForm]}, {13.122363377404328`, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.206072645530174`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.611537753638338`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.89921982609012, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}}],
     GridLines->
      NCache[{{9.210340371976184, 10.819778284410283`, 11.512925464970229`, 
         13.122363377404328`, 
         Log[100], 
         Log[500], 
         Log[1000], 
         Log[5000], 5.298317366548036, 5.703782474656201, 5.991464547107982, 
         6.396929655216146, 6.551080335043404, 6.684611727667927, 
         6.802394763324311, 7.600902459542082, 8.006367567650246, 
         8.294049640102028, 8.699514748210191, 8.85366542803745, 
         8.987196820661973, 9.104979856318357, 9.903487552536127, 
         10.308952660644293`, 10.596634733096073`, 11.002099841204238`, 
         11.156250521031495`, 11.289781913656018`, 11.407564949312402`, 
         12.206072645530174`, 12.611537753638338`, 
         12.89921982609012}, {-9.210340371976182, -6.907755278982137, \
-4.605170185988091, -2.3025850929940455`, 
         0, -8.517193191416238, -8.111728083308073, -7.824046010856292, \
-7.600902459542082, -7.418580902748127, -7.264430222920869, \
-7.1308988302963465`, -7.013115794639964, -6.214608098422191, \
-5.809142990314028, -5.521460917862246, -5.298317366548036, \
-5.115995809754082, -4.961845129926823, -4.8283137373023015`, \
-4.710530701645918, -3.912023005428146, -3.506557897319982, \
-3.2188758248682006`, -2.995732273553991, -2.8134107167600364`, \
-2.659260036932778, -2.5257286443082556`, -2.4079456086518722`, \
-1.6094379124341003`, -1.203972804325936, -0.916290731874155, \
-0.6931471805599453, -0.5108256237659905, -0.3566749439387323, \
-0.2231435513142097, -0.10536051565782628`}}, {{9.210340371976184, 
        10.819778284410283`, 11.512925464970229`, 13.122363377404328`, 
        4.605170185988092, 6.214608098422191, 6.907755278982137, 
        8.517193191416238, 5.298317366548036, 5.703782474656201, 
        5.991464547107982, 6.396929655216146, 6.551080335043404, 
        6.684611727667927, 6.802394763324311, 7.600902459542082, 
        8.006367567650246, 8.294049640102028, 8.699514748210191, 
        8.85366542803745, 8.987196820661973, 9.104979856318357, 
        9.903487552536127, 10.308952660644293`, 10.596634733096073`, 
        11.002099841204238`, 11.156250521031495`, 11.289781913656018`, 
        11.407564949312402`, 12.206072645530174`, 12.611537753638338`, 
        12.89921982609012}, {-9.210340371976182, -6.907755278982137, \
-4.605170185988091, -2.3025850929940455`, 
         0, -8.517193191416238, -8.111728083308073, -7.824046010856292, \
-7.600902459542082, -7.418580902748127, -7.264430222920869, \
-7.1308988302963465`, -7.013115794639964, -6.214608098422191, \
-5.809142990314028, -5.521460917862246, -5.298317366548036, \
-5.115995809754082, -4.961845129926823, -4.8283137373023015`, \
-4.710530701645918, -3.912023005428146, -3.506557897319982, \
-3.2188758248682006`, -2.995732273553991, -2.8134107167600364`, \
-2.659260036932778, -2.5257286443082556`, -2.4079456086518722`, \
-1.6094379124341003`, -1.203972804325936, -0.916290731874155, \
-0.6931471805599453, -0.5108256237659905, -0.3566749439387323, \
-0.2231435513142097, -0.10536051565782628`}}],
     ImageSize->Scaled[0.85],
     Method->{},
     PlotLabel->FormBox[
      "\"Frequency noise comparison (double pass AOM)\"", TraditionalForm],
     PlotRange->NCache[{{
         Log[100], 
         Log[100000]}, {-9.210340371976184, 0.}}, {{4.605170185988092, 
       11.512925464970229`}, {-9.210340371976184, 0.}}],
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], {None, None}},
     Ticks->{{{9.210340371976184, 
         FormBox[
          InterpretationBox[
           RowBox[{"1", "\[Times]", 
             TagBox[
              SuperscriptBox[
               TagBox["10", Power, Editable -> True, Selectable -> True], 
               TagBox["4", Power, Editable -> True, Selectable -> True]], 
              InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
              Selectable -> False]}], 
           Row[{1, 
             Superscript[10, 4]}, "\[Times]"]], TraditionalForm]}, {
        10.819778284410283`, 
         FormBox[
          InterpretationBox[
           RowBox[{"5", "\[Times]", 
             TagBox[
              SuperscriptBox[
               TagBox["10", Power, Editable -> True, Selectable -> True], 
               TagBox["4", Power, Editable -> True, Selectable -> True]], 
              InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
              Selectable -> False]}], 
           Row[{5, 
             Superscript[10, 4]}, "\[Times]"]], TraditionalForm]}, {
        11.512925464970229`, 
         FormBox[
          InterpretationBox[
           RowBox[{"1", "\[Times]", 
             TagBox[
              SuperscriptBox[
               TagBox["10", Power, Editable -> True, Selectable -> True], 
               TagBox["5", Power, Editable -> True, Selectable -> True]], 
              InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
              Selectable -> False]}], 
           Row[{1, 
             Superscript[10, 5]}, "\[Times]"]], TraditionalForm]}, {
        13.122363377404328`, 
         FormBox[
          InterpretationBox[
           RowBox[{"5", "\[Times]", 
             TagBox[
              SuperscriptBox[
               TagBox["10", Power, Editable -> True, Selectable -> True], 
               TagBox["5", Power, Editable -> True, Selectable -> True]], 
              InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
              Selectable -> False]}], 
           Row[{5, 
             Superscript[10, 5]}, "\[Times]"]], TraditionalForm]}, {
         NCache[
          Log[100], 4.605170185988092], 
         FormBox["100", TraditionalForm]}, {
         NCache[
          Log[500], 6.214608098422191], 
         FormBox["500", TraditionalForm]}, {
         NCache[
          Log[1000], 6.907755278982137], 
         FormBox["1000", TraditionalForm]}, {
         NCache[
          Log[5000], 8.517193191416238], 
         FormBox["5000", TraditionalForm]}, {5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.396929655216146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.551080335043404, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.684611727667927, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.802394763324311, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {7.600902459542082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.006367567650246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.294049640102028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.699514748210191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.85366542803745, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.987196820661973, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {9.104979856318357, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {9.903487552536127, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.308952660644293`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.596634733096073`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.002099841204238`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.156250521031495`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.289781913656018`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.407564949312402`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {12.206072645530174`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {12.611537753638338`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {12.89921982609012, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, {{-9.210340371976182, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox[
             RowBox[{"-", "4"}], Power, Editable -> True, Selectable -> 
             True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {-6.907755278982137, 
         FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
         FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
         FormBox["0.1`", TraditionalForm]}, {0, 
         FormBox["1", TraditionalForm]}, {-8.517193191416238, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-8.111728083308073, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.824046010856292, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.600902459542082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.418580902748127, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.264430222920869, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.1308988302963465`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.013115794639964, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.809142990314028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.521460917862246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.115995809754082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.961845129926823, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.8283137373023015`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.710530701645918, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.506557897319982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.2188758248682006`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.8134107167600364`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.659260036932778, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.5257286443082556`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.4079456086518722`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.203972804325936, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.916290731874155, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.5108256237659905, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.3566749439387323, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.2231435513142097, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.10536051565782628`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}}], {-1, -0.6180339887498948}, {
    Left, Bottom}, {2, 1.2360679774997896`}], InsetBox[
    GraphicsBox[{{{InsetBox[
         GraphicsBox[
          {GrayLevel[0], RectangleBox[{1, 1}]}], {0.08, 0.08}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"Current\"\>", {1.21, 0.58}, {-1, 0}, Automatic, {1, 
         0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[0, 0, 1], RectangleBox[{1, 1}]}], {0.08, 1.24}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"Second stage\"\>", {1.21, 1.74}, {-1, 0}, Automatic, {1,
          0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[1, 0, 0], RectangleBox[{1, 1}]}], {0.08, 2.4}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"First stage\"\>", {1.21, 2.9}, {-1, 0}, Automatic, {1, 
         0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[0, 
            NCache[
             Rational[2, 3], 0.6666666666666666], 0], 
           RectangleBox[{1, 1}]}], {0.08, 3.56}, {Left, Bottom}, {1, 1}], 
        InsetBox["\<\"OCXO\"\>", {1.21, 4.0600000000000005`}, {-1, 0}, 
         Automatic, {1, 0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[0.6, 0.4, 0.2], RectangleBox[{1, 1}]}], {0.08, 4.72}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"Scaled VCO\"\>", {1.21, 5.22}, {-1, 0}, Automatic, {1, 
         0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[0.4, 0.2666666666666667, 0.13333333333333336`], 
           RectangleBox[{1, 1}]}], {0.08, 5.88}, {Left, Bottom}, {1, 1}], 
        InsetBox["\<\"VCO\"\>", {1.21, 6.38}, {-1, 0}, Automatic, {1, 
         0}]}}, {}},
     AspectRatio->0.6,
     BaseStyle->{FontFamily -> "Helvetica", FontSize -> 10},
     PlotRange->{{-0.1, 6.26}, {-0.1, 7.059999999999999}}], {0.8, 0.}, {
    Left, Bottom}, {0.5, 0.3}]},
  AspectRatio->Automatic,
  Background->None,
  ColorOutput->Automatic,
  ImageSize->Scaled[0.85],
  PlotRange->All]], "Output",
 CellChangeTimes->{3.448398942828125*^9, 3.448399250703125*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Table", "Subsubtitle",
 CellChangeTimes->{{3.447176813277625*^9, 3.4471768245745*^9}, {
  3.447179727465125*^9, 3.447179780527625*^9}, {3.44718061510575*^9, 
  3.447180618512*^9}, {3.4471807273245*^9, 3.447180798715125*^9}, {
  3.44718143885575*^9, 3.447181444715125*^9}, {3.447181666152625*^9, 
  3.447181689246375*^9}, {3.447182003121375*^9, 3.4471820653245*^9}, {
  3.447182676512*^9, 3.447182687840125*^9}, {3.447182951777625*^9, 
  3.447182954871375*^9}, {3.4480256159327497`*^9, 3.4480256165889997`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{
      "\"\<Frequency\>\"", ",", "\"\<1st stage\>\"", ",", 
       "\"\<2nd stage\>\""}], "}"}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"#", ",", 
        RowBox[{"dB", "[", 
         RowBox[{"OutputNoise", "[", "#", "]"}], "]"}], ",", 
        RowBox[{"dB", "[", 
         RowBox[{"Output2Noise", "[", "#", "]"}], "]"}]}], "}"}], "&"}], "/@",
      
     RowBox[{"{", 
      RowBox[{"10", ",", "100", ",", "1000", ",", "1*^4", ",", "1*^5"}], 
      "}"}]}]}], "]"}], "//", "TableForm"}]], "Input",
 CellChangeTimes->{{3.4480255572764997`*^9, 3.4480257354483747`*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"Frequency\"\>", "\<\"1st stage\"\>", "\<\"2nd stage\"\>"},
    {"10", 
     RowBox[{"-", "58.56866008938539`"}], 
     RowBox[{"-", "78.1760726255511`"}]},
    {"100", 
     RowBox[{"-", "97.2790772066101`"}], 
     RowBox[{"-", "112.03037821836018`"}]},
    {"1000", 
     RowBox[{"-", "128.0474719819365`"}], 
     RowBox[{"-", "136.78885122239106`"}]},
    {"10000", 
     RowBox[{"-", "152.5057494779797`"}], 
     RowBox[{"-", "157.33953815994846`"}]},
    {"100000", 
     RowBox[{"-", "161.78688212321177`"}], 
     RowBox[{"-", "161.62533066230804`"}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.4480255899796247`*^9, 3.4480256245108747`*^9}, {
   3.4480256981671247`*^9, 3.4480257361827497`*^9}, 3.4481969052356253`*^9, 
   3.4483096840481253`*^9, 3.4483108251887503`*^9, 3.4483121568606253`*^9, 
   3.4483126382043753`*^9, 3.44837532853125*^9, 3.44837544715625*^9, {
   3.448379923546875*^9, 3.44837993534375*^9}, 3.448398806921875*^9, 
   3.448398865296875*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input Referred Noise", "Subtitle",
 CellChangeTimes->{{3.4471767958245*^9, 3.44717679679325*^9}, {
  3.447513895456727*^9, 3.4475139165945106`*^9}}],

Cell["VCO Frequency Noise", "Subsubtitle",
 CellChangeTimes->{{3.447186576652625*^9, 3.44718659091825*^9}, {
  3.447187881965125*^9, 3.447187883183875*^9}, {3.44751414086124*^9, 
  3.4475141452044067`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogLogPlot", "[", 
  RowBox[{
   RowBox[{"f", " ", 
    RowBox[{"VCONoise", "[", "f", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", "100", ",", "1*^7"}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
     "}"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0.001", ",", "1"}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<VCO frequency noise\>\""}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Offset Frequency (Hz)\>\"", ",", 
      "\"\<Noise (Hz/\!\(\*SqrtBox[\(Hz\)]\))\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.447178040887*^9, 3.447178087215125*^9}, {
   3.44717856066825*^9, 3.447178578996375*^9}, {3.447178693902625*^9, 
   3.447178697246375*^9}, {3.447178737058875*^9, 3.447178771871375*^9}, 
   3.447179197152625*^9, {3.44717928091825*^9, 3.44717929735575*^9}, {
   3.44717950954325*^9, 3.447179606762*^9}, {3.4471809514495*^9, 
   3.44718096791825*^9}, {3.447513923906028*^9, 3.447514081041156*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwV13k8VF8bAHClrDOXpJAlMjN3zIaolMpTlihlC2VJVCJKCFH8JBFCtkp5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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->NCache[{
     Log[100], -6.907755278982137}, {4.605170185988092, -6.907755278982137}],
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  Frame->True,
  FrameLabel->{
    FormBox["\"Offset Frequency (Hz)\"", TraditionalForm], 
    FormBox["\"Noise (Hz/\\!\\(\\*SqrtBox[\\(Hz\\)]\\))\"", TraditionalForm]},
  
  FrameTicks->FrontEndValueCache[{{{{0., 
        FormBox[
         TagBox[
          InterpretationBox["\"1.000\"", 1., AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-0.6931471805599453, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.500\"", 0.5, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {1.6094379124341003`, 
        FormBox[
         TagBox[
          InterpretationBox["\"5.000\"", 5., AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-2.302585092994046, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-2.995732273553991, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.050\"", 0.05, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-4.605170185988092, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-5.298317366548036, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.005\"", 0.005, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-6.907755278982137, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.001\"", 0.001, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.809142990314028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.521460917862246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.115995809754082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.961845129926823, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.8283137373023015`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.710530701645918, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.506557897319982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.2188758248682006`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.8134107167600364`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.6592600369327783`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.5257286443082556`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.4079456086518722`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.203972804325936, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.916290731874155, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.5108256237659907, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.35667494393873245`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.2231435513142097, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.10536051565782628`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{0., 
        FormBox["\" \"", TraditionalForm]}, {-0.6931471805599453, 
        FormBox["\" \"", TraditionalForm]}, {1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm]}, {-2.302585092994046, 
        FormBox["\" \"", TraditionalForm]}, {-2.995732273553991, 
        FormBox["\" \"", TraditionalForm]}, {-4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {-5.298317366548036, 
        FormBox["\" \"", TraditionalForm]}, {-6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.809142990314028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.521460917862246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.115995809754082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.961845129926823, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.8283137373023015`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.710530701645918, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.506557897319982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.2188758248682006`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.8134107167600364`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.6592600369327783`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.5257286443082556`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.4079456086518722`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.203972804325936, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.916290731874155, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.5108256237659907, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.35667494393873245`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.2231435513142097, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.10536051565782628`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}, {{{4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["6", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {16.11809565095832, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["7", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.508657738524219`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.914122846632385`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.201804919084164`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.424948470398375`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.60727002719233, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.761420707019587`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.89495209964411, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {16.012735135300492`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
        FormBox["\" \"", TraditionalForm]}, {16.11809565095832, 
        FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.508657738524219`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.914122846632385`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.201804919084164`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.424948470398375`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.60727002719233, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.761420707019587`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.89495209964411, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {16.012735135300492`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}, {{{{0., 
        FormBox[
         TagBox[
          InterpretationBox["\"1.000\"", 1., AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-0.6931471805599453, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.500\"", 0.5, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {1.6094379124341003`, 
        FormBox[
         TagBox[
          InterpretationBox["\"5.000\"", 5., AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-2.302585092994046, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-2.995732273553991, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.050\"", 0.05, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-4.605170185988092, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-5.298317366548036, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.005\"", 0.005, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-6.907755278982137, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.001\"", 0.001, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.809142990314028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.521460917862246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.115995809754082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.961845129926823, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.8283137373023015`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.710530701645918, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.506557897319982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.2188758248682006`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.8134107167600364`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.6592600369327783`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.5257286443082556`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.4079456086518722`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.203972804325936, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.916290731874155, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.5108256237659907, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.35667494393873245`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.2231435513142097, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.10536051565782628`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{0., 
        FormBox["\" \"", TraditionalForm]}, {-0.6931471805599453, 
        FormBox["\" \"", TraditionalForm]}, {1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm]}, {-2.302585092994046, 
        FormBox["\" \"", TraditionalForm]}, {-2.995732273553991, 
        FormBox["\" \"", TraditionalForm]}, {-4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {-5.298317366548036, 
        FormBox["\" \"", TraditionalForm]}, {-6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.809142990314028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.521460917862246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.115995809754082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.961845129926823, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.8283137373023015`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.710530701645918, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.506557897319982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.2188758248682006`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.8134107167600364`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.6592600369327783`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.5257286443082556`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.4079456086518722`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.203972804325936, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.916290731874155, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.5108256237659907, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.35667494393873245`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.2231435513142097, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.10536051565782628`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}, {{{4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["6", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {16.11809565095832, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["7", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.508657738524219`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.914122846632385`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.201804919084164`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.424948470398375`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.60727002719233, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.761420707019587`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.89495209964411, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {16.012735135300492`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
        FormBox["\" \"", TraditionalForm]}, {16.11809565095832, 
        FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.508657738524219`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.914122846632385`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.201804919084164`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.424948470398375`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.60727002719233, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.761420707019587`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.89495209964411, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {16.012735135300492`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}],
  GridLines->
   NCache[{{4.605170185988092, 6.907755278982137, 9.210340371976184, 
     11.512925464970229`, 13.815510557964274`, 16.11809565095832, 
     5.298317366548036, 5.703782474656201, 5.991464547107982, 
     6.214608098422191, 6.396929655216146, 6.551080335043404, 
     6.684611727667927, 6.802394763324311, 7.600902459542082, 
     8.006367567650246, 8.294049640102028, 8.517193191416238, 
     8.699514748210191, 8.85366542803745, 8.987196820661973, 
     9.104979856318357, 9.903487552536127, 10.308952660644293`, 
     10.596634733096073`, 10.819778284410283`, 11.002099841204238`, 
     11.156250521031495`, 11.289781913656018`, 11.407564949312402`, 
     12.206072645530174`, 12.611537753638338`, 12.89921982609012, 
     13.122363377404328`, 13.304684934198283`, 13.458835614025542`, 
     13.592367006650065`, 13.710150042306449`, 14.508657738524219`, 
     14.914122846632385`, 15.201804919084164`, 15.424948470398375`, 
     15.60727002719233, 15.761420707019587`, 15.89495209964411, 
     16.012735135300492`}, {0, -Log[2], 
      Log[5], -Log[10], -Log[20], -Log[100], -Log[200], -
      Log[1000], -6.214608098422191, -5.809142990314028, -5.521460917862246, \
-5.115995809754082, -4.961845129926823, -4.8283137373023015`, \
-4.710530701645918, -3.912023005428146, -3.506557897319982, \
-3.2188758248682006`, -2.8134107167600364`, -2.6592600369327783`, \
-2.5257286443082556`, -2.4079456086518722`, -1.6094379124341003`, \
-1.203972804325936, -0.916290731874155, -0.5108256237659907, \
-0.35667494393873245`, -0.2231435513142097, -0.10536051565782628`, 
      0.6931471805599453, 1.0986122886681098`, 1.3862943611198906`}}, {{
     4.605170185988092, 6.907755278982137, 9.210340371976184, 
     11.512925464970229`, 13.815510557964274`, 16.11809565095832, 
     5.298317366548036, 5.703782474656201, 5.991464547107982, 
     6.214608098422191, 6.396929655216146, 6.551080335043404, 
     6.684611727667927, 6.802394763324311, 7.600902459542082, 
     8.006367567650246, 8.294049640102028, 8.517193191416238, 
     8.699514748210191, 8.85366542803745, 8.987196820661973, 
     9.104979856318357, 9.903487552536127, 10.308952660644293`, 
     10.596634733096073`, 10.819778284410283`, 11.002099841204238`, 
     11.156250521031495`, 11.289781913656018`, 11.407564949312402`, 
     12.206072645530174`, 12.611537753638338`, 12.89921982609012, 
     13.122363377404328`, 13.304684934198283`, 13.458835614025542`, 
     13.592367006650065`, 13.710150042306449`, 14.508657738524219`, 
     14.914122846632385`, 15.201804919084164`, 15.424948470398375`, 
     15.60727002719233, 15.761420707019587`, 15.89495209964411, 
     16.012735135300492`}, {
     0, -0.6931471805599453, 
      1.6094379124341003`, -2.302585092994046, -2.995732273553991, \
-4.605170185988092, -5.298317366548036, -6.907755278982137, \
-6.214608098422191, -5.809142990314028, -5.521460917862246, \
-5.115995809754082, -4.961845129926823, -4.8283137373023015`, \
-4.710530701645918, -3.912023005428146, -3.506557897319982, \
-3.2188758248682006`, -2.8134107167600364`, -2.6592600369327783`, \
-2.5257286443082556`, -2.4079456086518722`, -1.6094379124341003`, \
-1.203972804325936, -0.916290731874155, -0.5108256237659907, \
-0.35667494393873245`, -0.2231435513142097, -0.10536051565782628`, 
      0.6931471805599453, 1.0986122886681098`, 1.3862943611198906`}}],
  Method->{},
  PlotLabel->FormBox["\"VCO frequency noise\"", TraditionalForm],
  PlotRange->NCache[{{
      Log[100], 
      Log[10000000]}, {-6.907755278982137, 0.}}, {{4.605170185988092, 
    16.11809565095832}, {-6.907755278982137, 0.}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {None, None}},
  Ticks->{{{4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["4", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["5", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["6", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {16.11809565095832, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["7", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {5.298317366548036, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.903487552536127, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.308952660644293`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.596634733096073`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.819778284410283`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.002099841204238`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.156250521031495`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.289781913656018`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.407564949312402`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.206072645530174`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.611537753638338`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.89921982609012, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.122363377404328`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.304684934198283`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.458835614025542`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.592367006650065`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.710150042306449`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {14.508657738524219`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {14.914122846632385`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.201804919084164`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.424948470398375`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.60727002719233, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.761420707019587`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.89495209964411, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {16.012735135300492`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, {{0, 
      FormBox[
       TagBox[
        InterpretationBox["\"1.000\"", 1., AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {
      NCache[-Log[2], -0.6931471805599453], 
      FormBox[
       TagBox[
        InterpretationBox["\"0.500\"", 0.5, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {
      NCache[
       Log[5], 1.6094379124341003`], 
      FormBox[
       TagBox[
        InterpretationBox["\"5.000\"", 5., AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {
      NCache[-Log[10], -2.302585092994046], 
      FormBox[
       TagBox[
        InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {
      NCache[-Log[20], -2.995732273553991], 
      FormBox[
       TagBox[
        InterpretationBox["\"0.050\"", 0.05, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {
      NCache[-Log[100], -4.605170185988092], 
      FormBox[
       TagBox[
        InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {
      NCache[-Log[200], -5.298317366548036], 
      FormBox[
       TagBox[
        InterpretationBox["\"0.005\"", 0.005, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {
      NCache[-Log[1000], -6.907755278982137], 
      FormBox[
       TagBox[
        InterpretationBox["\"0.001\"", 0.001, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-6.214608098422191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.809142990314028, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.521460917862246, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.115995809754082, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.961845129926823, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.8283137373023015`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.710530701645918, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.912023005428146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.506557897319982, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.2188758248682006`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.8134107167600364`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.6592600369327783`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.5257286443082556`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.4079456086518722`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.6094379124341003`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.203972804325936, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.916290731874155, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.5108256237659907, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.35667494393873245`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.2231435513142097, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.10536051565782628`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.6931471805599453, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.0986122886681098`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{{3.4475139339515524`*^9, 3.447514025470501*^9}, {
   3.4475140571224957`*^9, 3.447514081994153*^9}, 3.4480255244796247`*^9, 
   3.4481969055012503`*^9, 3.4483096842981253`*^9, 3.4483108254075003`*^9, 
   3.4483121570793753`*^9, 3.4483126384231253`*^9, 3.448375328671875*^9, 
   3.448375447296875*^9, {3.4483799236875*^9, 3.44837993553125*^9}, 
   3.4483988070625*^9, 3.448398865453125*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input Referred Voltage Noise", "Subsubtitle",
 CellChangeTimes->{{3.447186576652625*^9, 3.44718659091825*^9}, {
  3.447187881965125*^9, 3.447187883183875*^9}, {3.44751414086124*^9, 
  3.447514156905958*^9}, {3.4481979829543753`*^9, 3.4481979839856253`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tuneSense", "=", "26*^6"}], " ", ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"Hz", "/", "V"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.4475141626239395`*^9, 3.447514190073375*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogLogPlot", "[", 
  RowBox[{
   FractionBox[
    RowBox[{"f", " ", 
     RowBox[{"VCONoise", "[", "f", "]"}]}], "tuneSense"], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", "100", ",", "1*^7"}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
     "}"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1*^-10", ",", "1*^-6"}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<VCO tuning noise\>\""}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Offset Frequency (Hz)\>\"", ",", 
      "\"\<Noise (V/\!\(\*SqrtBox[\(Hz\)]\))\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.447178040887*^9, 3.447178087215125*^9}, {
   3.44717856066825*^9, 3.447178578996375*^9}, {3.447178693902625*^9, 
   3.447178697246375*^9}, {3.447178737058875*^9, 3.447178771871375*^9}, 
   3.447179197152625*^9, {3.44717928091825*^9, 3.44717929735575*^9}, {
   3.44717950954325*^9, 3.447179606762*^9}, {3.4471809514495*^9, 
   3.44718096791825*^9}, {3.447513923906028*^9, 3.447514081041156*^9}, {
   3.4475142166947966`*^9, 3.447514270047*^9}, {3.448375177609375*^9, 
   3.4483751783125*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwV13k4VG0UAHBaRLIkikJhZu6YzTZKpI6UKHuiLBERIZFdKMlWydpC2Ulp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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->NCache[{
     Log[100], -23.025850929940457`}, {
    4.605170185988092, -23.025850929940457`}],
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  Frame->True,
  FrameLabel->{
    FormBox["\"Offset Frequency (Hz)\"", TraditionalForm], 
    FormBox["\"Noise (V/\\!\\(\\*SqrtBox[\\(Hz\\)]\\))\"", TraditionalForm]},
  FrameTicks->FrontEndValueCache[{{{{-23.025850929940457`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox[
            RowBox[{"-", "10"}], Power, Editable -> True, Selectable -> 
            True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {-20.72326583694641, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox[
            RowBox[{"-", "9"}], Power, Editable -> True, Selectable -> True]],
           
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {-18.420680743952367`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox[
            RowBox[{"-", "8"}], Power, Editable -> True, Selectable -> True]],
           
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {-16.11809565095832, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox[
            RowBox[{"-", "7"}], Power, Editable -> True, Selectable -> True]],
           
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {-13.815510557964274`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox[
            RowBox[{"-", "6"}], Power, Editable -> True, Selectable -> True]],
           
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {-22.33270374938051, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-21.927238641272346`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-21.639556568820566`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-21.416413017506358`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-21.234091460712403`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-21.079940780885142`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-20.94640938826062, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-20.82862635260424, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-20.030118656386467`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-19.624653548278303`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-19.33697147582652, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-19.11382792451231, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-18.931506367718356`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-18.7773556878911, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-18.643824295266576`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-18.526041259610192`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-17.72753356339242, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-17.322068455284256`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-17.034386382832476`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-16.811242831518264`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-16.62892127472431, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-16.474770594897052`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-16.34123920227253, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-16.223456166616145`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-15.424948470398375`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-15.01948336229021, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-14.73180128983843, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-14.508657738524219`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-14.326336181730264`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-14.172185501903007`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-14.038654109278484`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-13.9208710736221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{-23.025850929940457`, 
        FormBox["\" \"", TraditionalForm]}, {-20.72326583694641, 
        FormBox["\" \"", TraditionalForm]}, {-18.420680743952367`, 
        FormBox["\" \"", TraditionalForm]}, {-16.11809565095832, 
        FormBox["\" \"", TraditionalForm]}, {-13.815510557964274`, 
        FormBox["\" \"", TraditionalForm]}, {-22.33270374938051, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-21.927238641272346`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-21.639556568820566`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-21.416413017506358`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-21.234091460712403`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-21.079940780885142`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-20.94640938826062, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-20.82862635260424, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-20.030118656386467`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-19.624653548278303`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-19.33697147582652, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-19.11382792451231, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-18.931506367718356`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-18.7773556878911, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-18.643824295266576`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-18.526041259610192`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-17.72753356339242, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-17.322068455284256`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-17.034386382832476`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-16.811242831518264`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-16.62892127472431, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-16.474770594897052`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-16.34123920227253, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-16.223456166616145`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-15.424948470398375`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-15.01948336229021, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-14.73180128983843, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-14.508657738524219`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-14.326336181730264`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-14.172185501903007`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-14.038654109278484`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-13.9208710736221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}, {{{4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["6", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {16.11809565095832, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["7", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.508657738524219`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.914122846632385`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.201804919084164`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.424948470398375`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.60727002719233, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.761420707019587`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.89495209964411, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {16.012735135300492`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
        FormBox["\" \"", TraditionalForm]}, {16.11809565095832, 
        FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.508657738524219`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.914122846632385`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.201804919084164`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.424948470398375`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.60727002719233, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.761420707019587`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.89495209964411, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {16.012735135300492`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}, {{{{-23.025850929940457`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox[
            RowBox[{"-", "10"}], Power, Editable -> True, Selectable -> 
            True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {-20.72326583694641, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox[
            RowBox[{"-", "9"}], Power, Editable -> True, Selectable -> True]],
           
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {-18.420680743952367`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox[
            RowBox[{"-", "8"}], Power, Editable -> True, Selectable -> True]],
           
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {-16.11809565095832, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox[
            RowBox[{"-", "7"}], Power, Editable -> True, Selectable -> True]],
           
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {-13.815510557964274`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox[
            RowBox[{"-", "6"}], Power, Editable -> True, Selectable -> True]],
           
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {-22.33270374938051, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-21.927238641272346`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-21.639556568820566`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-21.416413017506358`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-21.234091460712403`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-21.079940780885142`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-20.94640938826062, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-20.82862635260424, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-20.030118656386467`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-19.624653548278303`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-19.33697147582652, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-19.11382792451231, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-18.931506367718356`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-18.7773556878911, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-18.643824295266576`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-18.526041259610192`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-17.72753356339242, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-17.322068455284256`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-17.034386382832476`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-16.811242831518264`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-16.62892127472431, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-16.474770594897052`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-16.34123920227253, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-16.223456166616145`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-15.424948470398375`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-15.01948336229021, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-14.73180128983843, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-14.508657738524219`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-14.326336181730264`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-14.172185501903007`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-14.038654109278484`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-13.9208710736221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{-23.025850929940457`, 
        FormBox["\" \"", TraditionalForm]}, {-20.72326583694641, 
        FormBox["\" \"", TraditionalForm]}, {-18.420680743952367`, 
        FormBox["\" \"", TraditionalForm]}, {-16.11809565095832, 
        FormBox["\" \"", TraditionalForm]}, {-13.815510557964274`, 
        FormBox["\" \"", TraditionalForm]}, {-22.33270374938051, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-21.927238641272346`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-21.639556568820566`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-21.416413017506358`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-21.234091460712403`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-21.079940780885142`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-20.94640938826062, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-20.82862635260424, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-20.030118656386467`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-19.624653548278303`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-19.33697147582652, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-19.11382792451231, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-18.931506367718356`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-18.7773556878911, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-18.643824295266576`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-18.526041259610192`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-17.72753356339242, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-17.322068455284256`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-17.034386382832476`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-16.811242831518264`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-16.62892127472431, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-16.474770594897052`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-16.34123920227253, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-16.223456166616145`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-15.424948470398375`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-15.01948336229021, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-14.73180128983843, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-14.508657738524219`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-14.326336181730264`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-14.172185501903007`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-14.038654109278484`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-13.9208710736221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}, {{{4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["6", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {16.11809565095832, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["7", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.508657738524219`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.914122846632385`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.201804919084164`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.424948470398375`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.60727002719233, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.761420707019587`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.89495209964411, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {16.012735135300492`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
        FormBox["\" \"", TraditionalForm]}, {16.11809565095832, 
        FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.508657738524219`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.914122846632385`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.201804919084164`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.424948470398375`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.60727002719233, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.761420707019587`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.89495209964411, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {16.012735135300492`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}],
  GridLines->{{4.605170185988092, 6.907755278982137, 9.210340371976184, 
    11.512925464970229`, 13.815510557964274`, 16.11809565095832, 
    5.298317366548036, 5.703782474656201, 5.991464547107982, 
    6.214608098422191, 6.396929655216146, 6.551080335043404, 
    6.684611727667927, 6.802394763324311, 7.600902459542082, 
    8.006367567650246, 8.294049640102028, 8.517193191416238, 
    8.699514748210191, 8.85366542803745, 8.987196820661973, 9.104979856318357,
     9.903487552536127, 10.308952660644293`, 10.596634733096073`, 
    10.819778284410283`, 11.002099841204238`, 11.156250521031495`, 
    11.289781913656018`, 11.407564949312402`, 12.206072645530174`, 
    12.611537753638338`, 12.89921982609012, 13.122363377404328`, 
    13.304684934198283`, 13.458835614025542`, 13.592367006650065`, 
    13.710150042306449`, 14.508657738524219`, 14.914122846632385`, 
    15.201804919084164`, 15.424948470398375`, 15.60727002719233, 
    15.761420707019587`, 15.89495209964411, 
    16.012735135300492`}, {-23.025850929940457`, -20.72326583694641, \
-18.420680743952367`, -16.11809565095832, -13.815510557964274`, \
-22.33270374938051, -21.927238641272346`, -21.639556568820566`, \
-21.416413017506358`, -21.234091460712403`, -21.079940780885142`, \
-20.94640938826062, -20.82862635260424, -20.030118656386467`, \
-19.624653548278303`, -19.33697147582652, -19.11382792451231, \
-18.931506367718356`, -18.7773556878911, -18.643824295266576`, \
-18.526041259610192`, -17.72753356339242, -17.322068455284256`, \
-17.034386382832476`, -16.811242831518264`, -16.62892127472431, \
-16.474770594897052`, -16.34123920227253, -16.223456166616145`, \
-15.424948470398375`, -15.01948336229021, -14.73180128983843, \
-14.508657738524219`, -14.326336181730264`, -14.172185501903007`, \
-14.038654109278484`, -13.9208710736221}},
  Method->{},
  PlotLabel->FormBox["\"VCO tuning noise\"", TraditionalForm],
  PlotRange->NCache[{{
      Log[100], 
      Log[10000000]}, {-23.025850929940457`, -13.815510557964274`}}, {{
    4.605170185988092, 
    16.11809565095832}, {-23.025850929940457`, -13.815510557964274`}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {None, None}},
  Ticks->{{{4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["4", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["5", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["6", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {16.11809565095832, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["7", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {5.298317366548036, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.903487552536127, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.308952660644293`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.596634733096073`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.819778284410283`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.002099841204238`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.156250521031495`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.289781913656018`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.407564949312402`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.206072645530174`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.611537753638338`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.89921982609012, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.122363377404328`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.304684934198283`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.458835614025542`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.592367006650065`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.710150042306449`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {14.508657738524219`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {14.914122846632385`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.201804919084164`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.424948470398375`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.60727002719233, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.761420707019587`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.89495209964411, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {16.012735135300492`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, {{-23.025850929940457`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox[
          RowBox[{"-", "10"}], Power, Editable -> True, Selectable -> True]], 
        
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {-20.72326583694641, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox[
          RowBox[{"-", "9"}], Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {-18.420680743952367`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox[
          RowBox[{"-", "8"}], Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {-16.11809565095832, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox[
          RowBox[{"-", "7"}], Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {-13.815510557964274`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox[
          RowBox[{"-", "6"}], Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {-22.33270374938051, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-21.927238641272346`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-21.639556568820566`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-21.416413017506358`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-21.234091460712403`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-21.079940780885142`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-20.94640938826062, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-20.82862635260424, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-20.030118656386467`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-19.624653548278303`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-19.33697147582652, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-19.11382792451231, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-18.931506367718356`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-18.7773556878911, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-18.643824295266576`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-18.526041259610192`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-17.72753356339242, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-17.322068455284256`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-17.034386382832476`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-16.811242831518264`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-16.62892127472431, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-16.474770594897052`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-16.34123920227253, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-16.223456166616145`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-15.424948470398375`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-15.01948336229021, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-14.73180128983843, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-14.508657738524219`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-14.326336181730264`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-14.172185501903007`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-14.038654109278484`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-13.9208710736221, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{{3.4475142231314316`*^9, 3.447514272827876*^9}, 
   3.4480255247921247`*^9, 3.4481969058762503`*^9, 3.4483096845950003`*^9, 
   3.4483108257512503`*^9, 3.4483121573918753`*^9, 3.4483126387043753`*^9, 
   3.448375328875*^9, 3.448375447515625*^9, {3.44837992390625*^9, 
   3.44837993571875*^9}, 3.44839880728125*^9, 3.448398865765625*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pre-Amplification Noise", "Subtitle",
 CellChangeTimes->{{3.4471767958245*^9, 3.44717679679325*^9}, {
  3.447513895456727*^9, 3.4475139165945106`*^9}, {3.4481979932825003`*^9, 
  3.4481979960793753`*^9}, {3.4482000481887503`*^9, 3.4482000523137503`*^9}}],

Cell["Parallel and Serial Impedance", "Subsubtitle"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"par", "[", 
   RowBox[{"r1_", ",", "r2_"}], "]"}], ":=", 
  FractionBox["1", 
   RowBox[{
    FractionBox["1", "r1"], "+", 
    FractionBox["1", "r2"]}]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ser", "[", 
   RowBox[{"r1_", ",", "r2_"}], "]"}], ":=", 
  RowBox[{"r1", "+", "r2"}]}]}], "Input",
 CellChangeTimes->{{3.447515625697245*^9, 3.44751564138334*^9}, {
  3.4481980910637503`*^9, 3.4481980914075003`*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "Transfer ",
 Cell[BoxData[
  FormBox["Function", TraditionalForm]]],
 " of an OpAmp"
}], "Subsubtitle"],

Cell["\<\
This function computes the transfer function of an idealized OpAmp circuit
g: +1 for non-inverting configuration or -1 for inverting configuration, 0 \
for differential configuration
z2: Impedance in feedback path [Ohm]
z1: Impedance of input path (inverting) or impedance to ground \
(non-inverting) [Ohm]\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"OpAmp", "[", 
   RowBox[{"g_", ",", "z1_", ",", "z2_"}], "]"}], ":=", "\[IndentingNewLine]",
   
  RowBox[{"Which", "[", 
   RowBox[{
    RowBox[{"g", ">", "0"}], ",", 
    RowBox[{"1", "+", 
     FractionBox["z2", "z1"]}], ",", 
    RowBox[{"g", "<", "0"}], ",", 
    FractionBox["z2", "z1"], ",", "True", ",", " ", 
    FractionBox["z2", "z1"]}], "]"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Noise of an OpAmp", "Subsubtitle"],

Cell["\<\
This function computes the equivalent input noise of an OpAmp circuit
g: +1 for non-inverting configuration or -1 for inverting configuration, 0 \
for differential configuration
z1: Impedance of input path (inverting) or impedance to ground \
(non-inverting) [Ohm]
z2: Impedance over feedback path [Ohm]
en: voltage noise [Volt]
in: current noise [Ampere]\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"FourKT", "=", "1.62*^-20"}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["V", "2"], "/", "Hz"}], "/", "Ohm"}], ";", " ", 
    RowBox[{"room", " ", "temperature", " ", "20", "C"}]}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"OpAmpNoise", "[", 
   RowBox[{"g_", ",", "z1_", ",", "z2_", ",", "en_", ",", "in_"}], "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{"Which", "[", 
   RowBox[{
    RowBox[{"g", ">", "0"}], ",", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"z1", "\[Equal]", "Infinity"}], ",", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["en", "2"], "+", 
        RowBox[{"FourKT", " ", 
         RowBox[{"Abs", "[", "z2", "]"}]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"in", " ", 
           RowBox[{"Abs", "[", "z2", "]"}]}], ")"}], "2"]}]], ",", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["en", "2"], "+", 
        RowBox[{"FourKT", " ", 
         RowBox[{"Abs", "[", 
          RowBox[{"par", "[", 
           RowBox[{"z1", ",", "z2"}], "]"}], "]"}]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"in", " ", 
           RowBox[{"Abs", "[", 
            RowBox[{"par", "[", 
             RowBox[{"z1", ",", "z2"}], "]"}], "]"}]}], ")"}], "2"]}]]}], 
     "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"g", "<", "0"}], ",", 
    RowBox[{"\[Sqrt]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"Abs", "[", 
          RowBox[{"1", "+", 
           FractionBox["z1", "z2"]}], "]"}], "2"], 
        SuperscriptBox["en", "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Abs", "[", "z1", "]"}], "2"], 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["in", "2"], "+", 
          RowBox[{"Abs", "[", 
           FractionBox["FourKT", "z1"], "]"}], "+", 
          RowBox[{"Abs", "[", 
           FractionBox["FourKT", "z2"], "]"}]}], ")"}]}]}], ")"}]}], ",", 
    "\[IndentingNewLine]", "True", ",", " ", 
    RowBox[{"\[Sqrt]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"Abs", "[", 
          RowBox[{"1", "+", 
           FractionBox["z1", "z2"]}], "]"}], "2"], 
        SuperscriptBox["en", "2"]}], "+", 
       RowBox[{"2", 
        SuperscriptBox[
         RowBox[{"Abs", "[", "z1", "]"}], "2"], 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["in", "2"], "+", 
          RowBox[{"Abs", "[", 
           FractionBox["FourKT", "z1"], "]"}], "+", 
          RowBox[{"Abs", "[", 
           FractionBox["FourKT", "z2"], "]"}]}], ")"}]}]}], ")"}]}]}], 
   "]"}]}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples (AD829)", "Subsubtitle"],

Cell["\<\
Non-Inverting configuration: input noise w/ gain of 10 as function of r1\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogLinearPlot", "[", 
  RowBox[{
   RowBox[{"1*^9", 
    RowBox[{"OpAmpNoise", "[", 
     RowBox[{
      RowBox[{"+", "1"}], ",", "r", ",", 
      RowBox[{"9", "r"}], ",", "1.7*^-9", ",", "1.5*^-12"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "10", ",", "5000"}], "}"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<R1[Ohm]\>\"", ",", 
      "\"\<Voltage Noise[nV/\!\(\*SqrtBox[\(Hz\)]\)]\>\""}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
     "}"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4481982372043753`*^9, 3.4481982585481253`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwVy38w1Hkcx/Hdr137A7Frl2Vt+wPLpsb04xSd/b65WZQfdaq7Eal2rEp+
pBSKm8z5Ea3fRtqobi4qpZB+bG0lpfR7RLFOd36cH+tHOMpp13af++M9r3nM
PN9CeUKoAiMQCCHo/t8k0b1XDfsxKL4dv2q4T49rdJGc0wkY5EkD7L369Tip
AYs6fgiDT+WeywqQS/GN+pBjGMiar7V4DOjxxgitZCIPg7O6ma7cQT0+XT6f
La7FgDMef2HtsB6PNVvjc2YUg0c3qgIbx/W4Yu7qzUyFCZS+EIlc5/W4Ks5R
Ep5EAu/tYw2pTAOe8Fk+JU0kA6N8oS/c3YBzWbWty/eZgu8dD+33mwy4Wc9h
8dIjFNhK+5YYfMSAn7lG73FIpEIGM2Qm7Rz6X+bE4WfQINGtunai3YDbe8ui
3ZR0cDRdO0OnL+KKSHeKLMsMpiIcXxBli/ic+Owqeak5aNX0Jmr+Iu5kfF+v
LLSAf0kmOx51L+LLYtn4o+wlEJbC53S7GfGkDO3PCyWW4BHv604pNuLXQ2/s
PudnBRKaFKa+GnG/dZreH95YgdzH2u/ysW94gK5tZ9wWBjACctWdJAKohF7K
qrcMeOVSnfY4hAAFdZPpm35igpf8znrpJQJ0NJPtqJ1M6Ge4qsPIRFC77Er1
jbCGskLiK81hIphtf9BPHLCGk3srZdppItRZZ8w+i2RBSXtH/MoDGMwIsl9Y
DrPAsi8n3oVmAlk3pzZGRrHhoszL4buLyOwdHSv72FD8efxp448kcHluLsyJ
tgFJzYraIh4Z7EhCzuCgDVxS80bZU2SoK0nubN5vC/1X1EupOlO4OtFe4Thj
C9GN9u6n5imgf11kmh/HgVzmBogxp8EEVuKZMscBTZaNsn4bHVY8nGfHHLQD
1lbjvrYaM+jx2/21b9IO+k52KVSWFiARWVzQHrKHPVhoskyzBNoyefPd0/ag
S0sXu3taAW39AcvtKVzI7d32OMubAaoUl/b+L1zIkIzY+Acw4VTGgOrTQQfg
p1g/CYi2Bo8//5KkLzjAUHva0e67LHBu8ZEzk3nwD+nq5o0cG7i1MLRT8o0H
qb/6+8epbaHRkK9ozVwKs27lk9m/2IExW8XaS+QDlysZ6d3MhYko3QnlCT5Q
f79WanucBzaKkI5wEwFEOTRJX7bwYf+iZHi1jwBKHFWqOXshFD+s+SMoUwAj
lauZ02Ui2Nn63lnXIgDZOFlxl+cExrnq0KemQthwK/Qlf8EZRPGpCW+Qcwuq
9OHI/iNByg/IGvbD5RXIRdrZ1mHkHGl2sdVX1D/w8aRQhBAd5qwg6p3BL+cj
PwA5sOHymkGDMxTasSefIzd1DiRdJIihqWSU9g5Z60pvHkTuNtOIe5Clp6nm
AqIYREb5rjFkVW9eTQVy00B9B50qBG5w9VAuhvorQXcDkRmda5SxJDEYnARd
W5C9c97+fQlZeHZ2Nhw5Od9HOoQcU6RaEYt8+/yV2R1k1CeNnlciR/hW7N1k
KgbBp3v3y5DvTE4+O4ks21PYU4lcSOG6tiEXhHmw6pC9yvRjQBFD4zvaypvI
YxbXg9ORuwI/Bt9Hfmbi1aBGNjypj2lFXpdayf6CLJBm5rxG/i3xw9FVVDH8
B/O7C2Q=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->NCache[{
     Log[10], 1.7424070329684336`}, {2.302585092994046, 1.7424070329684336`}],
  
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  Frame->True,
  FrameLabel->{
    FormBox["\"R1[Ohm]\"", TraditionalForm], 
    FormBox[
    "\"Voltage Noise[nV/\\!\\(\\*SqrtBox[\\(Hz\\)]\\)]\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {{{9.210340371976184, 
       FormBox[
        InterpretationBox[
         RowBox[{"1", "\[Times]", 
           TagBox[
            SuperscriptBox[
             TagBox["10", Power, Editable -> True, Selectable -> True], 
             TagBox["4", Power, Editable -> True, Selectable -> True]], 
            InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
            Selectable -> False]}], 
         Row[{1, 
           Superscript[10, 4]}, "\[Times]"]], TraditionalForm]}, {
      10.819778284410283`, 
       FormBox[
        InterpretationBox[
         RowBox[{"5", "\[Times]", 
           TagBox[
            SuperscriptBox[
             TagBox["10", Power, Editable -> True, Selectable -> True], 
             TagBox["4", Power, Editable -> True, Selectable -> True]], 
            InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
            Selectable -> False]}], 
         Row[{5, 
           Superscript[10, 4]}, "\[Times]"]], TraditionalForm]}, {
       NCache[
        Log[10], 2.302585092994046], 
       FormBox["10", TraditionalForm]}, {
       NCache[
        Log[50], 3.912023005428146], 
       FormBox["50", TraditionalForm]}, {
       NCache[
        Log[100], 4.605170185988092], 
       FormBox["100", TraditionalForm]}, {
       NCache[
        Log[500], 6.214608098422191], 
       FormBox["500", TraditionalForm]}, {
       NCache[
        Log[1000], 6.907755278982137], 
       FormBox["1000", TraditionalForm]}, {
       NCache[
        Log[5000], 8.517193191416238], 
       FormBox["5000", TraditionalForm]}, {2.995732273553991, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.903487552536127, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.308952660644293`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.596634733096073`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{9.210340371976184, 
       FormBox["\" \"", TraditionalForm]}, {10.819778284410283`, 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[10], 2.302585092994046], 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[50], 3.912023005428146], 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[100], 4.605170185988092], 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[500], 6.214608098422191], 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[1000], 6.907755278982137], 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[5000], 8.517193191416238], 
       FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.903487552536127, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.308952660644293`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.596634733096073`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->NCache[{{9.210340371976184, 10.819778284410283`, 
      Log[10], 
      Log[50], 
      Log[100], 
      Log[500], 
      Log[1000], 
      Log[5000], 2.995732273553991, 3.4011973816621555`, 3.6888794541139363`, 
      4.0943445622221, 4.248495242049359, 4.382026634673881, 
      4.499809670330265, 5.298317366548036, 5.703782474656201, 
      5.991464547107982, 6.396929655216146, 6.551080335043404, 
      6.684611727667927, 6.802394763324311, 7.600902459542082, 
      8.006367567650246, 8.294049640102028, 8.699514748210191, 
      8.85366542803745, 8.987196820661973, 9.104979856318357, 
      9.903487552536127, 10.308952660644293`, 10.596634733096073`}, 
     Automatic}, {{9.210340371976184, 10.819778284410283`, 2.302585092994046, 
     3.912023005428146, 4.605170185988092, 6.214608098422191, 
     6.907755278982137, 8.517193191416238, 2.995732273553991, 
     3.4011973816621555`, 3.6888794541139363`, 4.0943445622221, 
     4.248495242049359, 4.382026634673881, 4.499809670330265, 
     5.298317366548036, 5.703782474656201, 5.991464547107982, 
     6.396929655216146, 6.551080335043404, 6.684611727667927, 
     6.802394763324311, 7.600902459542082, 8.006367567650246, 
     8.294049640102028, 8.699514748210191, 8.85366542803745, 
     8.987196820661973, 9.104979856318357, 9.903487552536127, 
     10.308952660644293`, 10.596634733096073`}, Automatic}],
  Method->{},
  PlotRange->NCache[{{
      Log[10], 
      Log[5000]}, {1.7424070329684336`, 11.016010130574445`}}, {{
    2.302585092994046, 8.517193191416238}, {1.7424070329684336`, 
    11.016010130574445`}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{{{9.210340371976184, 
      FormBox[
       InterpretationBox[
        RowBox[{"1", "\[Times]", 
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox["4", Power, Editable -> True, Selectable -> True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False]}], 
        Row[{1, 
          Superscript[10, 4]}, "\[Times]"]], TraditionalForm]}, {
     10.819778284410283`, 
      FormBox[
       InterpretationBox[
        RowBox[{"5", "\[Times]", 
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox["4", Power, Editable -> True, Selectable -> True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False]}], 
        Row[{5, 
          Superscript[10, 4]}, "\[Times]"]], TraditionalForm]}, {
      NCache[
       Log[10], 2.302585092994046], 
      FormBox["10", TraditionalForm]}, {
      NCache[
       Log[50], 3.912023005428146], 
      FormBox["50", TraditionalForm]}, {
      NCache[
       Log[100], 4.605170185988092], 
      FormBox["100", TraditionalForm]}, {
      NCache[
       Log[500], 6.214608098422191], 
      FormBox["500", TraditionalForm]}, {
      NCache[
       Log[1000], 6.907755278982137], 
      FormBox["1000", TraditionalForm]}, {
      NCache[
       Log[5000], 8.517193191416238], 
      FormBox["5000", TraditionalForm]}, {2.995732273553991, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.298317366548036, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.903487552536127, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.308952660644293`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.596634733096073`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, Automatic}]], "Output",
 CellChangeTimes->{{3.4481982427668753`*^9, 3.4481982590793753`*^9}, 
   3.4483096848137503`*^9, 3.4483097978606253`*^9, 3.4483098614075003`*^9, 
   3.4483099192200003`*^9, 3.4483102347043753`*^9, 3.4483102693606253`*^9, 
   3.4483108259543753`*^9, 3.4483121575950003`*^9, 3.4483126388918753`*^9, 
   3.44837532903125*^9, 3.448375447640625*^9, {3.44837992403125*^9, 
   3.448379935828125*^9}, 3.448398807421875*^9, 3.448398865875*^9}]
}, Open  ]],

Cell["\<\
Inverting configuration: input noise w/ gain of 10 as function of r1\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogLinearPlot", "[", 
  RowBox[{
   RowBox[{"1*^9", 
    RowBox[{"OpAmpNoise", "[", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "r", ",", 
      RowBox[{"10", "r"}], ",", "1.7*^-9", ",", "1.5*^-12"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "10", ",", "5000"}], "}"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<R1[Ohm]\>\"", ",", 
      "\"\<Voltage Noise[nV/\!\(\*SqrtBox[\(Hz\)]\)]\>\""}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
     "}"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4481982691731253`*^9, 3.4481982730168753`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwVzHlMk3cYwPH25SjlKkdb2wKlLVeLGMNUVAy8DzIKQ2QOECPlEGhBECiX
im5MyYASQeUwDitjm4oz2CqCaIccyqwHooxDEQTkyFA2EAkgoPh2P/948uST
55uHHycPkWEkEikYzZedLbjTeeMABpuvOqQfUxF481Q065wcA3+hvGYIWf8G
Jj2ehQFl1YfiqSbwCjzwU/D3GJyd/XvXInJ95IBo+gQGoUbDn1OvE/j7s0uF
zrUYFLfTexLrCTzFZKPP+bcYVF0TLudqCFy2oGrMl+kB91Wj3lYtgStTHUSS
bH14yuysKpsgcPli3Kx3hgEkqjIWL+vpcBt6rdYtyRDoKR4amosONxk86Mw9
RIHkgbD4rBAdfv6a8aBthhG4ceMV7sd1uNzVkWWfR4UfmDZbNml0OMfLL2Ft
iTGMjJQnKT7ocFn0eopfgQlEUAwHSLYkWHCu/iquwhQ0qi4q4UsCR+J5Xclp
M5idluRT0kjgmsLA7xWag6BYInKpIkF23sCelXIanLk9ZfldHwmuhzTE/iq2
AGZm1FUWjQziLc1Dvs8sQNPa9LIonAwBU49iUkMtQVU80hBWQwYl37Pkly5L
0Bx0lcYskeGUeib323AriIwau/lHBAa9dw3YRn1WcM+pRjp/D4M/XfYd2R5p
DWkZ4f3V3npgEtE6Rh63BryyWbz2oR6orfPmH0bTIaKY6yML04c5XmEHbZIO
dPvwGozQh4LG2cBoKQMCfo/yB7UBFDCiet1HGRB6lPxke7IhuDw25SsSmPD8
1F8SPIgCbH0+a2KCCbWRvN1HNxqBuvxw390Da8BqtONY7jdUUE13VzrMrYEr
z1TnQg4aw6enpYYnU1ngSuOb0q+YwDRWvjVngQXjypzKWboZrGtbYiRnsqF/
IjA+44Q5DIpjP47OsGG5ZfGCnZkFiARmlwayOOD6caih8qMFPMq3W3r5ngOi
+a7anTOWQN2WTovIsQH2BlbZfTNrUOa4dI99sAGb1DmOZBMdfs4bV77LtAXr
9ZqfdmQywGPktSh3xRa6lqcmbv/HBKd2nzirw3bA5R1RG8hZcGvlnxiRzg7S
H6gbErw4UL96UqbN58KFZVrrzQ22QBQq6fvJ9tCJLyy2beHCtHSqqKTIHkbf
pd2Rh/CAKQvulejxgJ3UJNpTwYcDn0WTG3x4EJuyztxxVgBlbZdfBeXz4NEu
O+9D5Y4Qo33uNNXOg+5hjqdY7AzEQk3IA0M+RFOlFt27hSBIOyJ/hvzEwXzI
OlwI/m+CSl4gW3ZcvhKOXDowr51Edn988eshZEGrz1YKhQ/C1U7Fmz1CECuG
7QOQ0xWvPYm9QjjNZsw8Ri7rsA9zixbCzfK31B7k800XvOTIL02anQeRyXV0
YT2ygIjb9y+yR5NWtzkG9eN1vcZGfPjxVmST7z7UXw1q2oFMvRgbKYkTwqoj
rz8UWX3jRVg1Mr96fl6CrMS2BY8hJ5cq16UgZx7t9k2MR332299KkLvdPDyz
pELgvbvTcgbZVePkeQvZL/H0YBWy/yX9bSvIp/Z60NXIo+pS/JhMCPU9VPdG
ZKLHy7cduX/H8M4WZM7+QX+DBPT/fl2y9ss9PWFnADLPO1/xFDltbiy0GPl/
3e8IbA==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->NCache[{
     Log[10], 1.9171137218897465`}, {2.302585092994046, 1.9171137218897465`}],
  
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  Frame->True,
  FrameLabel->{
    FormBox["\"R1[Ohm]\"", TraditionalForm], 
    FormBox[
    "\"Voltage Noise[nV/\\!\\(\\*SqrtBox[\\(Hz\\)]\\)]\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {{{9.210340371976184, 
       FormBox[
        InterpretationBox[
         RowBox[{"1", "\[Times]", 
           TagBox[
            SuperscriptBox[
             TagBox["10", Power, Editable -> True, Selectable -> True], 
             TagBox["4", Power, Editable -> True, Selectable -> True]], 
            InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
            Selectable -> False]}], 
         Row[{1, 
           Superscript[10, 4]}, "\[Times]"]], TraditionalForm]}, {
      10.819778284410283`, 
       FormBox[
        InterpretationBox[
         RowBox[{"5", "\[Times]", 
           TagBox[
            SuperscriptBox[
             TagBox["10", Power, Editable -> True, Selectable -> True], 
             TagBox["4", Power, Editable -> True, Selectable -> True]], 
            InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
            Selectable -> False]}], 
         Row[{5, 
           Superscript[10, 4]}, "\[Times]"]], TraditionalForm]}, {
       NCache[
        Log[10], 2.302585092994046], 
       FormBox["10", TraditionalForm]}, {
       NCache[
        Log[50], 3.912023005428146], 
       FormBox["50", TraditionalForm]}, {
       NCache[
        Log[100], 4.605170185988092], 
       FormBox["100", TraditionalForm]}, {
       NCache[
        Log[500], 6.214608098422191], 
       FormBox["500", TraditionalForm]}, {
       NCache[
        Log[1000], 6.907755278982137], 
       FormBox["1000", TraditionalForm]}, {
       NCache[
        Log[5000], 8.517193191416238], 
       FormBox["5000", TraditionalForm]}, {2.995732273553991, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.903487552536127, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.308952660644293`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.596634733096073`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{9.210340371976184, 
       FormBox["\" \"", TraditionalForm]}, {10.819778284410283`, 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[10], 2.302585092994046], 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[50], 3.912023005428146], 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[100], 4.605170185988092], 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[500], 6.214608098422191], 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[1000], 6.907755278982137], 
       FormBox["\" \"", TraditionalForm]}, {
       NCache[
        Log[5000], 8.517193191416238], 
       FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.903487552536127, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.308952660644293`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.596634733096073`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->NCache[{{9.210340371976184, 10.819778284410283`, 
      Log[10], 
      Log[50], 
      Log[100], 
      Log[500], 
      Log[1000], 
      Log[5000], 2.995732273553991, 3.4011973816621555`, 3.6888794541139363`, 
      4.0943445622221, 4.248495242049359, 4.382026634673881, 
      4.499809670330265, 5.298317366548036, 5.703782474656201, 
      5.991464547107982, 6.396929655216146, 6.551080335043404, 
      6.684611727667927, 6.802394763324311, 7.600902459542082, 
      8.006367567650246, 8.294049640102028, 8.699514748210191, 
      8.85366542803745, 8.987196820661973, 9.104979856318357, 
      9.903487552536127, 10.308952660644293`, 10.596634733096073`}, 
     Automatic}, {{9.210340371976184, 10.819778284410283`, 2.302585092994046, 
     3.912023005428146, 4.605170185988092, 6.214608098422191, 
     6.907755278982137, 8.517193191416238, 2.995732273553991, 
     3.4011973816621555`, 3.6888794541139363`, 4.0943445622221, 
     4.248495242049359, 4.382026634673881, 4.499809670330265, 
     5.298317366548036, 5.703782474656201, 5.991464547107982, 
     6.396929655216146, 6.551080335043404, 6.684611727667927, 
     6.802394763324311, 7.600902459542082, 8.006367567650246, 
     8.294049640102028, 8.699514748210191, 8.85366542803745, 
     8.987196820661973, 9.104979856318357, 9.903487552536127, 
     10.308952660644293`, 10.596634733096073`}, Automatic}],
  Method->{},
  PlotRange->NCache[{{
      Log[10], 
      Log[5000]}, {1.9171137218897465`, 12.200281735735839`}}, {{
    2.302585092994046, 8.517193191416238}, {1.9171137218897465`, 
    12.200281735735839`}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{{{9.210340371976184, 
      FormBox[
       InterpretationBox[
        RowBox[{"1", "\[Times]", 
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox["4", Power, Editable -> True, Selectable -> True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False]}], 
        Row[{1, 
          Superscript[10, 4]}, "\[Times]"]], TraditionalForm]}, {
     10.819778284410283`, 
      FormBox[
       InterpretationBox[
        RowBox[{"5", "\[Times]", 
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox["4", Power, Editable -> True, Selectable -> True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False]}], 
        Row[{5, 
          Superscript[10, 4]}, "\[Times]"]], TraditionalForm]}, {
      NCache[
       Log[10], 2.302585092994046], 
      FormBox["10", TraditionalForm]}, {
      NCache[
       Log[50], 3.912023005428146], 
      FormBox["50", TraditionalForm]}, {
      NCache[
       Log[100], 4.605170185988092], 
      FormBox["100", TraditionalForm]}, {
      NCache[
       Log[500], 6.214608098422191], 
      FormBox["500", TraditionalForm]}, {
      NCache[
       Log[1000], 6.907755278982137], 
      FormBox["1000", TraditionalForm]}, {
      NCache[
       Log[5000], 8.517193191416238], 
      FormBox["5000", TraditionalForm]}, {2.995732273553991, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.298317366548036, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.903487552536127, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.308952660644293`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.596634733096073`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, Automatic}]], "Output",
 CellChangeTimes->{
  3.4481982734543753`*^9, 3.4483096849231253`*^9, 3.4483097979543753`*^9, 
   3.4483098615012503`*^9, 3.4483099193293753`*^9, 3.4483102348137503`*^9, 
   3.4483102694543753`*^9, 3.4483108260325003`*^9, 3.4483121577043753`*^9, 
   3.4483126389856253`*^9, 3.448375329125*^9, 3.4483754476875*^9, {
   3.44837992409375*^9, 3.448379935890625*^9}, 3.448398807484375*^9, 
   3.4483988659375*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Series Product of OpAmps", "Subsubtitle"],

Cell["\<\
Computes the transfer function of several OpAmps circuits in series.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"OpAmpProduct", "[", 
   RowBox[{"t_", ",", "m_"}], "]"}], ":=", 
  RowBox[{"Product", "[", 
   RowBox[{
    RowBox[{"t", "[", "i", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "m"}], "}"}]}], "]"}]}]], "Input"],

Cell["\<\
Computes the equivalent input noise of several OpAmps circuits in series.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"NoiseSum", "[", 
   RowBox[{"prev_", ",", 
    RowBox[{"{", 
     RowBox[{"t_", ",", "n_"}], "}"}]}], "]"}], ":=", 
  RowBox[{
   SqrtBox[
    RowBox[{
     SuperscriptBox["prev", "2"], "+", 
     SuperscriptBox["n", "2"]}]], 
   RowBox[{"Abs", "[", "t", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"OpAmpNoiseProduct", "[", 
   RowBox[{"t_", ",", "n_", ",", "m_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{"Fold", "[", 
    RowBox[{"NoiseSum", ",", "0", ",", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"t", "[", "i", "]"}], ",", 
         RowBox[{"n", "[", "i", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "m"}], "}"}]}], "]"}]}], "]"}], 
   RowBox[{"Abs", "[", 
    RowBox[{"OpAmpProduct", "[", 
     RowBox[{"t", ",", "m"}], "]"}], "]"}]]}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Spectrum Math", "Subsubtitle"],

Cell["Propagate noise spectrum", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SpecProp", "[", 
   RowBox[{"prev_", ",", "t_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      ",", 
      RowBox[{
       RowBox[{"Abs", "[", 
        RowBox[{"t", "/.", 
         RowBox[{"s", "\[Rule]", 
          RowBox[{"2.", "\[Pi]", 
           RowBox[{
           "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}]}]}], 
        "]"}], 
       RowBox[{
       "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}]}], "}"}],
     "&"}], "/@", "prev"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SpecProp", "[", 
   RowBox[{"noise_", ",", "t_", ",", "m_"}], "]"}], ":=", 
  RowBox[{"FoldList", "[", 
   RowBox[{"SpecProp", ",", "noise", ",", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"t", "[", "i", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "m"}], "}"}]}], "]"}]}], "]"}]}]}], "Input"],

Cell["RMS of spectrum", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "SpecRMS", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SpecRMS", "[", 
   RowBox[{"l_List", "?", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"MatrixQ", "[", 
       RowBox[{"#", ",", "NumberQ"}], "]"}], "&"}], ")"}]}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"sqr", "=", "0"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"i", "<", 
        RowBox[{"Length", "[", "l", "]"}]}], ",", 
       RowBox[{"++", "i"}], ",", "\[IndentingNewLine]", 
       RowBox[{"sqr", "+=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"l", "\[LeftDoubleBracket]", 
            RowBox[{
             RowBox[{"i", "+", "1"}], ",", "1"}], "\[RightDoubleBracket]"}], 
           "-", 
           RowBox[{"l", "\[LeftDoubleBracket]", 
            RowBox[{"i", ",", "1"}], "\[RightDoubleBracket]"}]}], ")"}], 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox[
            RowBox[{
             RowBox[{"l", "\[LeftDoubleBracket]", 
              RowBox[{"i", ",", "2"}], "\[RightDoubleBracket]"}], "+", 
             RowBox[{"l", "\[LeftDoubleBracket]", 
              RowBox[{
               RowBox[{"i", "+", "1"}], ",", "2"}], 
              "\[RightDoubleBracket]"}]}], "2"], ")"}], "2"]}]}]}], "]"}], 
     ";", "\[IndentingNewLine]", 
     SqrtBox["sqr"]}]}], "]"}]}]}], "Input"],

Cell["Integrated RMS spectrum", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "RMSSpec", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RMSSpec", "[", 
   RowBox[{
    RowBox[{"l_List", "?", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"MatrixQ", "[", 
        RowBox[{"#", ",", "NumberQ"}], "]"}], "&"}], ")"}]}], ",", 
    RowBox[{"dir_:", 
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}]}]}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"sqr", "=", "0"}], ",", 
      RowBox[{"r", "=", 
       RowBox[{"N", "[", "l", "]"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"dir", "\[GreaterEqual]", "0"}], ",", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "2"}], ",", 
         RowBox[{"i", "\[LessEqual]", 
          RowBox[{"Length", "[", "l", "]"}]}], ",", 
         RowBox[{"++", "i"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"r", "\[LeftDoubleBracket]", 
           RowBox[{"i", ",", "2"}], "\[RightDoubleBracket]"}], "=", 
          SqrtBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"r", "\[LeftDoubleBracket]", 
              RowBox[{
               RowBox[{"i", "-", "1"}], ",", "2"}], "\[RightDoubleBracket]"}],
              "2"], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"r", "\[LeftDoubleBracket]", 
               RowBox[{"i", ",", "2"}], "\[RightDoubleBracket]"}], "2"], 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"r", "\[LeftDoubleBracket]", 
                RowBox[{"i", ",", "1"}], "\[RightDoubleBracket]"}], "-", 
               RowBox[{"r", "\[LeftDoubleBracket]", 
                RowBox[{
                 RowBox[{"i", "-", "1"}], ",", "1"}], 
                "\[RightDoubleBracket]"}]}], ")"}]}]}]]}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", 
          RowBox[{
           RowBox[{"Length", "[", "l", "]"}], "-", "2"}]}], ",", 
         RowBox[{"i", ">=", "1"}], ",", 
         RowBox[{"--", "i"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"r", "\[LeftDoubleBracket]", 
           RowBox[{"i", ",", "2"}], "\[RightDoubleBracket]"}], "=", 
          SqrtBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"r", "\[LeftDoubleBracket]", 
              RowBox[{
               RowBox[{"i", "+", "1"}], ",", "2"}], "\[RightDoubleBracket]"}],
              "2"], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"r", "\[LeftDoubleBracket]", 
               RowBox[{"i", ",", "2"}], "\[RightDoubleBracket]"}], "2"], 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"r", "\[LeftDoubleBracket]", 
                RowBox[{
                 RowBox[{"i", "+", "1"}], ",", "1"}], 
                "\[RightDoubleBracket]"}], "-", 
               RowBox[{"r", "\[LeftDoubleBracket]", 
                RowBox[{"i", ",", "1"}], "\[RightDoubleBracket]"}]}], 
              ")"}]}]}]]}]}], "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
     "r"}]}], "]"}]}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Instrumentation Amplifier", "Subsubtitle",
 CellChangeTimes->{{3.447186576652625*^9, 3.44718659091825*^9}, {
  3.447187881965125*^9, 3.447187883183875*^9}, {3.44751414086124*^9, 
  3.447514156905958*^9}, {3.4481979829543753`*^9, 3.4481979839856253`*^9}, {
  3.4481980255793753`*^9, 3.4481980385481253`*^9}}],

Cell["OpAmp 1", "Text",
 CellChangeTimes->{{3.4481986044856253`*^9, 3.4481986080793753`*^9}, 
   3.4481986942981253`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"n", "=", 
   RowBox[{"-", "1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"z1", "[", "n", "]"}], "=", "\[Infinity]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"z2", "[", "n", "]"}], "=", "100"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opamp", "[", "n", "]"}], "=", 
   RowBox[{"OpAmp", "[", 
    RowBox[{"1", ",", 
     RowBox[{"z1", "[", "n", "]"}], ",", 
     RowBox[{"z2", "[", "n", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opampnoise", "[", "n", "]"}], "=", 
   RowBox[{"OpAmpNoise", "[", 
    RowBox[{"1", ",", 
     RowBox[{"z1", "[", "n", "]"}], ",", 
     RowBox[{"z2", "[", "n", "]"}], ",", "1.7*^-9", ",", "1.5*^-12"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4481984260950003`*^9, 3.4481984495950003`*^9}, {
   3.4481985188606253`*^9, 3.4481985223918753`*^9}, {3.4481986649387503`*^9, 
   3.4481986653450003`*^9}, 3.4481988381731253`*^9}],

Cell["OpAmp 2", "Text",
 CellChangeTimes->{{3.4481986044856253`*^9, 3.4481986236262503`*^9}, 
   3.4481986929231253`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"n", "=", 
   RowBox[{"-", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"z1", "[", "n", "]"}], "=", "\[Infinity]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"z2", "[", "n", "]"}], "=", "100"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opamp", "[", "n", "]"}], "=", 
   RowBox[{"OpAmp", "[", 
    RowBox[{"1", ",", 
     RowBox[{"z1", "[", "n", "]"}], ",", 
     RowBox[{"z2", "[", "n", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opampnoise", "[", "n", "]"}], "=", 
   RowBox[{"OpAmpNoise", "[", 
    RowBox[{"1", ",", 
     RowBox[{"z1", "[", "n", "]"}], ",", 
     RowBox[{"z2", "[", "n", "]"}], ",", "1.7*^-9", ",", "1.5*^-12"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4481984260950003`*^9, 3.4481984495950003`*^9}, {
   3.4481985188606253`*^9, 3.4481985223918753`*^9}, {3.4481986705325003`*^9, 
   3.4481986718137503`*^9}, 3.4481988394700003`*^9}],

Cell["Diff OpAmp", "Text",
 CellChangeTimes->{{3.4481986044856253`*^9, 3.4481986236262503`*^9}, {
  3.4481986839856253`*^9, 3.4481986900325003`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"n", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"z1", "[", "n", "]"}], "=", "4990."}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"z2", "[", "n", "]"}], "=", 
   RowBox[{"par", "[", 
    RowBox[{"2490.", ",", 
     FractionBox["1", 
      RowBox[{"s", " ", "10*^-12"}]]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opamp", "[", "n", "]"}], "=", 
   RowBox[{"OpAmp", "[", 
    RowBox[{"0", ",", 
     RowBox[{"z1", "[", "n", "]"}], ",", 
     RowBox[{"z2", "[", "n", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opampnoise", "[", "n", "]"}], "=", 
   RowBox[{"\[Sqrt]", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"OpAmpNoise", "[", 
        RowBox[{"0", ",", 
         RowBox[{"z1", "[", "n", "]"}], ",", 
         RowBox[{"z2", "[", "n", "]"}], ",", "1.7*^-9", ",", "1.5*^-12"}], 
        "]"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"opampnoise", "[", 
        RowBox[{"-", "1"}], "]"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"opampnoise", "[", 
        RowBox[{"-", "2"}], "]"}], "2"]}], ")"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4481984260950003`*^9, 3.4481984495950003`*^9}, {
  3.4481985188606253`*^9, 3.4481985223918753`*^9}, {3.4481986705325003`*^9, 
  3.4481986718137503`*^9}, {3.4481987056575003`*^9, 3.4481987781262503`*^9}, {
  3.4481989822356253`*^9, 3.4481990026887503`*^9}, {3.4481990352200003`*^9, 
  3.4481990562356253`*^9}, {3.4482044852356253`*^9, 3.4482044903762503`*^9}, {
  3.4482059093293753`*^9, 3.4482059189075003`*^9}, {3.4483102273137503`*^9, 
  3.4483102289231253`*^9}, {3.4483102654700003`*^9, 3.4483102669543753`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generic Gain Stage", "Subsubtitle",
 CellChangeTimes->{{3.447186576652625*^9, 3.44718659091825*^9}, {
  3.447187881965125*^9, 3.447187883183875*^9}, {3.44751414086124*^9, 
  3.447514156905958*^9}, {3.4481979829543753`*^9, 3.4481979839856253`*^9}, {
  3.4481980255793753`*^9, 3.4481980385481253`*^9}, {3.4481991368762503`*^9, 
  3.4481991426262503`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"n", "=", "2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"z1", "[", "n", "]"}], "=", "4990."}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"z2", "[", "n", "]"}], "=", "4990."}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"z3", "[", "n", "]"}], "=", "49900."}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"impedance", " ", "on", " ", "plus", " ", "input"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"z4", "[", "n", "]"}], "=", 
   FractionBox["1", 
    RowBox[{"s", " ", "1*^-6"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opamp", "[", "n", "]"}], "=", 
   RowBox[{"OpAmp", "[", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"z1", "[", "n", "]"}], ",", 
     RowBox[{"z2", "[", "n", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"radjnoise", "=", "500*^-9"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"adjnoise2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["in", "2"], 
      SuperscriptBox[
       RowBox[{"Abs", "[", 
        RowBox[{"par", "[", 
         RowBox[{
          RowBox[{"z3", "[", "n", "]"}], ",", 
          RowBox[{"z4", "[", "n", "]"}]}], "]"}], "]"}], "2"]}], "+", 
     RowBox[{"FourKT", " ", 
      RowBox[{"Abs", "[", 
       RowBox[{"par", "[", 
        RowBox[{
         RowBox[{"z3", "[", "n", "]"}], ",", 
         RowBox[{"z4", "[", "n", "]"}]}], "]"}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"Abs", "[", 
        FractionBox[
         RowBox[{"z4", "[", "n", "]"}], 
         RowBox[{
          RowBox[{"z4", "[", "n", "]"}], "+", 
          RowBox[{"z3", "[", "n", "]"}]}]], "]"}], "2"], 
      SuperscriptBox["radjnoise", "2"]}]}], "/.", 
    RowBox[{"in", "\[Rule]", "1.5*^-12"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opampnoise", "[", "n", "]"}], "=", 
   RowBox[{"\[Sqrt]", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"OpAmpNoise", "[", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{"z1", "[", "n", "]"}], ",", 
         RowBox[{"z2", "[", "n", "]"}], ",", "1.7*^-9", ",", "1.5*^-12"}], 
        "]"}], "2"], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Abs", "[", 
         RowBox[{"1", "+", 
          FractionBox[
           RowBox[{"z1", "[", "n", "]"}], 
           RowBox[{"z2", "[", "n", "]"}]]}], "]"}], "2"], "adjnoise2"}]}], 
     ")"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4481984260950003`*^9, 3.4481984495950003`*^9}, {
   3.4481985188606253`*^9, 3.4481985223918753`*^9}, {3.4481986649387503`*^9, 
   3.4481986653450003`*^9}, 3.4481988381731253`*^9, {3.4481991067825003`*^9, 
   3.4481991256418753`*^9}, {3.4481991862981253`*^9, 
   3.4481992440950003`*^9}, {3.4481999554700003`*^9, 
   3.4481999563606253`*^9}, {3.4482045219856253`*^9, 
   3.4482045235325003`*^9}, {3.4482046465637503`*^9, 
   3.4482046653918753`*^9}, {3.4482059009387503`*^9, 
   3.4482059058450003`*^9}, {3.4483094331575003`*^9, 
   3.4483094949231253`*^9}, {3.4483096374387503`*^9, 
   3.4483096483606253`*^9}, {3.4483097025012503`*^9, 
   3.4483097030793753`*^9}, {3.4483097700481253`*^9, 
   3.4483097900637503`*^9}, {3.4483098487512503`*^9, 
   3.4483098496106253`*^9}, {3.4483099085793753`*^9, 3.4483099142668753`*^9}, 
   3.4483099642356253`*^9, {3.4483100257200003`*^9, 3.4483100263293753`*^9}, {
   3.4483101073762503`*^9, 3.4483101140481253`*^9}, {3.4483103407825003`*^9, 
   3.4483103895950003`*^9}, {3.4483104227043753`*^9, 3.4483104561731253`*^9}, 
   3.4483104933450003`*^9, {3.4483105275793753`*^9, 3.4483105295637503`*^9}, {
   3.4483106348918753`*^9, 3.4483106368918753`*^9}, {3.4483107284856253`*^9, 
   3.4483107292668753`*^9}, {3.4483109492668753`*^9, 3.4483109560325003`*^9}, 
   3.4483110137825003`*^9, {3.4483113693450003`*^9, 3.4483113801106253`*^9}, {
   3.4483117252043753`*^9, 3.4483119380325003`*^9}, {3.4483119708918753`*^9, 
   3.4483119777825003`*^9}, 3.4483120459387503`*^9, {3.4483120824075003`*^9, 
   3.4483121279387503`*^9}, {3.4483123912043753`*^9, 3.4483124183450003`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Summing Stage", "Subsubtitle",
 CellChangeTimes->{{3.447186576652625*^9, 3.44718659091825*^9}, {
  3.447187881965125*^9, 3.447187883183875*^9}, {3.44751414086124*^9, 
  3.447514156905958*^9}, {3.4481979829543753`*^9, 3.4481979839856253`*^9}, {
  3.4481980255793753`*^9, 3.4481980385481253`*^9}, {3.4481991368762503`*^9, 
  3.4481991725950003`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"n", "=", "3"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"z1", "[", "n", "]"}], "=", "4990."}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"z2", "[", "n", "]"}], "=", 
   RowBox[{"par", "[", 
    RowBox[{"3570.", ",", 
     FractionBox["1", 
      RowBox[{"s", " ", "10*^-12"}]]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opamp", "[", "n", "]"}], "=", 
   RowBox[{"OpAmp", "[", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"z1", "[", "n", "]"}], ",", 
     RowBox[{"z2", "[", "n", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opampnoise", "[", "n", "]"}], "=", 
   RowBox[{"OpAmpNoise", "[", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"z1", "[", "n", "]"}], ",", 
     RowBox[{"z2", "[", "n", "]"}], ",", "1.7*^-9", ",", "1.5*^-12"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4481984260950003`*^9, 3.4481984495950003`*^9}, {
   3.4481985188606253`*^9, 3.4481985223918753`*^9}, {3.4481986649387503`*^9, 
   3.4481986653450003`*^9}, 3.4481988381731253`*^9, {3.4481991067825003`*^9, 
   3.4481991256418753`*^9}, 3.4481992184700003`*^9, {3.4481992543137503`*^9, 
   3.4481992572356253`*^9}, {3.4481999581106253`*^9, 
   3.4481999598918753`*^9}, {3.4482008611262503`*^9, 
   3.4482008641418753`*^9}, {3.4482046895168753`*^9, 
   3.4482046919387503`*^9}, {3.4482059370168753`*^9, 
   3.4482059512825003`*^9}, {3.4482207440950003`*^9, 3.4482207443762503`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Driver Stage", "Subsubtitle",
 CellChangeTimes->{{3.447186576652625*^9, 3.44718659091825*^9}, {
  3.447187881965125*^9, 3.447187883183875*^9}, {3.44751414086124*^9, 
  3.447514156905958*^9}, {3.4481979829543753`*^9, 3.4481979839856253`*^9}, {
  3.4481980255793753`*^9, 3.4481980385481253`*^9}, {3.4481991368762503`*^9, 
  3.4481991725950003`*^9}, {3.4481993053293753`*^9, 3.4481993083293753`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"z1", "[", "n", "]"}], "=", "\[Infinity]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"z2", "[", "n", "]"}], "=", "100"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"drivermul", "=", "2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opamp", "[", "n", "]"}], "=", 
   RowBox[{"OpAmp", "[", 
    RowBox[{"1", ",", 
     RowBox[{"z1", "[", "n", "]"}], ",", 
     RowBox[{"z2", "[", "n", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opampnoise", "[", "n", "]"}], "=", 
   FractionBox[
    RowBox[{"OpAmpNoise", "[", 
     RowBox[{"1", ",", 
      RowBox[{"z1", "[", "n", "]"}], ",", 
      RowBox[{"z2", "[", "n", "]"}], ",", "1.7*^-9", ",", "1.5*^-12"}], "]"}],
     
    SqrtBox["drivermul"]]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4481984260950003`*^9, 3.4481984495950003`*^9}, {
   3.4481985188606253`*^9, 3.4481985223918753`*^9}, {3.4481986649387503`*^9, 
   3.4481986653450003`*^9}, 3.4481988381731253`*^9, {3.4481991067825003`*^9, 
   3.4481991256418753`*^9}, 3.4481992184700003`*^9, {3.4481992543137503`*^9, 
   3.4481992572356253`*^9}, {3.4481993217356253`*^9, 
   3.4481993325637503`*^9}, {3.4481994389075003`*^9, 
   3.4481995677668753`*^9}, {3.4481996052512503`*^9, 
   3.4481996215168753`*^9}, {3.4481996868450003`*^9, 
   3.4481997200793753`*^9}, {3.4481999616731253`*^9, 3.4482000067043753`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pole/Zero Stage", "Subsubtitle",
 CellChangeTimes->{{3.447186576652625*^9, 3.44718659091825*^9}, {
  3.447187881965125*^9, 3.447187883183875*^9}, {3.44751414086124*^9, 
  3.447514156905958*^9}, {3.4481979829543753`*^9, 3.4481979839856253`*^9}, {
  3.4481980255793753`*^9, 3.4481980385481253`*^9}, {3.4481991368762503`*^9, 
  3.4481991725950003`*^9}, {3.4481993053293753`*^9, 3.4481993083293753`*^9}, {
  3.4481993531887503`*^9, 3.4481993602356253`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"n", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"z1", "[", "n", "]"}], "=", 
   FractionBox["2490.", "2"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"z2", "[", "n", "]"}], "=", 
   RowBox[{"ser", "[", 
    RowBox[{"49.9", ",", 
     FractionBox["1", 
      RowBox[{"s", " ", "80*^-6"}]]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opamp", "[", "n", "]"}], "=", 
   FractionBox[
    RowBox[{"z2", "[", "n", "]"}], 
    RowBox[{
     RowBox[{"z2", "[", "n", "]"}], "+", 
     RowBox[{"z1", "[", "n", "]"}]}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opampnoise", "[", "n", "]"}], "=", 
   SqrtBox[
    RowBox[{"FourKT", " ", 
     RowBox[{"par", "[", 
      RowBox[{
       RowBox[{"z1", "[", "n", "]"}], ",", 
       RowBox[{"z2", "[", "n", "]"}]}], "]"}]}]]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4481984260950003`*^9, 3.4481984495950003`*^9}, {
   3.4481985188606253`*^9, 3.4481985223918753`*^9}, {3.4481986649387503`*^9, 
   3.4481986653450003`*^9}, 3.4481988381731253`*^9, {3.4481991067825003`*^9, 
   3.4481991256418753`*^9}, 3.4481992184700003`*^9, {3.4481992543137503`*^9, 
   3.4481992572356253`*^9}, {3.4481993217356253`*^9, 
   3.4481993325637503`*^9}, {3.4481996671887503`*^9, 3.4481996811418753`*^9}, 
   3.4481997230481253`*^9, {3.4481997635325003`*^9, 3.4481997840637503`*^9}, {
   3.4481999448762503`*^9, 3.4481999738606253`*^9}, {3.4482004528918753`*^9, 
   3.4482004533450003`*^9}, {3.4482009218293753`*^9, 
   3.4482009606887503`*^9}, {3.4482059647981253`*^9, 3.4482059744231253`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Total", "Subsubtitle",
 CellChangeTimes->{{3.447186576652625*^9, 3.44718659091825*^9}, {
  3.447187881965125*^9, 3.447187883183875*^9}, {3.44751414086124*^9, 
  3.447514156905958*^9}, {3.4481979829543753`*^9, 3.4481979839856253`*^9}, {
  3.4481980255793753`*^9, 3.4481980385481253`*^9}, {3.4481991368762503`*^9, 
  3.4481991725950003`*^9}, {3.4481993053293753`*^9, 3.4481993083293753`*^9}, {
  3.4481993531887503`*^9, 3.4481993602356253`*^9}, {3.4482000287043753`*^9, 
  3.4482000294856253`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"stages", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opamp", "[", "0", "]"}], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"OpAmpProduct", "[", 
     RowBox[{"opamp", ",", "stages"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opampnoise", "[", "0", "]"}], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"OpAmpNoiseProduct", "[", 
     RowBox[{"opamp", ",", "opampnoise", ",", "stages"}], "]"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.4482001880950003`*^9, 3.4482002000950003`*^9}, {
  3.4482009844700003`*^9, 3.4482009886887503`*^9}, {3.4482010215950003`*^9, 
  3.4482010232512503`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "\"\<Frequency\>\"", ",", "\"\<Magnitude (dB)\>\"", ",", 
        "\"\<Phase (\[Degree])\>\""}], "}"}], ",", 
      RowBox[{"{", "}"}]}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"#", ",", 
        RowBox[{
         RowBox[{"dB", "[", 
          RowBox[{"opamp", "[", "0", "]"}], "]"}], "/.", 
         RowBox[{"s", "\[Rule]", 
          RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "#"}]}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Arg", "[", 
           RowBox[{"opamp", "[", "0", "]"}], "]"}], "/", "Degree"}], "/.", 
         RowBox[{"s", "\[Rule]", 
          RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "#"}]}]}]}], "}"}],
       "&"}], "/@", 
     RowBox[{"{", 
      RowBox[{
      "0", ",", "0.1", ",", "1", ",", "10", ",", "100", ",", "1000", ",", 
       "1*^4", ",", "1*^5"}], "}"}]}]}], "]"}], "//", "TableForm"}]], "Input",\

 CellChangeTimes->{{3.4480255572764997`*^9, 3.4480257354483747`*^9}, {
  3.4482002402825003`*^9, 3.4482004240168753`*^9}, {3.4482004740793753`*^9, 
  3.4482005057512503`*^9}, {3.4482009979543753`*^9, 3.4482010018450003`*^9}, {
  3.4482012028293753`*^9, 3.4482012032512503`*^9}}],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {"\<\"Frequency\"\>", "\<\"Magnitude (dB)\"\>", "\<\"Phase \
(\[Degree])\"\>"},
    {"\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
    {"0", 
     RowBox[{"-", "8.946670560777003`"}], "0"},
    {"0.1`", 
     RowBox[{"-", "8.965003469396807`"}], 
     RowBox[{"-", "3.5803493593302163`"}]},
    {"1", 
     RowBox[{"-", "10.477986230068565`"}], 
     RowBox[{"-", "31.62281241955019`"}]},
    {"10", 
     RowBox[{"-", "25.053135112557662`"}], 
     RowBox[{"-", "67.1850902939644`"}]},
    {"100", 
     RowBox[{"-", "36.58976409357726`"}], 
     RowBox[{"-", "20.85839442302785`"}]},
    {"1000", 
     RowBox[{"-", "37.222497232456355`"}], 
     RowBox[{"-", "2.2168750215361035`"}]},
    {"10000", 
     RowBox[{"-", "37.229347819477205`"}], 
     RowBox[{"-", "0.43778531026895295`"}]},
    {"100000", 
     RowBox[{"-", "37.23263106608747`"}], 
     RowBox[{"-", "2.2032740693663078`"}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  TableForm[{{"Frequency", "Magnitude (dB)", "Phase (\[Degree])"}, {}, {
    0, -8.946670560777003, 0}, {
    0.1, -8.965003469396807, -3.5803493593302163`}, {
    1, -10.477986230068565`, -31.62281241955019}, {
    10, -25.053135112557662`, -67.1850902939644}, {
    100, -36.58976409357726, -20.85839442302785}, {
    1000, -37.222497232456355`, -2.2168750215361035`}, {
    10000, -37.229347819477205`, -0.43778531026895295`}, {
    100000, -37.23263106608747, -2.2032740693663078`}}]]], "Output",
 CellChangeTimes->{{3.4482004032512503`*^9, 3.4482004244700003`*^9}, {
   3.4482004588137503`*^9, 3.4482005061575003`*^9}, {3.4482009985168753`*^9, 
   3.4482010022356253`*^9}, 3.4482012035950003`*^9, {3.4482045351575003`*^9, 
   3.4482045457825003`*^9}, 3.4482060046106253`*^9, 3.4482207491731253`*^9, {
   3.4483096852512503`*^9, 3.4483097122356253`*^9}, 3.4483097980637503`*^9, 
   3.4483098617512503`*^9, 3.4483099195637503`*^9, 3.4483099846575003`*^9, 
   3.4483101217043753`*^9, 3.4483102350793753`*^9, 3.4483102695793753`*^9, {
   3.4483104980481253`*^9, 3.4483105010793753`*^9}, 3.4483107512668753`*^9, 
   3.4483108261575003`*^9, 3.4483121578762503`*^9, 3.4483126391106253`*^9, 
   3.44837532953125*^9, 3.448375447765625*^9, {3.448379924375*^9, 
   3.44837993609375*^9}, 3.448398807765625*^9, 3.44839886621875*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "\"\<Frequency\>\"", ",", "\"\<Input Noise\>\"", ",", 
        "\"\<Output Noise\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Hz\>\"", ",", "\"\<nV/\!\(\*SqrtBox[\(Hz\)]\)\>\"", ",", 
        "\"\<nV/\!\(\*SqrtBox[\(Hz\)]\)\>\""}], "}"}], ",", 
      RowBox[{"{", "}"}]}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"#", ",", 
        RowBox[{"1*^9", 
         RowBox[{"Abs", "[", 
          RowBox[{
           RowBox[{"opampnoise", "[", "0", "]"}], "/.", 
           RowBox[{"s", "\[Rule]", 
            RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "#"}]}]}], 
          "]"}]}], ",", 
        RowBox[{"1*^9", 
         RowBox[{"Abs", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"opamp", "[", "0", "]"}], " ", 
            RowBox[{"opampnoise", "[", "0", "]"}]}], "/.", 
           RowBox[{"s", "\[Rule]", 
            RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "#"}]}]}], 
          "]"}]}]}], "}"}], "&"}], "/@", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "10", ",", "100", ",", "1000", ",", "1*^4", ",", "1*^5"}], 
      "}"}]}]}], "]"}], "//", "TableForm"}]], "Input",
 CellChangeTimes->{{3.4480255572764997`*^9, 3.4480257354483747`*^9}, {
  3.4482002402825003`*^9, 3.4482003830793753`*^9}, {3.4482005854543753`*^9, 
  3.4482006498762503`*^9}, {3.4482007616731253`*^9, 3.4482007644231253`*^9}, {
  3.4482010066106253`*^9, 3.4482010103762503`*^9}, {3.4482010560325003`*^9, 
  3.4482011812825003`*^9}, {3.4482012846106253`*^9, 3.4482013113137503`*^9}}],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {"\<\"Frequency\"\>", "\<\"Input Noise\"\>", "\<\"Output Noise\"\>"},
    {"\<\"Hz\"\>", "\<\"nV/\\!\\(\\*SqrtBox[\\(Hz\\)]\\)\"\>", "\<\"nV/\\!\\(\
\\*SqrtBox[\\(Hz\\)]\\)\"\>"},
    {"\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
    {"1", "1937.4516805977698`", "579.8712388853432`"},
    {"10", "621.0724019216569`", "34.7124666622469`"},
    {"100", "85.05552162953009`", "1.2595467965589338`"},
    {"1000", "52.25744247322009`", "0.7194875602846694`"},
    {"10000", "51.499687421614624`", "0.708495672827169`"},
    {"100000", "51.4659421019`", "0.7077638452800892`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  TableForm[{{"Frequency", "Input Noise", "Output Noise"}, {
    "Hz", "nV/\!\(\*SqrtBox[\(Hz\)]\)", "nV/\!\(\*SqrtBox[\(Hz\)]\)"}, {}, {
    1, 1937.4516805977698`, 579.8712388853432}, {
    10, 621.0724019216569, 34.7124666622469}, {
    100, 85.05552162953009, 1.2595467965589338`}, {
    1000, 52.25744247322009, 0.7194875602846694}, {
    10000, 51.499687421614624`, 0.708495672827169}, {
    100000, 51.4659421019, 0.7077638452800892}}]]], "Output",
 CellChangeTimes->{{3.4483120008606253`*^9, 3.4483120110793753`*^9}, 
   3.4483120524700003`*^9, 3.4483120946262503`*^9, {3.4483121345793753`*^9, 
   3.4483121579231253`*^9}, {3.4483123968606253`*^9, 3.4483124232825003`*^9}, 
   3.4483126391418753`*^9, 3.448375329578125*^9, 3.4483754478125*^9, {
   3.448379924390625*^9, 3.448379936125*^9}, 3.448398807796875*^9, 
   3.44839886625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogLogPlot", "[", 
  RowBox[{
   RowBox[{"tuneSense", " ", 
    RowBox[{"Abs", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"opamp", "[", "0", "]"}], 
       RowBox[{"opampnoise", "[", "0", "]"}]}], "/.", 
      RowBox[{"s", "\[Rule]", 
       RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", "  ", "f"}]}]}], "]"}]}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", "100", ",", "1*^7"}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
     "}"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1*^-3", ",", "1"}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<VCO frequency noise\>\""}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Offset Frequency (Hz)\>\"", ",", 
      "\"\<Noise (V/\!\(\*SqrtBox[\(Hz\)]\))\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.4482013379231253`*^9, 3.4482014130012503`*^9}, {
   3.4482014526731253`*^9, 3.4482014906418753`*^9}, {3.4482015348606253`*^9, 
   3.4482015445481253`*^9}, {3.4482016118918753`*^9, 
   3.4482016373918753`*^9}, {3.4482017094387503`*^9, 
   3.4482018792043753`*^9}, {3.4482019670012503`*^9, 
   3.4482020131575003`*^9}, {3.4482020893918753`*^9, 3.4482021426731253`*^9}, 
   3.4482022654231253`*^9, {3.4482023852356253`*^9, 3.4482024325793753`*^9}, {
   3.4482024692512503`*^9, 3.4482025067825003`*^9}, {3.4482025510793753`*^9, 
   3.4482025528918753`*^9}, {3.4482026236418753`*^9, 3.4482026238606253`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwV13c8lV8YAHAtKdx77Wtd177ustIg9URJqJCs0EJKMhKySiQlympKdmUk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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->NCache[{
     Log[100], -6.907755278982137}, {4.605170185988092, -6.907755278982137}],
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
  Frame->True,
  FrameLabel->{
    FormBox["\"Offset Frequency (Hz)\"", TraditionalForm], 
    FormBox["\"Noise (V/\\!\\(\\*SqrtBox[\\(Hz\\)]\\))\"", TraditionalForm]},
  FrameTicks->FrontEndValueCache[{{{{0., 
        FormBox[
         TagBox[
          InterpretationBox["\"1.000\"", 1., AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-0.6931471805599453, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.500\"", 0.5, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {1.6094379124341003`, 
        FormBox[
         TagBox[
          InterpretationBox["\"5.000\"", 5., AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-2.302585092994046, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-2.995732273553991, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.050\"", 0.05, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-4.605170185988092, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-5.298317366548036, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.005\"", 0.005, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-6.907755278982137, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.001\"", 0.001, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.809142990314028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.521460917862246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.115995809754082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.961845129926823, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.8283137373023015`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.710530701645918, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.506557897319982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.2188758248682006`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.8134107167600364`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.6592600369327783`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.5257286443082556`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.4079456086518722`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.203972804325936, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.916290731874155, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.5108256237659907, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.35667494393873245`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.2231435513142097, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.10536051565782628`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{0., 
        FormBox["\" \"", TraditionalForm]}, {-0.6931471805599453, 
        FormBox["\" \"", TraditionalForm]}, {1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm]}, {-2.302585092994046, 
        FormBox["\" \"", TraditionalForm]}, {-2.995732273553991, 
        FormBox["\" \"", TraditionalForm]}, {-4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {-5.298317366548036, 
        FormBox["\" \"", TraditionalForm]}, {-6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.809142990314028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.521460917862246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.115995809754082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.961845129926823, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.8283137373023015`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.710530701645918, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.506557897319982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.2188758248682006`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.8134107167600364`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.6592600369327783`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.5257286443082556`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.4079456086518722`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.203972804325936, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.916290731874155, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.5108256237659907, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.35667494393873245`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.2231435513142097, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.10536051565782628`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}, {{{4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["6", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {16.11809565095832, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["7", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.508657738524219`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.914122846632385`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.201804919084164`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.424948470398375`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.60727002719233, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.761420707019587`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.89495209964411, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {16.012735135300492`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
        FormBox["\" \"", TraditionalForm]}, {16.11809565095832, 
        FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.508657738524219`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.914122846632385`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.201804919084164`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.424948470398375`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.60727002719233, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.761420707019587`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.89495209964411, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {16.012735135300492`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}, {{{{0., 
        FormBox[
         TagBox[
          InterpretationBox["\"1.000\"", 1., AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-0.6931471805599453, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.500\"", 0.5, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {1.6094379124341003`, 
        FormBox[
         TagBox[
          InterpretationBox["\"5.000\"", 5., AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-2.302585092994046, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-2.995732273553991, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.050\"", 0.05, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-4.605170185988092, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-5.298317366548036, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.005\"", 0.005, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-6.907755278982137, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.001\"", 0.001, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.809142990314028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.521460917862246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.115995809754082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.961845129926823, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.8283137373023015`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.710530701645918, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.506557897319982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.2188758248682006`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.8134107167600364`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.6592600369327783`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.5257286443082556`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.4079456086518722`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.203972804325936, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.916290731874155, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.5108256237659907, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.35667494393873245`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.2231435513142097, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.10536051565782628`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{0., 
        FormBox["\" \"", TraditionalForm]}, {-0.6931471805599453, 
        FormBox["\" \"", TraditionalForm]}, {1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm]}, {-2.302585092994046, 
        FormBox["\" \"", TraditionalForm]}, {-2.995732273553991, 
        FormBox["\" \"", TraditionalForm]}, {-4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {-5.298317366548036, 
        FormBox["\" \"", TraditionalForm]}, {-6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.809142990314028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.521460917862246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.115995809754082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.961845129926823, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.8283137373023015`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.710530701645918, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.506557897319982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.2188758248682006`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.8134107167600364`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.6592600369327783`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.5257286443082556`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.4079456086518722`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.203972804325936, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.916290731874155, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.5108256237659907, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.35667494393873245`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.2231435513142097, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.10536051565782628`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}, {{{4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {9.210340371976184, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["4", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["5", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["6", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {16.11809565095832, 
        FormBox[
         TagBox[
          SuperscriptBox[
           TagBox["10", Power, Editable -> True, Selectable -> True], 
           TagBox["7", Power, Editable -> True, Selectable -> True]], 
          InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
          Selectable -> False], TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.508657738524219`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.914122846632385`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.201804919084164`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.424948470398375`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.60727002719233, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.761420707019587`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.89495209964411, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {16.012735135300492`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{4.605170185988092, 
        FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
        FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
        FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
        FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
        FormBox["\" \"", TraditionalForm]}, {16.11809565095832, 
        FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {7.600902459542082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.006367567650246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.294049640102028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.517193191416238, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.699514748210191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.85366542803745, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {8.987196820661973, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.104979856318357, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {9.903487552536127, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.308952660644293`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.596634733096073`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {10.819778284410283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.002099841204238`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.156250521031495`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.289781913656018`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {11.407564949312402`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.206072645530174`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.611537753638338`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {12.89921982609012, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.122363377404328`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.304684934198283`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.458835614025542`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.592367006650065`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {13.710150042306449`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.508657738524219`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {14.914122846632385`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.201804919084164`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.424948470398375`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.60727002719233, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.761420707019587`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {15.89495209964411, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {16.012735135300492`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}}],
  GridLines->
   NCache[{{4.605170185988092, 6.907755278982137, 9.210340371976184, 
     11.512925464970229`, 13.815510557964274`, 16.11809565095832, 
     5.298317366548036, 5.703782474656201, 5.991464547107982, 
     6.214608098422191, 6.396929655216146, 6.551080335043404, 
     6.684611727667927, 6.802394763324311, 7.600902459542082, 
     8.006367567650246, 8.294049640102028, 8.517193191416238, 
     8.699514748210191, 8.85366542803745, 8.987196820661973, 
     9.104979856318357, 9.903487552536127, 10.308952660644293`, 
     10.596634733096073`, 10.819778284410283`, 11.002099841204238`, 
     11.156250521031495`, 11.289781913656018`, 11.407564949312402`, 
     12.206072645530174`, 12.611537753638338`, 12.89921982609012, 
     13.122363377404328`, 13.304684934198283`, 13.458835614025542`, 
     13.592367006650065`, 13.710150042306449`, 14.508657738524219`, 
     14.914122846632385`, 15.201804919084164`, 15.424948470398375`, 
     15.60727002719233, 15.761420707019587`, 15.89495209964411, 
     16.012735135300492`}, {0, -Log[2], 
      Log[5], -Log[10], -Log[20], -Log[100], -Log[200], -
      Log[1000], -6.214608098422191, -5.809142990314028, -5.521460917862246, \
-5.115995809754082, -4.961845129926823, -4.8283137373023015`, \
-4.710530701645918, -3.912023005428146, -3.506557897319982, \
-3.2188758248682006`, -2.8134107167600364`, -2.6592600369327783`, \
-2.5257286443082556`, -2.4079456086518722`, -1.6094379124341003`, \
-1.203972804325936, -0.916290731874155, -0.5108256237659907, \
-0.35667494393873245`, -0.2231435513142097, -0.10536051565782628`, 
      0.6931471805599453, 1.0986122886681098`, 1.3862943611198906`}}, {{
     4.605170185988092, 6.907755278982137, 9.210340371976184, 
     11.512925464970229`, 13.815510557964274`, 16.11809565095832, 
     5.298317366548036, 5.703782474656201, 5.991464547107982, 
     6.214608098422191, 6.396929655216146, 6.551080335043404, 
     6.684611727667927, 6.802394763324311, 7.600902459542082, 
     8.006367567650246, 8.294049640102028, 8.517193191416238, 
     8.699514748210191, 8.85366542803745, 8.987196820661973, 
     9.104979856318357, 9.903487552536127, 10.308952660644293`, 
     10.596634733096073`, 10.819778284410283`, 11.002099841204238`, 
     11.156250521031495`, 11.289781913656018`, 11.407564949312402`, 
     12.206072645530174`, 12.611537753638338`, 12.89921982609012, 
     13.122363377404328`, 13.304684934198283`, 13.458835614025542`, 
     13.592367006650065`, 13.710150042306449`, 14.508657738524219`, 
     14.914122846632385`, 15.201804919084164`, 15.424948470398375`, 
     15.60727002719233, 15.761420707019587`, 15.89495209964411, 
     16.012735135300492`}, {
     0, -0.6931471805599453, 
      1.6094379124341003`, -2.302585092994046, -2.995732273553991, \
-4.605170185988092, -5.298317366548036, -6.907755278982137, \
-6.214608098422191, -5.809142990314028, -5.521460917862246, \
-5.115995809754082, -4.961845129926823, -4.8283137373023015`, \
-4.710530701645918, -3.912023005428146, -3.506557897319982, \
-3.2188758248682006`, -2.8134107167600364`, -2.6592600369327783`, \
-2.5257286443082556`, -2.4079456086518722`, -1.6094379124341003`, \
-1.203972804325936, -0.916290731874155, -0.5108256237659907, \
-0.35667494393873245`, -0.2231435513142097, -0.10536051565782628`, 
      0.6931471805599453, 1.0986122886681098`, 1.3862943611198906`}}],
  Method->{},
  PlotLabel->FormBox["\"VCO frequency noise\"", TraditionalForm],
  PlotRange->NCache[{{
      Log[100], 
      Log[10000000]}, {-6.907755278982137, 0.}}, {{4.605170185988092, 
    16.11809565095832}, {-6.907755278982137, 0.}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {None, None}},
  Ticks->{{{4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["4", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["5", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["6", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {16.11809565095832, 
      FormBox[
       TagBox[
        SuperscriptBox[
         TagBox["10", Power, Editable -> True, Selectable -> True], 
         TagBox["7", Power, Editable -> True, Selectable -> True]], 
        InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
        Selectable -> False], TraditionalForm]}, {5.298317366548036, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.903487552536127, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.308952660644293`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.596634733096073`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.819778284410283`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.002099841204238`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.156250521031495`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.289781913656018`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.407564949312402`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.206072645530174`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.611537753638338`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.89921982609012, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.122363377404328`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.304684934198283`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.458835614025542`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.592367006650065`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.710150042306449`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {14.508657738524219`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {14.914122846632385`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.201804919084164`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.424948470398375`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.60727002719233, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.761420707019587`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.89495209964411, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {16.012735135300492`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, {{0, 
      FormBox[
       TagBox[
        InterpretationBox["\"1.000\"", 1., AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {
      NCache[-Log[2], -0.6931471805599453], 
      FormBox[
       TagBox[
        InterpretationBox["\"0.500\"", 0.5, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {
      NCache[
       Log[5], 1.6094379124341003`], 
      FormBox[
       TagBox[
        InterpretationBox["\"5.000\"", 5., AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {
      NCache[-Log[10], -2.302585092994046], 
      FormBox[
       TagBox[
        InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {
      NCache[-Log[20], -2.995732273553991], 
      FormBox[
       TagBox[
        InterpretationBox["\"0.050\"", 0.05, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {
      NCache[-Log[100], -4.605170185988092], 
      FormBox[
       TagBox[
        InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {
      NCache[-Log[200], -5.298317366548036], 
      FormBox[
       TagBox[
        InterpretationBox["\"0.005\"", 0.005, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {
      NCache[-Log[1000], -6.907755278982137], 
      FormBox[
       TagBox[
        InterpretationBox["\"0.001\"", 0.001, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-6.214608098422191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.809142990314028, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.521460917862246, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.115995809754082, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.961845129926823, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.8283137373023015`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.710530701645918, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.912023005428146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.506557897319982, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.2188758248682006`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.8134107167600364`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.6592600369327783`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.5257286443082556`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.4079456086518722`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.6094379124341003`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.203972804325936, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.916290731874155, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.5108256237659907, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.35667494393873245`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.2231435513142097, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.10536051565782628`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.6931471805599453, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.0986122886681098`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{
  3.4482026170168753`*^9, 3.4482027782043753`*^9, 3.4482034143293753`*^9, 
   3.4482045834387503`*^9, 3.4482060306262503`*^9, 3.4482207582200003`*^9, 
   3.4483096855012503`*^9, 3.4483097984387503`*^9, 3.4483098621575003`*^9, 
   3.4483099198918753`*^9, 3.4483099992825003`*^9, 3.4483100409075003`*^9, 
   3.4483101271575003`*^9, 3.4483102355168753`*^9, 3.4483102699543753`*^9, {
   3.4483104414075003`*^9, 3.4483104673606253`*^9}, 3.4483105071106253`*^9, 
   3.4483105372356253`*^9, 3.4483106514700003`*^9, 3.4483107633450003`*^9, 
   3.4483108266731253`*^9, 3.4483120153606253`*^9, 3.4483120560637503`*^9, 
   3.4483120975637503`*^9, {3.4483121367825003`*^9, 3.4483121582512503`*^9}, {
   3.4483124022356253`*^9, 3.4483124258606253`*^9}, 3.4483126394231253`*^9, 
   3.448375329796875*^9, 3.44837544803125*^9, {3.448379924609375*^9, 
   3.448379936328125*^9}, 3.44839880803125*^9, 3.448398866484375*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Combined VCO Frequency Noise", "Subsubtitle",
 CellChangeTimes->{{3.447186576652625*^9, 3.44718659091825*^9}, {
  3.447187881965125*^9, 3.447187883183875*^9}, {3.44751414086124*^9, 
  3.447514156905958*^9}, {3.4481979829543753`*^9, 3.4481979839856253`*^9}, {
  3.4481980255793753`*^9, 3.4481980385481253`*^9}, {3.4481991368762503`*^9, 
  3.4481991725950003`*^9}, {3.4481993053293753`*^9, 3.4481993083293753`*^9}, {
  3.4481993531887503`*^9, 3.4481993602356253`*^9}, {3.4482000287043753`*^9, 
  3.4482000294856253`*^9}, {3.4482028025950003`*^9, 3.4482028090325003`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ShowLegend", "[", 
   RowBox[{
    RowBox[{"LogLogPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"f", " ", 
              RowBox[{"VCONoise", "[", "f", "]"}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"tuneSense", " ", 
              RowBox[{"Abs", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"opamp", "[", "0", "]"}], 
                 RowBox[{"opampnoise", "[", "0", "]"}]}], "/.", 
                RowBox[{"s", "\[Rule]", 
                 RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", "  ", "f"}]}]}], 
               "]"}]}], ")"}], "2"]}], ")"}]}], ",", 
        RowBox[{"f", " ", 
         RowBox[{"VCONoise", "[", "f", "]"}]}], ",", 
        RowBox[{"tuneSense", " ", 
         RowBox[{"Abs", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"opamp", "[", "0", "]"}], 
            RowBox[{"opampnoise", "[", "0", "]"}]}], "/.", 
           RowBox[{"s", "\[Rule]", 
            RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", "  ", "f"}]}]}], 
          "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"f", ",", "100", ",", "1*^7"}], "}"}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Red"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", "Blue"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", " ", "[", "0.007", "]"}], ",", " ", 
           RowBox[{"Darker", "[", "Green", "]"}]}], "}"}]}], "}"}]}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", "$TextStyle"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"1*^-3", ",", "1"}], "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotLabel", "\[Rule]", "\"\<Total VCO frequency noise\>\""}], 
      ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Offset Frequency (Hz)\>\"", ",", 
         "\"\<Noise (Hz/\!\(\*SqrtBox[\(Hz\)]\))\>\""}], "}"}]}], ",", 
      RowBox[{"ImageSize", "\[Rule]", 
       RowBox[{"Scaled", "[", "0.8", "]"}]}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Red", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<Total\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Blue", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<Oscillator\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Darker", "[", "Green", "]"}], ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
          "\"\<Tuning\>\""}], "}"}]}], "}"}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
         RowBox[{"FontSize", "\[Rule]", "10"}]}], "}"}]}], ",", 
      RowBox[{"LegendPosition", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0.7", ",", 
         RowBox[{"-", "0.0"}]}], "}"}]}], ",", 
      RowBox[{"LegendSize", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0.5", ",", "0.3"}], "}"}]}], ",", 
      RowBox[{"LegendTextSpace", "\[Rule]", "5"}], ",", 
      RowBox[{"LegendShadow", "\[Rule]", "None"}]}], "}"}]}], "]"}], "//", 
  "Quiet"}]], "Input",
 CellChangeTimes->{{3.4482013379231253`*^9, 3.4482014130012503`*^9}, {
   3.4482014526731253`*^9, 3.4482014906418753`*^9}, {3.4482015348606253`*^9, 
   3.4482015445481253`*^9}, {3.4482016118918753`*^9, 
   3.4482016373918753`*^9}, {3.4482017094387503`*^9, 
   3.4482018792043753`*^9}, {3.4482019670012503`*^9, 
   3.4482020131575003`*^9}, {3.4482020893918753`*^9, 3.4482021426731253`*^9}, 
   3.4482022654231253`*^9, {3.4482023852356253`*^9, 3.4482024325793753`*^9}, {
   3.4482024692512503`*^9, 3.4482025067825003`*^9}, {3.4482025510793753`*^9, 
   3.4482025528918753`*^9}, {3.4482026382668753`*^9, 
   3.4482026982668753`*^9}, {3.4482027460481253`*^9, 
   3.4482027551262503`*^9}, {3.4482029083450003`*^9, 
   3.4482031324387503`*^9}, {3.4482031854856253`*^9, 
   3.4482032056887503`*^9}, {3.4482033576418753`*^9, 
   3.4482033579700003`*^9}, {3.4483107881731253`*^9, 3.4483107931106253`*^9}}],\


Cell[BoxData[
 GraphicsBox[{InsetBox[
    GraphicsBox[{{}, {}, 
      {RGBColor[1, 0, 0], Thickness[0.007], LineBox[CompressedData["
1:eJwV13k8lG8QAHBdG7vryBXlCrvv2gvpppoiIbdQKooSpeRI5UqKHMlZKZIo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        "]]}, 
      {RGBColor[0, 0, 1], Thickness[0.007], LineBox[CompressedData["
1:eJwV13k8VF8bAHClrDOXpJAlMjN3zIaolMpTlihlC2VJVCJKCFH8JBFCtkp5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        "]]}, 
      {RGBColor[0, 
        NCache[
         Rational[2, 3], 0.6666666666666666], 0], Thickness[0.007], 
       LineBox[CompressedData["
1:eJwV13c8lV8YAHAtKdx77Wtd177ustIg9URJqJCs0EJKMhKySiQlympKdmUk
0iDVKZoiO6ISRSrys6KU39M/fL6f977Pc85z1nuUd/jaeswWEBBQwj///jd8
OFhb6i0OT7Kser45CZO+1C/eG33FoXym8L7ZVmEyvc5BZDBAHI5vyVG55C5M
WOWL1rNCxUFjRCxhua8wORz3oz4jThzcw8L+rokRJrq6Hk3xeeIQLdClHVMs
TJKPWHd4fBCHkWvNeremhcnVJQ8PzukVB/vZL5ZHzxIhD77z5LL6xKFGsG3E
SlCEfLUX3tI1KA4bHhh4NVNFiCnnaZfttDgUTVy4WKQiQsaajbpXykqApVuQ
RdJaEbJZXbNfdpMEXBAyi+UlipBKiz075zlIwOSLwPjXySKE6Vf8YdhZApYe
7CjZe1aEfK/Ub3+2A3/vstftXKYIibGGFwcCJMCj69rJW2UipDzMqbAxSQJ8
xvoWLGgTIZJN8b7HGyTgL5+/WE1WlIT+rP8W2CIB6h1dbnxFUdKtIO61rV0C
rjdt+6GvLEqKdp3btqRbAgrzpmx0tUTJ6j+5Np9/SMDZxyXu40tFyX7WA/1V
VEnwKXs/L89BlDRFDv+cXC8JRtoR9FtJoqRsesdYlo0kxD4JdJtIFSVJoa3D
FpslYU7hzSH9c6LEOqhyIN1FEqa2Jv7MyRAl9T4xneAtCdTK7kGHQlFS60J/
GBeHz7slE8RqREmNIcTSqyVhvoDwdNeIKMm9W3bk0VNJMB6X3VA0LkqiF6sf
2vNSEgrsHA1DJkWJid7CkKpGSfDf1PBt3l9R8kirZfe2bkmQsRz7PSlEIQ/o
Xuuv/pGEUft9SsCgkDsTpySXLpUCM8EpJQ8zCnFkPyipN5KC0tiz9cScQiZd
v1t4rJQCu9xN8bKWFGL4xDwq2UwKfuzZs+zxRgqpSpk19N1OCpIrxW8MO1LI
Y539z7L8pUAw7oh5zR4KebXHPlS4UAqK4o4YOp6kkL0ZMVLZ16WgN2yo0DmR
QkSbym4sLZMC573USOfTFLJhGbXfo0IK5uWTDbapFNI4//km8kwKXlrP+qqS
TiFtuct4Bz5JgQ2zaq1FIYV8fK/Q/V5RGmgVXUeqn1FI0xElh2plafh4e+fr
iy+wPRoq9VfUpcHQXd/Tv5ZCcvZpVvnxpOFviN8hydcU4vFX99xsY2lYPeNX
YdhGIQOKa601XKThzL7d1IWfKOQ/F3/ic0EaGHdjaS//UEiPQOAS2wxpmL3g
212bGcyXG3R9cbY0DFZVU94IUMnN72HpM9cwfympfzuHSg6Ex4YkVUhDV9f0
yNMFVDJ18aLOrXZp6ElwdFskRSWzOp9kTkvLgLOw8ftgNpXsffPzbIacDJy6
M2Cfx6GStmatU8CQAbNWlmwjl0oKXiVExKjLAFeZE62qTSW2DzY7iyySgYRr
AexyfSrJzfosoWAjAymzU67FLqcSM695x4ziZSBc+Y7qjBWV3HBfEvkuUQY6
nW4MTa2nErntuw8cSpaB0+eoZqMbqGTIqW5n9XkZyPN+m/XRmkrOWqaB5VUZ
+OTBXV1sRyVf+Oq/nJ/IgIX27Y+zXKgkfny1T+iMDOQzrh0v3o35dljCnjl0
+Pl1UV/iHioReG0j4TyfDg8rB5r3eVNJ4FW3imVUOjxLSvRm+1CJy5aQeVMM
OhRs939+2o9KuI8KLwWvoEPTUisphWAqeXVSvD4wgg4XymQcjKKpJHaKnuUe
RQdHntinETR4KgXaHaXD+CwD02sxVFK+kiu3KIEO67J9D4nHUkn6yBrP0XQ6
nJOzVn0Th/V1PPjXv4oOzZFnitmJVCKi1s33/U0HhghnVPAclRwzy860mqHD
PssL4efRs3e7i7PnyEJCgQSdc55KJou/jH9aKAs26bR4ywtU8mnJf1XOcrJg
n6dzIiqdSu5bzrY0WyYLQ/0a/OpMKtm3X22XYrAs1EFqYf5VKhlI62v/FSoL
QiWtPMY1KnG/e9WiPVIWZuxzBlPRzn+4/JRYWbBMbmQfLsB6HjMYFzojCxFw
5v76IiphXDSLHiuXBZ59ycanJVTy+rHX5doRWWgw+sI0uE0lNcbOSZ4TssA4
4k85jb571zJ61i9ZONCnGPAVnX2dv2vJLDn4vJh/+dIdHI8LY/wcqhwcExG9
8ucuzoeAww9CuXIw1NbLzLtHJZ7K595pecqBYT2RPUuoZEv68dc1u+XAXSdp
Yw/aWibs0VYfORC/8kSC94hKlom65aUFysF/n2UtHqFFplR9ZkXLAa3eN+rT
YyopayiZbr8sBzmW0SXST6jkz6Fn8nEdciC4KimM/4JKTLwTBvzeYXyO4rQ/
OtZ+0x2nj3KgOvWEcgtN432w5QzIgfyQ7eCyl1Si8nbieP2kHDyVcMxZUYv1
WqQxKUmXh8kNaqcW1VHJ6S8xLVn28iB6Z4HwmwYqaWm2yD7hLA+WwouZlEYq
kX1I89vvJg+l5WFdq9HZaenCazzloXhroVUputyk3OTLAXl4b/1aPraJSjrS
e2/w0+RBtfjsqFIL5rcxSbjXLA/Oes8s6W+opDt1Sef2N/JQNs11MkFntHO1
hDrlYdTzveZetPw2mSd2PfLgIFey8CFa0vf79OCwPKTnlg1vb6cSwYQze5kU
BcgNykhK78D58vyr5VFzBfBYcSinv5NKrop0n+dYKYB4wLHEhV04Ptat/Y0b
FeDiDxkzHrrnzcNohoMCmH+WVAhAv+1LvXfHQwGer1y6dwr9au5KztcjCqD8
w/rj33e4H0DKwo33FeAyBQ/iD1Sibbj6Zw9RAO8fF3LndFPJdf3x3qAaBfjP
2mdKCV2s4XA/o1YBdm5lsh3RBSLyfkMdClB9L/j6U3Rue3ZrwgTmf+AXnP6R
Ss75lWW+0lYEntr9i9xeKpHZszNhm74iDJtZB61Gn9kpGTq2WBH+hG7WdkGn
2QdtUlihCNK0I8bx6OTlhoJ7rRTBWL3vdT/6pNBjb+HdihDx/cvPC5+oJCqz
cbFFtiL4BD689PUzzseFDjOcfEXQI0r2An1UwgzseiZaoAgM1ttBKfSDtf2O
jaWKoFOqVwXoX0PToY6PFCEteNHbVHSgMeuhZ7ci/Dzhbr6kH+v7NnJtNIMB
Keylpp5fqMRg9VyahwoDVNqfrg1Bz71+vN1MgwHpa+/onkBnR6XuXshnQM3h
3beL0R9YBfFJxgyY1XPn2CjaMbj19WUXBrxbarAvdIBKLCS5jlUXGKDx2M0t
6CuVpLR1Z27JYEDJRkXXGHTXubSBX1kM6NEdME9G+yjOhC67xoC897JfitGn
NZou3b7DALXwb2s/oduWhvTeaGGAv7563vpvVLLTtWZfHkUJnrhNx0t8p5Ii
pYN3VosrQfPB71uV0GMfeQKfpJQgoYWpxkHHep5NUlFUgo62sggTdIHvnvLL
HCXInPod7IcejqL9Om+uBA6ixekv0OH5LkcTjyjBgyOtRv6DOJ87Pl8Li1WC
iPgQ2XB0sbBvvdcJJaj9XdEfi37vFyVjmqwEwg9D7NPRq4zyr/3MUgKL1KhD
T9GCDT/qtj1Sgj1h8pL0ISp5Hr4qXlaACfMk9vXcQEtKxyrSZjNB9G79TAV6
W8nLEsG5TPg2eZxWjZ76uKlldD4TzA+7ibSi2Ws9FeupTGjuvOg7iU4Qiy85
osSEjuDuseU/8PzMb2n+toIJlc9FQu6jD8kFG3QAEw5HRgo8QRclyp59asKE
NaY9ka/QgsFuzllmTDCevOfaia5Y+6XbfgMTzG7Y502imQO/Bx+5YntVGrx0
h6lkkKMqdC6cCfaVjsrpaLnMJ7uPRjKBn74jOhttJulVG3CYCc514u+uojOn
ixLXxzAhlnY2+Bbarm6x1JyTTAjdH2VRj67cZ6Gy7yIT9vrrBvxFx5X6L19d
yYSD0q0yTv9RyUgjx41WxQTx2DRNN7TLyOdDXffxOdVcdydaW9+5OvARE578
l6Png24rN7HIe86EwF6ZocNo1bsSjoJvmBDm3rjhCvrBg1v7n48yIdcLvv9A
sz74pqWOM+HlVq11Y+ikGa07234ywapvJHMS7Q4ZvyZ/McH7msmqWSNUIvw4
NkprtjKYyZ1eI452fOJw6gRNGVovXdyhjx6tnSqw4ilDL9teLgAdo5ZRuVJb
GYYsdHSD0NIRJi/1dJWBUTdoEoo25McP0A2UYU25tsMR9OHTCqzPy5VhS02a
aTJaZPPKvAgrZajqmNYtRWu8j7l83VsZ7tZmpnxD312sVZLlg/FLhCR/oNed
qnuQ6qsM9h3qp0fQe0H6feh+ZVh67WzYFPpm9hWFtWHKEDnnj9L8Ufze2PXy
/IcTymD7+XWOMtppmJpKK1CGR5O99zehWeO1O3sKlSFi5sJJe/TE1DH98mJl
gGCOoxM6eY5As0OpMpy/9uWzG/qV9LDY5bvKYOJv0rX7X3zjhlO8Z9i//S1L
DqE1TpyOt/ikDLsuetZcQY8lWm1R6FOGi6qXDQrQ1SlCnKF+Zdh0QSO3CL3t
0uGXSd+UIalC+2Ap+sINvwUdI8rwOv7YnHto0TfWx3bNUgG8N6TX/YunKhYd
w1CBdtWxkWH01213IIKpAqODhatG0R8vuf49oKICoaolCePoepmCg7s0VGCO
Xr7iL/QVYVM/C74KNO6sVJwzht8vo4GutBUqsOFmbJYk+uHj9iXpripg4Sny
2gB9eyZyPHWrCkxPvaxbgi5arn4zYbsKHLiz4uUy9Lnb/vxDHirw+rZNlTE6
oGCh+g4fFZCgHDy6Bq2WvFycFaEC0p1O1+3QJ7Znfr+ZrgLzrvzy8UdvP5h7
MCdDBYY6Opj70UuTrgqmZKpAfnN7YyC6j9xgBuSqwP2SlfwQ9CrmIzudIhUo
9xxtiERPvv9YVXRPBcLjfj+MR3u6qCbkvVWBJKWldrlo40BNubQuFThyOfR1
HlryJOdKzHsV4LarrruCfnxP/9HOHhVwPFu2pACtKL96XPmrCoTcmZp1A93S
4e6aMaUCzKQBq3toE4d83lm6KjQGXnvRgLaXfxzqIacK6w9ZzTSi93x490xf
QRWaPj3Ub0Yn7ZLa0aCkClLeiudb0d3BMWcWaKrCeNnbzW/REed2zIQZ4PPU
lHO96LsdjMZttqoQ/H6L1Tj61SVDhradKnxVLHKb+Pf+dnvvP5tV4Z3+T9+f
6PlfE+ZdcFKF6tYjp6b+tefX9LLmbaqw0TL58R/0mFxn9hpfVRgryZyaN477
icvZQPZJVfgwUHpTCr3H8VKJUqIqePlxq6TR+XY5XyVPq4J8/+VqGTRjfcm2
mRRVcDUIfi2LFlnxzKrloir0TYp2KqIHlH6qRRaqwsNykWp1dE6vfWvjS8wv
durDIrSMt/TigwvUwJ68OG2NPi2xSHe9sBrITrRsskELVdlwlUXVYJsBSNui
J0USVF7Q1OB0oOH5Tei31+dQZelqkGvz5qw9OmNkuP+uhho0JoSFuKA1QmvP
T5qqwduXF+p2oRcdP/wnOFINfvHVf4aj92/dns7+Tw0owovnZaOLVzbcOuej
DtVy8SlP0Qra7NbbH9Xh5urAr1/Qs18nGV3vVYdXpj1HB9Bf9k1l5X1Wh+c7
8pS/om9ef74vdUAd5urrOn9DW/B3CQX8pw7Lx0+8HkQH83KNeLM0wGC46NUI
uonDyM5haoBEzyaFP+i7tUeFLqpogPLY6Sf/fMl7cF+ymgZYqjn5/kV7FVYZ
RbE04M+65JoZ9Ax7S6ubjgY0LOk6MHsC71vsc0JyoAGeOeHj89HHWOK+p7fi
+2dnB0ugN+S8yY3crgHXgid1JdGSjEtv9+7UAGOzm4P/nCnBMlu3SwPilx/e
JY2++9dYcbavBpgsKXeXRX9t2V27P1IDpEIOHFNCr496pOlwSQNo+kWR3H/x
pmNd11zWgCsXC+x56LdBVin6WRpQcb5Cm4/23PvmLzVPA3w/SHzWRkc6DLY+
L9IA7sa5rvroGzzZGMMqDdj6e1mMIVrirV+3YqcG2OWr1qxDS8/a0Pa1SwN6
9XzKLNByLM6rO+81QF1tPMsSzQz6fMemRwNWNL+MWf+vHuLOp44OaACrtN3J
Br3awnTF4E+s1+1+Uyd0YKVUepWkJpxyl+buQQd/HEk6Lq0JbpRra73RoUIN
x+zpmpAt1+6+F33Y/sT+YXlNKPCn5+5Dnxz5a6Gmqgl3xiIX70fnsr9Mxetq
wurBruJwdMuFSoctGzRh17vemdPomakoo43WmpCURQKS0WyndUqmtpqg4Sj8
JeVffJn2Pra9JkxYzXSc+df+1PEDv1w14eG6sc50dHSCTup5H03YMbvW5Rpa
73B+w5uTmrBtQCq0Bu36wae8NlETlhiGrHmKjlthcO7haU0Yn54l+Rz9frp6
65VUTaDOya+sRZ84+HEoKF0TBKcG+M3ongAFUekiTZhT41zRg07ySF5nV6sJ
5VF74ub+xPXn5z+oUacJqofEMwXR28Ktk6bqNWHE2uyeEFonhdKR0aQJyl57
p0XQDeSE10CHJig+8y+QQlMUoo9FftGE6ImYe5roE037n1ydxwK3b0mfN6BH
3tnuDpvPggK4GW6Ddh7QFd2wgAUm1dZ0O7SWwLDdqAgL1GaruDqhn/P2fjKW
ZMHhNBGGO1rwuPucZhUWVEdfjwlFR6/cvOrPSha8P/dOvRD9Sj25/OkqFrQu
qVx/HS0p8lrztCkLvOoFw0p//rvvmFNU17JAMkWm7w76qf/yTvMNLBjW1J2p
QQvlqh5IdWFB7Ccrs+6f/+4vI1c5B1kwJmQaKD+J4z3EVxgPZYHy1ZtuSmiF
Vu9TD8JZIBE9vlEVXZz1+YDNYRZouzLWctD1hh0mwcdYwI/ZedwILeZDuh6n
sWCt/rSXK/pMYyLNuYwFvq+XjOajBYdv+VuUs2DWpT6jInQQ5V2T4W0WUBfm
JpaiHSw5afKVLLgTd962Ck1/8kz23SMWtNVl2DehL9wVUN3WyAKF49TtAlNU
svCNZox1Mwuu7Ne3E0SHjm/4DK0sKKsusxVBb9G7dEW5gwXJtgoBdLRC0TJu
bzcLNG+JGeuiMy4HGHgOsyDf9IWMB5ry4PwZ+xEWZLzaWeuNjuwiP83GWBB1
oSE+AL1VllqpOcmC/37H6B9GM1MKVwzMsMBTRkk5HZ0d+2ntXqoWVCh8j29D
5/nYOwfwtcB7luR2+1/4fb80LWyVjhZw2m9au6EF5rSk0/S0QPla3AZPtPM5
mw/XDbTgrcLSA0FoSrWV+7flWtCWGOd/Fh1EN93nbqkFsS1bjLvQa6u1j9h7
acGKfYb9/r/xPEzYl6O+RwsUtTubwtDZjsU1Y95aoOW8puEoenqQPT/FVwt6
TCcELqBv0DVOvg7SgioDJ+NqNH2fwhnzo1oQHui0UnYazz/6ggLDbC1I6fV2
a0E/kNer0MnVgg97bjd+RCcztjzXyNcCncvsrT/Qy9WK+8QLtKB/csuLhX/w
PNS2Uf1WqgW7jeO7TdBLzc6nX3yE8SYKzO+iRdc9Lkyq1oLRXtPgZ+gey2+V
x55ogf+9ndVt6JM2xh37X2C+x4q3xtHdLh+lrBq14L3327kGf3F/2K91arpb
Cwacuo9XoF2DbDNGerSAr3un6CVa72BY8ZdPWrDh4PvhTnRXZF1tyxctuFLN
fP8XrXPCX6h4GPv/+/Imsxkqac+siHIVYIP9mejPnWhW/brAB0ps2DC7tTZJ
gEYMI06Ypiiz4bvI8O+LaCturbiXKhvUTaJW5KN9T1iVimmyQVAy/ncl+rbZ
xiF3Phs8/L85fkaveWjnJWzMhq4U+YfGs2hkx42tLo7ObLC68mbJX3Tg1kwO
z4UNCi1nfi+cTSOxlI+/ZrmxoffC7jYZ9LW9O84XbmeD7ZwfjbroYZZH218v
NrBWi3z2RB/K2mOdF8yGamd6Vis6PfnA6pFUNqw+al70dA6NJCpI9t4/wwYu
L8ChDR2VXxZ1/BwbrlitY/ShPSt/PGCms6HkAJmZN5dGtHt2L9uYw4b4XE2Z
tejHum78olI2/Nlyuroe3d9gRvesZ8Ps3omo8Xk08tb5823dBjaYXzUSXCBI
I68+RW/+08iGQnpLkQL6xiRJTm1lw4TP9+2r0aFMI9HqLjbErFobkIYW8dOe
zfzGhvYey+0r5tOIHpX+vWM+B7TFyg2LhbDejZkhrxZwoGLqXcoztGeK1ryH
whwg1UJKPeiLMkaMXCoHopc1vZJZQCNzmW7W+2Q4YGntd/oouk0nt3y2Jgf0
/V4Jey/E+o1wV42zONDOP18ah15461ZdP5sDArUHTuWjVy571veKzwEnt6mx
HvTVVV/pZxdzQDU8PsBNGNtvqxPBMePAPEvttG0iNJIqWbGAYc6BWyvjB6PQ
19tWnaFZcGDkv7KYHHSv86aS8fUcKMvg+fejrXYGfXy4mQN9jICNAaI0wgis
WmPnwQEj2uO4VAqNVKeZUyJiOLCio3QTRYxG5OYOOG+I5cC2eYGXDdABAcev
KMVxoLcmTdsVzdz4Eh7Hc2DyzH1GMTpcyGr//BTsnw97jbU4jSwK29ielMWB
SCFB2VwJGsnfZp+d/4ADYpb9i45K08if+omhYMKBTfWC47fQdsZnjdY95kCB
y1+hfvRsufaWb0840CyYyreQoZGtzU7zdeuwPi8cDknSaYRu5rr3XifWuyOn
tEKWRo5z3Bc3THKgyJtrZ6FII0JNQ37Pf3Eg635eeTw6LuRgIZnmwNCSFQl1
6NgnicxSAS48zpm+ZsugkSNbKxYmC3GhU8n46g4lrHcK5cMmOheYmt2+F5Rp
ZM/vu8feLOGCsN4STV8NGhnIMn38ehkXWCrfOY/QXub108+MuBCitLNGQhPn
S1qv/92VXLC94lBeid6hTXE5v5YL09ffFVC1aMR5506dLQ5c8MvQe9nGoRGL
WtGO90FcaE5Z/6pbl0YKrCZ66kK4UDOcYb1Gj0YW1L//XhXKBes45yMF6OcN
JQIXI7kQvUV9JEifRszabFgOsVzYmtCiRDegEdOPacGv07jwQEj/UvhSGln+
U1GalHOB0e92uXUlrtcQQWbJbS4kXk1+ZwM08ntqSCvjLhc01a9/q0dXTj80
Dq/iwk9vVnjtKhpZOnuHx9IaLmhkchPrTXF8RfPLbzRzgQ4KB/+spRGeKn9T
1ggXrEIm8wRtaOSlNV/Rd4wLnw+fe5eK9ozk9y+f4MJV+P5V1ZZGMjr4Ye1T
XDgcmHti9SYaoZ3WzqHO4kFuvvKvU5tpZHRaZzSCygMzx8wQa2caqWjTT3Hm
8oAbfeZXpDuN2M9d5Mri8+Dy/NJ2LQ8aGdFdpDmhzYOq9oyiVjQ7YdG9JH0e
3Fg+s0xnF/bX1KD3uSEP/kTJz/9vN+5fNxbrL1nHA6+yK1bZvrhfnljWLOHJ
g/8KucdfhuH6HFaNF/LiwUQjb92VcBqp30wx/bObB/Mk3248GoH5lXvL+nx4
0KmntXjNIRz/uyeTKw7w4Ly55vGWIzRyou+DzdajPBgsvuOkdwLfN4ltKMjl
wa6pqyMj52kk+apf3OV8HryoNOz8dQHjUbZA6lUexDD+as9Np5EPHdo3Iop4
kG+yW0U+A/cPv45T1uU8kBxPM3fOphGJy9yNE9U8ePtz4RFGIY04/m6qW9XL
A5FKw6An92nESbR1jdRnHtwesZb/8gDnm9Kb+1/6eGDKNaOLEBpxMe0sPvWV
Bx5urgqOj2lke3xvwrv/eKC3t9RN4BnOd/mx9QcF+LC+VNg6uQHXt5FU/Q1F
PsSm7T/28BONZIY51Cs58iExXS5hk5gYOeJ1R+qrEx/IvAjV5+JiZOdmGdfy
LXyw75tDXyEpRjS033wz38oHG/UV8nwZMVLcY78gwJMPjz79OMZQFCOV6+xX
1wTywU5sUxdoiZFWmc2VXkl8GO2f9fa4iRhZWG6bX/qSD+FfDeqkDooRyY70
zuxXfDizodRRMEyMKP7to6XW86GvdNB1MlyM6JiHhQU18aEtY1lj92ExYt+V
Y230lg8iSUpG1XFiJGfu+K+aAT7sJHaUunNiZPnmsxvbhbRBx7Vx77cKMeI7
0Tn510wbngwV+k/PiJEF5tY205XacOiQZ1Nygjh5baOV7KygA0kK42LCOhIk
v+ej1A50RsOHmwx05P4L53ejGx6+2qyH5qcJZ4Wg560qPu+ETmwfLDmDvuwV
p3wVbbW1rK4JLa2Qq7tGV4K83Gu0wFJRB+6nOWw6pCdBsv+MnrRFUy4fGU9G
hyYW0ZzR0/tKzuajtW4o0nej1e0oXXXouNEZjWPokbpudwV9CbI2tGZ1NbrQ
pjWoAs0Qjnj+Et1Ek5etQ09cNLBqQoe77LjXjc6/n7/pI7r2xPjM/EUSRHDW
8R0zaPKOd9we/T5pVZ8gQwesLx7i7EHfVvm1m4J2ft5UF4H2WO3tr4h22REh
node3qo6roamPW8pv4uW9OwK4aIfJ/IcXqG/T6RO66Pryo5NfUDXHFt/2Aid
rNN7cRT9P1u/jpI=
        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->NCache[{
        Log[100], -6.907755278982137}, {
       4.605170185988092, -6.907755278982137}],
     BaseStyle->{FontFamily -> "Helvetica", FontSize -> 13},
     Frame->True,
     FrameLabel->{
       FormBox["\"Offset Frequency (Hz)\"", TraditionalForm], 
       FormBox[
       "\"Noise (Hz/\\!\\(\\*SqrtBox[\\(Hz\\)]\\))\"", TraditionalForm]},
     FrameTicks->FrontEndValueCache[{{{{0., 
           FormBox[
            TagBox[
             InterpretationBox["\"1.000\"", 1., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.500\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {1.6094379124341003`, 
           FormBox[
            TagBox[
             InterpretationBox["\"5.000\"", 5., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {-2.302585092994046, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {-2.995732273553991, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.050\"", 0.05, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {-4.605170185988092, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {-5.298317366548036, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.005\"", 0.005, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {-6.907755278982137, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.001\"", 0.001, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.6592600369327783`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659907, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.35667494393873245`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{0., 
           FormBox["\" \"", TraditionalForm]}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm]}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm]}, {-2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm]}, {-4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm]}, {-6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.6592600369327783`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659907, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.35667494393873245`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}, {{{4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {9.210340371976184, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["4", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["5", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["6", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {16.11809565095832, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["7", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.206072645530174`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.611537753638338`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.89921982609012, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.122363377404328`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.304684934198283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.458835614025542`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.592367006650065`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.710150042306449`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {14.508657738524219`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {14.914122846632385`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {15.201804919084164`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {15.424948470398375`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {15.60727002719233, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {15.761420707019587`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {15.89495209964411, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {16.012735135300492`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
           FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
           FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
           FormBox["\" \"", TraditionalForm]}, {16.11809565095832, 
           FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.206072645530174`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.611537753638338`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.89921982609012, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.122363377404328`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.304684934198283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.458835614025542`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.592367006650065`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.710150042306449`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {14.508657738524219`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {14.914122846632385`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {15.201804919084164`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {15.424948470398375`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {15.60727002719233, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {15.761420707019587`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {15.89495209964411, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {16.012735135300492`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}}, {{{{0., 
           FormBox[
            TagBox[
             InterpretationBox["\"1.000\"", 1., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.500\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {1.6094379124341003`, 
           FormBox[
            TagBox[
             InterpretationBox["\"5.000\"", 5., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {-2.302585092994046, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {-2.995732273553991, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.050\"", 0.05, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {-4.605170185988092, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {-5.298317366548036, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.005\"", 0.005, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {-6.907755278982137, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.001\"", 0.001, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.6592600369327783`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659907, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.35667494393873245`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{0., 
           FormBox["\" \"", TraditionalForm]}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm]}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm]}, {-2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm]}, {-4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm]}, {-6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.6592600369327783`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659907, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.35667494393873245`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}, {{{4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {9.210340371976184, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["4", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["5", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["6", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {16.11809565095832, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox["7", Power, Editable -> True, Selectable -> True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.206072645530174`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.611537753638338`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.89921982609012, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.122363377404328`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.304684934198283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.458835614025542`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.592367006650065`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.710150042306449`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {14.508657738524219`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {14.914122846632385`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {15.201804919084164`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {15.424948470398375`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {15.60727002719233, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {15.761420707019587`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {15.89495209964411, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {16.012735135300492`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {9.210340371976184, 
           FormBox["\" \"", TraditionalForm]}, {11.512925464970229`, 
           FormBox["\" \"", TraditionalForm]}, {13.815510557964274`, 
           FormBox["\" \"", TraditionalForm]}, {16.11809565095832, 
           FormBox["\" \"", TraditionalForm]}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.206072645530174`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.611537753638338`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.89921982609012, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.122363377404328`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.304684934198283`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.458835614025542`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.592367006650065`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.710150042306449`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {14.508657738524219`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {14.914122846632385`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {15.201804919084164`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {15.424948470398375`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {15.60727002719233, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {15.761420707019587`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {15.89495209964411, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {16.012735135300492`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}}],
     GridLines->
      NCache[{{4.605170185988092, 6.907755278982137, 9.210340371976184, 
        11.512925464970229`, 13.815510557964274`, 16.11809565095832, 
        5.298317366548036, 5.703782474656201, 5.991464547107982, 
        6.214608098422191, 6.396929655216146, 6.551080335043404, 
        6.684611727667927, 6.802394763324311, 7.600902459542082, 
        8.006367567650246, 8.294049640102028, 8.517193191416238, 
        8.699514748210191, 8.85366542803745, 8.987196820661973, 
        9.104979856318357, 9.903487552536127, 10.308952660644293`, 
        10.596634733096073`, 10.819778284410283`, 11.002099841204238`, 
        11.156250521031495`, 11.289781913656018`, 11.407564949312402`, 
        12.206072645530174`, 12.611537753638338`, 12.89921982609012, 
        13.122363377404328`, 13.304684934198283`, 13.458835614025542`, 
        13.592367006650065`, 13.710150042306449`, 14.508657738524219`, 
        14.914122846632385`, 15.201804919084164`, 15.424948470398375`, 
        15.60727002719233, 15.761420707019587`, 15.89495209964411, 
        16.012735135300492`}, {0, -Log[2], 
         Log[5], -Log[10], -Log[20], -Log[100], -Log[200], -
         Log[1000], -6.214608098422191, -5.809142990314028, \
-5.521460917862246, -5.115995809754082, -4.961845129926823, \
-4.8283137373023015`, -4.710530701645918, -3.912023005428146, \
-3.506557897319982, -3.2188758248682006`, -2.8134107167600364`, \
-2.6592600369327783`, -2.5257286443082556`, -2.4079456086518722`, \
-1.6094379124341003`, -1.203972804325936, -0.916290731874155, \
-0.5108256237659907, -0.35667494393873245`, -0.2231435513142097, \
-0.10536051565782628`, 0.6931471805599453, 1.0986122886681098`, 
         1.3862943611198906`}}, {{4.605170185988092, 6.907755278982137, 
        9.210340371976184, 11.512925464970229`, 13.815510557964274`, 
        16.11809565095832, 5.298317366548036, 5.703782474656201, 
        5.991464547107982, 6.214608098422191, 6.396929655216146, 
        6.551080335043404, 6.684611727667927, 6.802394763324311, 
        7.600902459542082, 8.006367567650246, 8.294049640102028, 
        8.517193191416238, 8.699514748210191, 8.85366542803745, 
        8.987196820661973, 9.104979856318357, 9.903487552536127, 
        10.308952660644293`, 10.596634733096073`, 10.819778284410283`, 
        11.002099841204238`, 11.156250521031495`, 11.289781913656018`, 
        11.407564949312402`, 12.206072645530174`, 12.611537753638338`, 
        12.89921982609012, 13.122363377404328`, 13.304684934198283`, 
        13.458835614025542`, 13.592367006650065`, 13.710150042306449`, 
        14.508657738524219`, 14.914122846632385`, 15.201804919084164`, 
        15.424948470398375`, 15.60727002719233, 15.761420707019587`, 
        15.89495209964411, 16.012735135300492`}, {
        0, -0.6931471805599453, 
         1.6094379124341003`, -2.302585092994046, -2.995732273553991, \
-4.605170185988092, -5.298317366548036, -6.907755278982137, \
-6.214608098422191, -5.809142990314028, -5.521460917862246, \
-5.115995809754082, -4.961845129926823, -4.8283137373023015`, \
-4.710530701645918, -3.912023005428146, -3.506557897319982, \
-3.2188758248682006`, -2.8134107167600364`, -2.6592600369327783`, \
-2.5257286443082556`, -2.4079456086518722`, -1.6094379124341003`, \
-1.203972804325936, -0.916290731874155, -0.5108256237659907, \
-0.35667494393873245`, -0.2231435513142097, -0.10536051565782628`, 
         0.6931471805599453, 1.0986122886681098`, 1.3862943611198906`}}],
     ImageSize->Scaled[0.8],
     Method->{},
     PlotLabel->FormBox["\"Total VCO frequency noise\"", TraditionalForm],
     PlotRange->NCache[{{
         Log[100], 
         Log[10000000]}, {-6.907755278982137, 0.}}, {{4.605170185988092, 
       16.11809565095832}, {-6.907755278982137, 0.}}],
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], {None, None}},
     Ticks->{{{4.605170185988092, 
         FormBox["100", TraditionalForm]}, {6.907755278982137, 
         FormBox["1000", TraditionalForm]}, {9.210340371976184, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox["4", Power, Editable -> True, Selectable -> True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {11.512925464970229`, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox["5", Power, Editable -> True, Selectable -> True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {13.815510557964274`, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox["6", Power, Editable -> True, Selectable -> True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {16.11809565095832, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox["7", Power, Editable -> True, Selectable -> True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.396929655216146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.551080335043404, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.684611727667927, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.802394763324311, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {7.600902459542082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.006367567650246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.294049640102028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.517193191416238, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.699514748210191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.85366542803745, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.987196820661973, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {9.104979856318357, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {9.903487552536127, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.308952660644293`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.596634733096073`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {10.819778284410283`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.002099841204238`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.156250521031495`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.289781913656018`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {11.407564949312402`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {12.206072645530174`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {12.611537753638338`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {12.89921982609012, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {13.122363377404328`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {13.304684934198283`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {13.458835614025542`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {13.592367006650065`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {13.710150042306449`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {14.508657738524219`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {14.914122846632385`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {15.201804919084164`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {15.424948470398375`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {15.60727002719233, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {15.761420707019587`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {15.89495209964411, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {16.012735135300492`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, {{0, 
         FormBox[
          TagBox[
           InterpretationBox["\"1.000\"", 1., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {
         NCache[-Log[2], -0.6931471805599453], 
         FormBox[
          TagBox[
           InterpretationBox["\"0.500\"", 0.5, AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {
         NCache[
          Log[5], 1.6094379124341003`], 
         FormBox[
          TagBox[
           InterpretationBox["\"5.000\"", 5., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {
         NCache[-Log[10], -2.302585092994046], 
         FormBox[
          TagBox[
           InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {
         NCache[-Log[20], -2.995732273553991], 
         FormBox[
          TagBox[
           InterpretationBox["\"0.050\"", 0.05, AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {
         NCache[-Log[100], -4.605170185988092], 
         FormBox[
          TagBox[
           InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {
         NCache[-Log[200], -5.298317366548036], 
         FormBox[
          TagBox[
           InterpretationBox["\"0.005\"", 0.005, AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {
         NCache[-Log[1000], -6.907755278982137], 
         FormBox[
          TagBox[
           InterpretationBox["\"0.001\"", 0.001, AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {-6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.809142990314028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.521460917862246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.115995809754082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.961845129926823, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.8283137373023015`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.710530701645918, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.506557897319982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.2188758248682006`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.8134107167600364`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.6592600369327783`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.5257286443082556`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.4079456086518722`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.203972804325936, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.916290731874155, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.5108256237659907, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.35667494393873245`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.2231435513142097, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.10536051565782628`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.0986122886681098`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.3862943611198906`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}}], {-1, -0.6180339887498948}, {
    Left, Bottom}, {2, 1.2360679774997896`}], InsetBox[
    GraphicsBox[{{{InsetBox[
         GraphicsBox[
          {RGBColor[0, 
            NCache[
             Rational[2, 3], 0.6666666666666666], 0], 
           RectangleBox[{1, 1}]}], {0.08, 0.08}, {Left, Bottom}, {1, 1}], 
        InsetBox["\<\"Tuning\"\>", {1.21, 0.58}, {-1, 0}, Automatic, {1, 
         0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[0, 0, 1], RectangleBox[{1, 1}]}], {0.08, 1.24}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"Oscillator\"\>", {1.21, 1.74}, {-1, 0}, Automatic, {1, 
         0}]}, {InsetBox[
         GraphicsBox[
          {RGBColor[1, 0, 0], RectangleBox[{1, 1}]}], {0.08, 2.4}, {
         Left, Bottom}, {1, 1}], 
        InsetBox["\<\"Total\"\>", {1.21, 2.9}, {-1, 0}, Automatic, {1, 
         0}]}}, {}},
     AspectRatio->0.6,
     BaseStyle->{FontFamily -> "Helvetica", FontSize -> 10},
     PlotRange->{{-0.1, 6.26}, {-0.1, 3.5799999999999996`}}], {0.7, 0.}, {
    Left, Bottom}, {0.5, 0.3}]},
  AspectRatio->Automatic,
  Background->None,
  ColorOutput->Automatic,
  ImageSize->Scaled[0.8],
  PlotRange->All]], "Output",
 CellChangeTimes->{
  3.4482031343293753`*^9, {3.4482031890325003`*^9, 3.4482032109543753`*^9}, 
   3.4482033593137503`*^9, 3.4482045925793753`*^9, 3.4482060380168753`*^9, 
   3.4482207611418753`*^9, 3.4483096861262503`*^9, 3.4483097993137503`*^9, 
   3.4483098630168753`*^9, 3.4483099208137503`*^9, 3.4483101489387503`*^9, 
   3.4483102364231253`*^9, 3.4483102709075003`*^9, 3.4483104728450003`*^9, 
   3.4483105412356253`*^9, 3.4483106540168753`*^9, {3.4483107818137503`*^9, 
   3.4483108277668753`*^9}, 3.4483120190793753`*^9, 3.4483120595793753`*^9, 
   3.4483121010637503`*^9, {3.4483121390793753`*^9, 3.4483121590481253`*^9}, {
   3.4483124054231253`*^9, 3.4483124282356253`*^9}, 3.4483126402200003`*^9, 
   3.4483753303125*^9, 3.44837544859375*^9, {3.44837992515625*^9, 
   3.448379936875*^9}, 3.44839880859375*^9, {3.448398840796875*^9, 
   3.44839886703125*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Readback", "Subsubtitle",
 CellChangeTimes->{{3.447186576652625*^9, 3.44718659091825*^9}, {
  3.447187881965125*^9, 3.447187883183875*^9}, {3.44751414086124*^9, 
  3.447514156905958*^9}, {3.4481979829543753`*^9, 3.4481979839856253`*^9}, {
  3.4481980255793753`*^9, 3.4481980385481253`*^9}, {3.4481991368762503`*^9, 
  3.4481991725950003`*^9}, {3.4481993053293753`*^9, 3.4481993083293753`*^9}, {
  3.4481993531887503`*^9, 3.4481993602356253`*^9}, {3.4482000287043753`*^9, 
  3.4482000294856253`*^9}, {3.4482028025950003`*^9, 3.4482028090325003`*^9}, {
  3.4482068017356253`*^9, 3.4482068038450003`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"n", "=", "6"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"z1", "[", "n", "]"}], "=", "\[Infinity]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"z2", "[", "n", "]"}], "=", "100"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opamp", "[", "n", "]"}], "=", 
   RowBox[{"OpAmp", "[", 
    RowBox[{"1", ",", 
     RowBox[{"z1", "[", "n", "]"}], ",", 
     RowBox[{"z2", "[", "n", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opampnoise", "[", "n", "]"}], "=", 
   RowBox[{"OpAmpNoise", "[", 
    RowBox[{"1", ",", 
     RowBox[{"z1", "[", "n", "]"}], ",", 
     RowBox[{"z2", "[", "n", "]"}], ",", "1.7*^-9", ",", "1.5*^-12"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4481984260950003`*^9, 3.4481984495950003`*^9}, {
   3.4481985188606253`*^9, 3.4481985223918753`*^9}, {3.4481986649387503`*^9, 
   3.4481986653450003`*^9}, 3.4481988381731253`*^9, {3.4481991067825003`*^9, 
   3.4481991256418753`*^9}, 3.4481992184700003`*^9, {3.4481992543137503`*^9, 
   3.4481992572356253`*^9}, {3.4481993217356253`*^9, 
   3.4481993325637503`*^9}, {3.4481996671887503`*^9, 3.4481996811418753`*^9}, 
   3.4481997230481253`*^9, {3.4481997635325003`*^9, 3.4481997840637503`*^9}, {
   3.4481999448762503`*^9, 3.4481999738606253`*^9}, {3.4482004528918753`*^9, 
   3.4482004533450003`*^9}, {3.4482009218293753`*^9, 
   3.4482009606887503`*^9}, {3.4482059647981253`*^9, 
   3.4482059744231253`*^9}, {3.4482068235950003`*^9, 
   3.4482068595325003`*^9}, {3.4482070691575003`*^9, 
   3.4482070732356253`*^9}, {3.4482071667825003`*^9, 
   3.4482072954231253`*^9}, {3.4482073619543753`*^9, 
   3.4482073889231253`*^9}, {3.4482074337825003`*^9, 
   3.4482074577200003`*^9}, {3.4482075921418753`*^9, 
   3.4482076822512503`*^9}, {3.4482077139856253`*^9, 3.4482077533293753`*^9}, 
   3.4482080842043753`*^9, {3.4482157725481253`*^9, 3.4482157907356253`*^9}, {
   3.4482160077668753`*^9, 3.4482160230325003`*^9}, {3.4482165793606253`*^9, 
   3.4482165930168753`*^9}, {3.4482202176575003`*^9, 
   3.4482202425012503`*^9}, {3.4482222349856253`*^9, 3.4482222501262503`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"n", "=", "7"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"z1", "[", "n", "]"}], "=", 
   RowBox[{"par", "[", 
    RowBox[{"4990.", ",", 
     RowBox[{"200", "+", 
      FractionBox["1", 
       RowBox[{"s", " ", "20*^-6"}]]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"z2", "[", "n", "]"}], "=", "3570."}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opamp", "[", "n", "]"}], "=", 
   RowBox[{"OpAmp", "[", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"z1", "[", "n", "]"}], ",", 
     RowBox[{"z2", "[", "n", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opampnoise", "[", "n", "]"}], "=", 
   RowBox[{"OpAmpNoise", "[", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"z1", "[", "n", "]"}], ",", 
     RowBox[{"z2", "[", "n", "]"}], ",", "1.7*^-9", ",", "1.5*^-12"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4481984260950003`*^9, 3.4481984495950003`*^9}, {
   3.4481985188606253`*^9, 3.4481985223918753`*^9}, {3.4481986649387503`*^9, 
   3.4481986653450003`*^9}, 3.4481988381731253`*^9, {3.4481991067825003`*^9, 
   3.4481991256418753`*^9}, 3.4481992184700003`*^9, {3.4481992543137503`*^9, 
   3.4481992572356253`*^9}, {3.4481993217356253`*^9, 
   3.4481993325637503`*^9}, {3.4481996671887503`*^9, 3.4481996811418753`*^9}, 
   3.4481997230481253`*^9, {3.4481997635325003`*^9, 3.4481997840637503`*^9}, {
   3.4481999448762503`*^9, 3.4481999738606253`*^9}, {3.4482004528918753`*^9, 
   3.4482004533450003`*^9}, {3.4482009218293753`*^9, 
   3.4482009606887503`*^9}, {3.4482059647981253`*^9, 
   3.4482059744231253`*^9}, {3.4482068235950003`*^9, 
   3.4482068595325003`*^9}, {3.4482070691575003`*^9, 
   3.4482070732356253`*^9}, {3.4482071667825003`*^9, 
   3.4482072954231253`*^9}, {3.4482073619543753`*^9, 
   3.4482073889231253`*^9}, {3.4482074337825003`*^9, 
   3.4482074577200003`*^9}, {3.4482075921418753`*^9, 
   3.4482076822512503`*^9}, {3.4482077139856253`*^9, 3.4482077533293753`*^9}, 
   3.4482080842043753`*^9, {3.4482157725481253`*^9, 3.4482157907356253`*^9}, {
   3.4482160077668753`*^9, 3.4482160230325003`*^9}, {3.4482165793606253`*^9, 
   3.4482165930168753`*^9}, {3.4482202735793753`*^9, 
   3.4482202916575003`*^9}, {3.4482203650012503`*^9, 
   3.4482203658606253`*^9}, {3.4482205374856253`*^9, 
   3.4482205702043753`*^9}, {3.4482207657043753`*^9, 3.4482207668293753`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"opamp", "[", "7", "]"}], "/.", 
      RowBox[{"s", "\[Rule]", 
       RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "#"}]}]}], ")"}], 
    "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"1*^-6", ",", "1*^6"}], "}"}]}], "//", "Abs"}]], "Input",
 CellChangeTimes->{{3.4482159192200003`*^9, 3.4482159822668753`*^9}, 
   3.4482202966418753`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.715430861723599`", ",", "18.565430847049402`"}], "}"}]], "Output",\

 CellChangeTimes->{{3.4482159773762503`*^9, 3.4482160253762503`*^9}, {
   3.4482165825012503`*^9, 3.4482165956262503`*^9}, 3.4482202980793753`*^9, 
   3.4482205733762503`*^9, 3.4482207695168753`*^9, 3.4482216594856253`*^9, 
   3.4483096864231253`*^9, 3.4483097995481253`*^9, 3.4483098632825003`*^9, 
   3.4483099215950003`*^9, 3.4483102367043753`*^9, 3.4483102711575003`*^9, 
   3.4483108280325003`*^9, 3.4483121593606253`*^9, 3.4483126404856253`*^9, 
   3.4483753304375*^9, 3.44837544878125*^9, {3.44837992528125*^9, 
   3.448379937*^9}, 3.44839880871875*^9, 3.448398867171875*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"stages2", "=", "7"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opamp", "[", "r", "]"}], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"OpAmpProduct", "[", 
     RowBox[{"opamp", ",", "stages2"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opampnoise", "[", "r", "]"}], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"OpAmpNoiseProduct", "[", 
     RowBox[{"opamp", ",", "opampnoise", ",", "stages2"}], "]"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.4482001880950003`*^9, 3.4482002000950003`*^9}, {
  3.4482009844700003`*^9, 3.4482009886887503`*^9}, {3.4482010215950003`*^9, 
  3.4482010232512503`*^9}, {3.4482079066575003`*^9, 3.4482079142512503`*^9}, {
  3.4482203052668753`*^9, 3.4482203107981253`*^9}}],

Cell[CellGroupData[{

Cell["Output stage only", "Subsection",
 CellChangeTimes->{{3.4482211279543753`*^9, 3.4482211309075003`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "\"\<Frequency\>\"", ",", "\"\<Magnitude (dB)\>\"", ",", 
        "\"\<Phase (\[Degree])\>\""}], "}"}], ",", 
      RowBox[{"{", "}"}]}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"#", ",", 
        RowBox[{
         RowBox[{"dB", "[", 
          FractionBox[
           RowBox[{"opamp", "[", "r", "]"}], 
           RowBox[{"opamp", "[", "0", "]"}]], "]"}], "/.", 
         RowBox[{"s", "\[Rule]", 
          RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "#"}]}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Arg", "[", 
           FractionBox[
            RowBox[{"opamp", "[", "r", "]"}], 
            RowBox[{"opamp", "[", "0", "]"}]], "]"}], "/", "Degree"}], "/.", 
         RowBox[{"s", "\[Rule]", 
          RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "#"}]}]}]}], "}"}],
       "&"}], "/@", 
     RowBox[{"{", 
      RowBox[{
      "0", ",", "0.1", ",", "1", ",", "10", ",", "100", ",", "1000", ",", 
       "1*^4", ",", "1*^5"}], "}"}]}]}], "]"}], "//", "TableForm"}]], "Input",\

 CellChangeTimes->{{3.4480255572764997`*^9, 3.4480257354483747`*^9}, {
   3.4482002402825003`*^9, 3.4482004240168753`*^9}, {3.4482004740793753`*^9, 
   3.4482005057512503`*^9}, {3.4482009979543753`*^9, 
   3.4482010018450003`*^9}, {3.4482012028293753`*^9, 
   3.4482012032512503`*^9}, {3.4482079336731253`*^9, 3.4482079354856253`*^9}, 
   3.4482212518137503`*^9, {3.4482213495012503`*^9, 3.4482213610793753`*^9}}],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {"\<\"Frequency\"\>", "\<\"Magnitude (dB)\"\>", "\<\"Phase \
(\[Degree])\"\>"},
    {"\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
    {"0", 
     RowBox[{"-", "2.9086465902239333`"}], "0"},
    {"0.1`", 
     RowBox[{"-", "2.890240143440485`"}], "3.58751552689982`"},
    {"1", 
     RowBox[{"-", "1.3721498716687712`"}], "31.67247801327932`"},
    {"10", "13.213808502735041`", "67.17501338450572`"},
    {"100", "24.736857178083593`", "20.818545433782432`"},
    {"1000", "25.3672407954318`", "2.1906740602043295`"},
    {"10000", "25.37403200106243`", "0.2191863865045223`"},
    {"100000", "25.37409996693617`", "0.021918757743928916`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  TableForm[{{"Frequency", "Magnitude (dB)", "Phase (\[Degree])"}, {}, {
    0, -2.9086465902239333`, 0}, {0.1, -2.890240143440485, 
    3.58751552689982}, {1, -1.3721498716687712`, 31.67247801327932}, {
    10, 13.213808502735041`, 67.17501338450572}, {
    100, 24.736857178083593`, 20.818545433782432`}, {
    1000, 25.3672407954318, 2.1906740602043295`}, {
    10000, 25.37403200106243, 0.2191863865045223}, {
    100000, 25.37409996693617, 0.021918757743928916`}}]]], "Output",
 CellChangeTimes->{{3.4482213769543753`*^9, 3.4482213788137503`*^9}, 
   3.4483096867981253`*^9, 3.4483097999231253`*^9, 3.4483098636887503`*^9, 
   3.4483099223606253`*^9, 3.4483102371418753`*^9, 3.4483102712200003`*^9, 
   3.4483108285012503`*^9, 3.4483121599856253`*^9, 3.4483126405325003`*^9, 
   3.448375331171875*^9, 3.4483754488125*^9, {3.448379925765625*^9, 
   3.44837993703125*^9}, 3.448398809234375*^9, 3.448398867703125*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "\"\<Frequency\>\"", ",", "\"\<Input Noise\>\"", ",", 
        "\"\<Output Noise\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Hz\>\"", ",", "\"\<nV/\!\(\*SqrtBox[\(Hz\)]\)\>\"", ",", 
        "\"\<nV/\!\(\*SqrtBox[\(Hz\)]\)\>\""}], "}"}], ",", 
      RowBox[{"{", "}"}]}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"#", ",", 
        RowBox[{
         RowBox[{"1*^9", 
          SqrtBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"Abs", "[", 
              RowBox[{"opampnoise", "[", "6", "]"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"Abs", "[", 
              RowBox[{"opampnoise", "[", "7", "]"}], "]"}], "2"]}]]}], "/.", 
         RowBox[{"s", "\[Rule]", 
          RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "#"}]}]}], ",", 
        RowBox[{"1*^9", 
         RowBox[{"Abs", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"opamp", "[", "6", "]"}], 
            RowBox[{"opamp", "[", "7", "]"}], " ", 
            SqrtBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                RowBox[{"opampnoise", "[", "6", "]"}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                RowBox[{"opampnoise", "[", "7", "]"}], "]"}], "2"]}]]}], "/.",
            
           RowBox[{"s", "\[Rule]", 
            RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "#"}]}]}], 
          "]"}]}]}], "}"}], "&"}], "/@", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "10", ",", "100", ",", "1000", ",", "1*^4", ",", "1*^5"}], 
      "}"}]}]}], "]"}], "//", "TableForm"}]], "Input",
 CellChangeTimes->{{3.4480255572764997`*^9, 3.4480257354483747`*^9}, {
  3.4482002402825003`*^9, 3.4482003830793753`*^9}, {3.4482005854543753`*^9, 
  3.4482006498762503`*^9}, {3.4482007616731253`*^9, 3.4482007644231253`*^9}, {
  3.4482010066106253`*^9, 3.4482010103762503`*^9}, {3.4482010560325003`*^9, 
  3.4482011812825003`*^9}, {3.4482012846106253`*^9, 3.4482013113137503`*^9}, {
  3.4482079741418753`*^9, 3.4482079767981253`*^9}, {3.4482080190168753`*^9, 
  3.4482080333450003`*^9}, {3.4482162843762503`*^9, 3.4482162875950003`*^9}, {
  3.4482214500168753`*^9, 3.4482215489543753`*^9}}],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {"\<\"Frequency\"\>", "\<\"Input Noise\"\>", "\<\"Output Noise\"\>"},
    {"\<\"Hz\"\>", "\<\"nV/\\!\\(\\*SqrtBox[\\(Hz\\)]\\)\"\>", "\<\"nV/\\!\\(\
\\*SqrtBox[\\(Hz\\)]\\)\"\>"},
    {"\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
    {"1", "14.266483260015924`", "12.181743130905401`"},
    {"10", "4.980986376458963`", "22.803724160385524`"},
    {"100", "3.374656205299662`", "58.22002590854156`"},
    {"1000", "3.3333526666306996`", "61.83627272591873`"},
    {"10000", "3.3329235524004566`", "61.8766727105338`"},
    {"100000", "3.3329192595251933`", "61.877077189680584`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  TableForm[{{"Frequency", "Input Noise", "Output Noise"}, {
    "Hz", "nV/\!\(\*SqrtBox[\(Hz\)]\)", "nV/\!\(\*SqrtBox[\(Hz\)]\)"}, {}, {
    1, 14.266483260015924`, 12.181743130905401`}, {
    10, 4.980986376458963, 22.803724160385524`}, {
    100, 3.374656205299662, 58.22002590854156}, {
    1000, 3.3333526666306996`, 61.83627272591873}, {
    10000, 3.3329235524004566`, 61.8766727105338}, {
    100000, 3.3329192595251933`, 61.877077189680584`}}]]], "Output",
 CellChangeTimes->{
  3.4482215105012503`*^9, {3.4482215435481253`*^9, 3.4482215502512503`*^9}, 
   3.4483096868450003`*^9, 3.4483097999543753`*^9, 3.4483098637356253`*^9, 
   3.4483099242356253`*^9, 3.4483102371887503`*^9, 3.4483102713137503`*^9, 
   3.4483108285325003`*^9, 3.4483121600325003`*^9, 3.4483126405950003`*^9, 
   3.448375331234375*^9, 3.44837544884375*^9, {3.44837992578125*^9, 
   3.448379937078125*^9}, 3.448398809265625*^9, 3.448398867734375*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input to monitor overall", "Subsection",
 CellChangeTimes->{{3.4482211571418753`*^9, 3.4482211673606253`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "\"\<Frequency\>\"", ",", "\"\<Magnitude (dB)\>\"", ",", 
        "\"\<Phase (\[Degree])\>\""}], "}"}], ",", 
      RowBox[{"{", "}"}]}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"#", ",", 
        RowBox[{
         RowBox[{"dB", "[", 
          RowBox[{"opamp", "[", "r", "]"}], "]"}], "/.", 
         RowBox[{"s", "\[Rule]", 
          RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "#"}]}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Arg", "[", 
           RowBox[{"opamp", "[", "r", "]"}], "]"}], "/", "Degree"}], "/.", 
         RowBox[{"s", "\[Rule]", 
          RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "#"}]}]}]}], "}"}],
       "&"}], "/@", 
     RowBox[{"{", 
      RowBox[{
      "0", ",", "0.1", ",", "1", ",", "10", ",", "100", ",", "1000", ",", 
       "1*^4", ",", "1*^5"}], "}"}]}]}], "]"}], "//", "TableForm"}]], "Input",\

 CellChangeTimes->{{3.4480255572764997`*^9, 3.4480257354483747`*^9}, {
  3.4482002402825003`*^9, 3.4482004240168753`*^9}, {3.4482004740793753`*^9, 
  3.4482005057512503`*^9}, {3.4482009979543753`*^9, 3.4482010018450003`*^9}, {
  3.4482012028293753`*^9, 3.4482012032512503`*^9}, {3.4482079336731253`*^9, 
  3.4482079354856253`*^9}, {3.4482213248606253`*^9, 3.4482213261575003`*^9}}],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {"\<\"Frequency\"\>", "\<\"Magnitude (dB)\"\>", "\<\"Phase \
(\[Degree])\"\>"},
    {"\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
    {"0", 
     RowBox[{"-", "11.855317151000936`"}], "0"},
    {"0.1`", 
     RowBox[{"-", "11.855243612837295`"}], "0.007166167569603273`"},
    {"1", 
     RowBox[{"-", "11.850136101737334`"}], "0.04966559372913644`"},
    {"10", 
     RowBox[{"-", "11.839326609822619`"}], 
     RowBox[{"-", "0.010076909458667203`"}]},
    {"100", 
     RowBox[{"-", "11.852906915493667`"}], 
     RowBox[{"-", "0.039848989245421636`"}]},
    {"1000", 
     RowBox[{"-", "11.855256437024556`"}], 
     RowBox[{"-", "0.026200961331774204`"}]},
    {"10000", 
     RowBox[{"-", "11.855315818414772`"}], 
     RowBox[{"-", "0.21859892376443063`"}]},
    {"100000", 
     RowBox[{"-", "11.858531099151293`"}], 
     RowBox[{"-", "2.18135531162238`"}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  TableForm[{{"Frequency", "Magnitude (dB)", "Phase (\[Degree])"}, {}, {
    0, -11.855317151000936`, 0}, {0.1, -11.855243612837295`, 
    0.007166167569603273}, {1, -11.850136101737334`, 0.04966559372913644}, {
    10, -11.839326609822619`, -0.010076909458667203`}, {
    100, -11.852906915493667`, -0.039848989245421636`}, {
    1000, -11.855256437024556`, -0.026200961331774204`}, {
    10000, -11.855315818414772`, -0.21859892376443063`}, {
    100000, -11.858531099151293`, -2.18135531162238}}]]], "Output",
 CellChangeTimes->{{3.4482004032512503`*^9, 3.4482004244700003`*^9}, {
   3.4482004588137503`*^9, 3.4482005061575003`*^9}, {3.4482009985168753`*^9, 
   3.4482010022356253`*^9}, 3.4482012035950003`*^9, {3.4482045351575003`*^9, 
   3.4482045457825003`*^9}, 3.4482060046106253`*^9, 3.4482079363450003`*^9, 
   3.4482080884700003`*^9, {3.4482157780325003`*^9, 3.4482157942825003`*^9}, {
   3.4482160315950003`*^9, 3.4482160340481253`*^9}, 3.4482165994075003`*^9, 
   3.4482203139075003`*^9, 3.4482203703137503`*^9, {3.4482205473137503`*^9, 
   3.4482205764856253`*^9}, 3.4482207745325003`*^9, 3.4482210086106253`*^9, 
   3.4482212232356253`*^9, {3.4482212734543753`*^9, 3.4482213411418753`*^9}, 
   3.4482215657356253`*^9, 3.4483096868918753`*^9, 3.4483097999856253`*^9, 
   3.4483098637825003`*^9, 3.4483099242981253`*^9, 3.4483102372356253`*^9, 
   3.4483102713450003`*^9, 3.4483108285637503`*^9, 3.4483121600950003`*^9, 
   3.4483126406418753`*^9, 3.448375331296875*^9, 3.448375448875*^9, {
   3.4483799258125*^9, 3.44837993709375*^9}, 3.4483988093125*^9, 
   3.448398867765625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "\"\<Frequency\>\"", ",", "\"\<Input Noise\>\"", ",", 
        "\"\<Output Noise\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Hz\>\"", ",", "\"\<nV/\!\(\*SqrtBox[\(Hz\)]\)\>\"", ",", 
        "\"\<nV/\!\(\*SqrtBox[\(Hz\)]\)\>\""}], "}"}], ",", 
      RowBox[{"{", "}"}]}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"#", ",", 
        RowBox[{"1*^9", 
         RowBox[{"Abs", "[", 
          RowBox[{
           RowBox[{"opampnoise", "[", "r", "]"}], "/.", 
           RowBox[{"s", "\[Rule]", 
            RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "#"}]}]}], 
          "]"}]}], ",", 
        RowBox[{"1*^9", 
         RowBox[{"Abs", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"opamp", "[", "r", "]"}], " ", 
            RowBox[{"opampnoise", "[", "r", "]"}]}], "/.", 
           RowBox[{"s", "\[Rule]", 
            RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "#"}]}]}], 
          "]"}]}]}], "}"}], "&"}], "/@", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "10", ",", "100", ",", "1000", ",", "1*^4", ",", "1*^5"}], 
      "}"}]}]}], "]"}], "//", "TableForm"}]], "Input",
 CellChangeTimes->{{3.4480255572764997`*^9, 3.4480257354483747`*^9}, {
   3.4482002402825003`*^9, 3.4482003830793753`*^9}, {3.4482005854543753`*^9, 
   3.4482006498762503`*^9}, {3.4482007616731253`*^9, 
   3.4482007644231253`*^9}, {3.4482010066106253`*^9, 
   3.4482010103762503`*^9}, {3.4482010560325003`*^9, 
   3.4482011812825003`*^9}, {3.4482012846106253`*^9, 
   3.4482013113137503`*^9}, {3.4482079741418753`*^9, 
   3.4482079767981253`*^9}, {3.4482080190168753`*^9, 
   3.4482080333450003`*^9}, {3.4482162843762503`*^9, 3.4482162875950003`*^9}, 
   3.4482216167825003`*^9}],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {"\<\"Frequency\"\>", "\<\"Input Noise\"\>", "\<\"Output Noise\"\>"},
    {"\<\"Hz\"\>", "\<\"nV/\\!\\(\\*SqrtBox[\\(Hz\\)]\\)\"\>", "\<\"nV/\\!\\(\
\\*SqrtBox[\\(Hz\\)]\\)\"\>"},
    {"\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
    {"1", "1938.0379617121707`", "495.2853412492276`"},
    {"10", "627.4338137121773`", "160.54677628602093`"},
    {"100", "243.24163514843156`", "62.1430505285833`"},
    {"1000", "247.68187312588685`", "63.260322494280096`"},
    {"10000", "247.67944352664247`", "63.2592694756638`"},
    {"100000", "247.7617185176828`", "63.25686284340153`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  TableForm[{{"Frequency", "Input Noise", "Output Noise"}, {
    "Hz", "nV/\!\(\*SqrtBox[\(Hz\)]\)", "nV/\!\(\*SqrtBox[\(Hz\)]\)"}, {}, {
    1, 1938.0379617121707`, 495.2853412492276}, {
    10, 627.4338137121773, 160.54677628602093`}, {
    100, 243.24163514843156`, 62.1430505285833}, {
    1000, 247.68187312588685`, 63.260322494280096`}, {
    10000, 247.67944352664247`, 63.2592694756638}, {
    100000, 247.7617185176828, 63.25686284340153}}]]], "Output",
 CellChangeTimes->{{3.4482002904075003`*^9, 3.4482003116262503`*^9}, {
   3.4482003656575003`*^9, 3.4482003838918753`*^9}, {3.4482006083450003`*^9, 
   3.4482006503450003`*^9}, 3.4482007649387503`*^9, {3.4482010071418753`*^9, 
   3.4482010263293753`*^9}, {3.4482010660793753`*^9, 
   3.4482010944700003`*^9}, {3.4482011370325003`*^9, 
   3.4482011821575003`*^9}, {3.4482012851887503`*^9, 3.4482013117200003`*^9}, 
   3.4482045485637503`*^9, {3.4482046585637503`*^9, 3.4482046992512503`*^9}, 
   3.4482060093918753`*^9, 3.4482079778450003`*^9, 3.4482080339231253`*^9, 
   3.4482080951575003`*^9, {3.4482162884231253`*^9, 3.4482162934387503`*^9}, 
   3.4482210108918753`*^9, 3.4482212904856253`*^9, 3.4482215670012503`*^9, 
   3.4482216174543753`*^9, 3.4483096869387503`*^9, 3.4483098000168753`*^9, 
   3.4483098638450003`*^9, 3.4483099243450003`*^9, 3.4483102372825003`*^9, 
   3.4483102713918753`*^9, 3.4483108286106253`*^9, 3.4483121601418753`*^9, 
   3.4483126406887503`*^9, 3.44837533140625*^9, 3.448375448921875*^9, {
   3.448379925828125*^9, 3.448379937140625*^9}, 3.448398809359375*^9, 
   3.448398867796875*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Others", "Subsubtitle",
 CellChangeTimes->{{3.447186576652625*^9, 3.44718659091825*^9}, {
  3.447187881965125*^9, 3.447187883183875*^9}, {3.44751414086124*^9, 
  3.447514156905958*^9}, {3.4481979829543753`*^9, 3.4481979839856253`*^9}, {
  3.4481980255793753`*^9, 3.4481980385481253`*^9}, {3.4481991368762503`*^9, 
  3.4481991725950003`*^9}, {3.4481992975168753`*^9, 3.4481992989543753`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vvv", "=", 
  RowBox[{"v", "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox[
         RowBox[{"v", "-", "vin"}], "r1"], "+", 
        FractionBox["v", "r2"], "+", 
        FractionBox[
         RowBox[{"v", "-", "V15"}], "r3"], "+", 
        FractionBox["v", 
         RowBox[{"r4", "+", 
          FractionBox["1", 
           RowBox[{"s", " ", "C"}]]}]]}], "\[Equal]", "0"}], ",", "v"}], 
     "]"}], "\[LeftDoubleBracket]", "1", 
    "\[RightDoubleBracket]"}]}]}]], "Input",
 CellChangeTimes->{{3.4475156569600687`*^9, 3.4475157442178745`*^9}, {
  3.447515801087779*^9, 3.447515808899579*^9}, {3.447515854707974*^9, 
  3.447515855411036*^9}, {3.447515903562971*^9, 3.4475159105310965`*^9}, {
  3.447516046018956*^9, 3.447516074282048*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"r2", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"C", " ", "r4", " ", "s"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"r1", " ", "V15"}], "+", 
     RowBox[{"r3", " ", "vin"}]}], ")"}]}], 
  RowBox[{
   RowBox[{"r1", " ", "r2"}], "+", 
   RowBox[{"r1", " ", "r3"}], "+", 
   RowBox[{"r2", " ", "r3"}], "+", 
   RowBox[{"C", " ", "r1", " ", "r2", " ", "r3", " ", "s"}], "+", 
   RowBox[{"C", " ", "r1", " ", "r2", " ", "r4", " ", "s"}], "+", 
   RowBox[{"C", " ", "r1", " ", "r3", " ", "r4", " ", "s"}], "+", 
   RowBox[{"C", " ", "r2", " ", "r3", " ", "r4", " ", "s"}]}]]], "Output",
 CellChangeTimes->{{3.44751572753187*^9, 3.447515744592841*^9}, {
   3.4475158017595935`*^9, 3.4475158093057923`*^9}, 3.4475158567702894`*^9, 
   3.4475159110935464`*^9, 3.447516074953863*^9, 3.4480255250264997`*^9, 
   3.4481969061106253`*^9, 3.4483096870325003`*^9, 3.4483098000481253`*^9, 
   3.4483098638918753`*^9, 3.4483099243918753`*^9, 3.4483102373293753`*^9, 
   3.4483102714231253`*^9, 3.4483108286418753`*^9, 3.4483121601887503`*^9, 
   3.4483126407356253`*^9, 3.44837533153125*^9, 3.448375448953125*^9, {
   3.448379925859375*^9, 3.448379937171875*^9}, 3.448398809421875*^9, 
   3.448398867828125*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vvv", "/.", 
    RowBox[{"vin", "\[Rule]", "0"}]}], "/.", 
   RowBox[{"s", "\[Rule]", "0"}]}], "//", "PowerExpand"}]], "Input",
 CellChangeTimes->{{3.4475158586763687`*^9, 3.4475158877675114`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"r1", " ", "r2", " ", "V15"}], 
  RowBox[{
   RowBox[{"r1", " ", "r2"}], "+", 
   RowBox[{"r1", " ", "r3"}], "+", 
   RowBox[{"r2", " ", "r3"}]}]]], "Output",
 CellChangeTimes->{{3.447515866988124*^9, 3.447515913327721*^9}, 
   3.447516077422392*^9, 3.4480255250889997`*^9, 3.4481969062200003`*^9, 
   3.4483096870793753`*^9, 3.4483098000793753`*^9, 3.4483098639231253`*^9, 
   3.4483099244387503`*^9, 3.4483102373762503`*^9, 3.4483102714387503`*^9, 
   3.4483108286731253`*^9, 3.4483121602356253`*^9, 3.4483126407825003`*^9, 
   3.448375331578125*^9, 3.448375448984375*^9, {3.448379925875*^9, 
   3.4483799371875*^9}, 3.448398809453125*^9, 3.448398867859375*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vdc", "=", 
  RowBox[{
   RowBox[{"vvv", "/.", 
    RowBox[{"s", "\[Rule]", "0"}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.4475159300293493`*^9, 3.44751598375891*^9}, {
  3.447516143432102*^9, 3.4475161646489506`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"r2", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"r1", " ", "V15"}], "+", 
     RowBox[{"r3", " ", "vin"}]}], ")"}]}], 
  RowBox[{
   RowBox[{"r2", " ", "r3"}], "+", 
   RowBox[{"r1", " ", 
    RowBox[{"(", 
     RowBox[{"r2", "+", "r3"}], ")"}]}]}]]], "Output",
 CellChangeTimes->{{3.4475159312792377`*^9, 3.4475159456529493`*^9}, {
   3.4475159769938912`*^9, 3.4475159840245113`*^9}, 3.447516081156432*^9, {
   3.447516143791445*^9, 3.447516165258271*^9}, 3.4475163385864897`*^9, 
   3.4480255251827497`*^9, 3.4481969064543753`*^9, 3.4483096871418753`*^9, 
   3.4483098000950003`*^9, 3.4483098639700003`*^9, 3.4483099244700003`*^9, 
   3.4483102374231253`*^9, 3.4483102714700003`*^9, 3.4483108287043753`*^9, 
   3.4483121604387503`*^9, 3.4483126408293753`*^9, 3.448375331625*^9, 
   3.448375449015625*^9, {3.448379925890625*^9, 3.44837993721875*^9}, 
   3.4483988095*^9, 3.448398867890625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"prm", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"r1", "\[Rule]", "1*^3"}], ",", 
    RowBox[{"V15", "\[Rule]", "10."}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"vdc", "\[Equal]", "11"}], "/.", 
     RowBox[{"vin", "\[Rule]", "0"}]}], ",", 
    RowBox[{
     RowBox[{"vdc", "\[Equal]", "10.9"}], "/.", 
     RowBox[{"vin", "\[Rule]", 
      RowBox[{"-", "10"}]}]}]}], "}"}], "/.", 
  "prm"}], "\[IndentingNewLine]", 
 RowBox[{"Solve", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{"r2", ",", "r3"}], "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"vdc", "/.", 
    RowBox[{"%", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], "/.",
    
   RowBox[{"vin", "\[Rule]", 
    RowBox[{"+", "10"}]}]}], "/.", "prm"}]}], "Input",
 CellChangeTimes->{{3.4475161676643057`*^9, 3.4475162067858*^9}, {
  3.4475163183226805`*^9, 3.4475165110563107`*^9}, {3.447516541960187*^9, 
  3.4475166395776896`*^9}, {3.4475166695910096`*^9, 3.447516701994771*^9}, {
  3.447516732508052*^9, 3.4475167601934257`*^9}, {3.447516870059987*^9, 
  3.447516889839718*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"r1", "\[Rule]", "1000"}], ",", 
   RowBox[{"V15", "\[Rule]", "10.`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.4475163307434425`*^9, 3.4475163396020236`*^9}, {
   3.447516388519515*^9, 3.4475165114625297`*^9}, {3.4475165597400713`*^9, 
   3.447516639765175*^9}, {3.447516673903178*^9, 3.447516702510356*^9}, {
   3.4475167329923897`*^9, 3.4475167605059013`*^9}, {3.447516871684862*^9, 
   3.447516890355304*^9}, 3.4480255252921247`*^9, 3.4481969065168753`*^9, 
   3.4483096871731253`*^9, 3.4483098001262503`*^9, 3.4483098640012503`*^9, 
   3.4483099245168753`*^9, 3.4483102374543753`*^9, 3.4483102715012503`*^9, 
   3.4483108287356253`*^9, 3.4483121604856253`*^9, 3.4483126408606253`*^9, 
   3.4483753316875*^9, 3.448375449046875*^9, {3.44837992590625*^9, 
   3.44837993725*^9}, 3.448398809546875*^9, 3.448398867921875*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"10000.`", " ", "r2"}], 
     RowBox[{
      RowBox[{"r2", " ", "r3"}], "+", 
      RowBox[{"1000", " ", 
       RowBox[{"(", 
        RowBox[{"r2", "+", "r3"}], ")"}]}]}]], "\[Equal]", "11"}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"r2", " ", 
      RowBox[{"(", 
       RowBox[{"10000.`", "\[InvisibleSpace]", "-", 
        RowBox[{"10", " ", "r3"}]}], ")"}]}], 
     RowBox[{
      RowBox[{"r2", " ", "r3"}], "+", 
      RowBox[{"1000", " ", 
       RowBox[{"(", 
        RowBox[{"r2", "+", "r3"}], ")"}]}]}]], "\[Equal]", "10.9`"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.4475163307434425`*^9, 3.4475163396020236`*^9}, {
   3.447516388519515*^9, 3.4475165114625297`*^9}, {3.4475165597400713`*^9, 
   3.447516639765175*^9}, {3.447516673903178*^9, 3.447516702510356*^9}, {
   3.4475167329923897`*^9, 3.4475167605059013`*^9}, {3.447516871684862*^9, 
   3.447516890355304*^9}, 3.4480255252921247`*^9, 3.4481969065168753`*^9, 
   3.4483096871731253`*^9, 3.4483098001262503`*^9, 3.4483098640012503`*^9, 
   3.4483099245168753`*^9, 3.4483102374543753`*^9, 3.4483102715012503`*^9, 
   3.4483108287356253`*^9, 3.4483121604856253`*^9, 3.4483126408606253`*^9, 
   3.4483753316875*^9, 3.448375449046875*^9, {3.44837992590625*^9, 
   3.44837993725*^9}, 3.448398809546875*^9, 3.448398867921875*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"r2", "\[Rule]", 
     RowBox[{"-", "90.9090909090909`"}]}], ",", 
    RowBox[{"r3", "\[Rule]", "9.090909090909092`"}]}], "}"}], "}"}]], "Output",\

 CellChangeTimes->{{3.4475163307434425`*^9, 3.4475163396020236`*^9}, {
   3.447516388519515*^9, 3.4475165114625297`*^9}, {3.4475165597400713`*^9, 
   3.447516639765175*^9}, {3.447516673903178*^9, 3.447516702510356*^9}, {
   3.4475167329923897`*^9, 3.4475167605059013`*^9}, {3.447516871684862*^9, 
   3.447516890355304*^9}, 3.4480255252921247`*^9, 3.4481969065168753`*^9, 
   3.4483096871731253`*^9, 3.4483098001262503`*^9, 3.4483098640012503`*^9, 
   3.4483099245168753`*^9, 3.4483102374543753`*^9, 3.4483102715012503`*^9, 
   3.4483108287356253`*^9, 3.4483121604856253`*^9, 3.4483126408606253`*^9, 
   3.4483753316875*^9, 3.448375449046875*^9, {3.44837992590625*^9, 
   3.44837993725*^9}, 3.448398809546875*^9, 3.448398867921875*^9}],

Cell[BoxData["11.100000000000001`"], "Output",
 CellChangeTimes->{{3.4475163307434425`*^9, 3.4475163396020236`*^9}, {
   3.447516388519515*^9, 3.4475165114625297`*^9}, {3.4475165597400713`*^9, 
   3.447516639765175*^9}, {3.447516673903178*^9, 3.447516702510356*^9}, {
   3.4475167329923897`*^9, 3.4475167605059013`*^9}, {3.447516871684862*^9, 
   3.447516890355304*^9}, 3.4480255252921247`*^9, 3.4481969065168753`*^9, 
   3.4483096871731253`*^9, 3.4483098001262503`*^9, 3.4483098640012503`*^9, 
   3.4483099245168753`*^9, 3.4483102374543753`*^9, 3.4483102715012503`*^9, 
   3.4483108287356253`*^9, 3.4483121604856253`*^9, 3.4483126408606253`*^9, 
   3.4483753316875*^9, 3.448375449046875*^9, {3.44837992590625*^9, 
   3.44837993725*^9}, 3.448398809546875*^9, 3.4483988679375*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vvv", "=", 
  RowBox[{"v", "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"v", "-", "vin"}], "r1"], "+", 
          FractionBox[
           RowBox[{"v", "-", "v2"}], "r2"]}], "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"v2", "-", "v"}], "r2"], "+", 
          RowBox[{"v2", " ", "s", " ", "C"}], "+", 
          FractionBox[
           RowBox[{"v2", "-", "vref"}], "r3"]}], "\[Equal]", "0"}]}], "}"}], 
      ",", "v", ",", "v2"}], "]"}], "\[LeftDoubleBracket]", "1", 
    "\[RightDoubleBracket]"}]}]}]], "Input",
 CellChangeTimes->{{3.447517861223312*^9, 3.447517935374816*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", "r2"}], " ", "vin"}], "-", 
    RowBox[{"r3", " ", "vin"}], "-", 
    RowBox[{"C", " ", "r2", " ", "r3", " ", "s", " ", "vin"}], "-", 
    RowBox[{"r1", " ", "vref"}]}], 
   RowBox[{"r1", "+", "r2", "+", "r3", "+", 
    RowBox[{"C", " ", "r1", " ", "r3", " ", "s"}], "+", 
    RowBox[{"C", " ", "r2", " ", "r3", " ", "s"}]}]]}]], "Output",
 CellChangeTimes->{{3.447517929875168*^9, 3.447517935796664*^9}, 
   3.4480255254952497`*^9, 3.4481969067043753`*^9, 3.4483096872668753`*^9, 
   3.4483098001731253`*^9, 3.4483098641731253`*^9, 3.4483099245793753`*^9, 
   3.4483102375637503`*^9, 3.4483102715325003`*^9, 3.4483108288606253`*^9, 
   3.4483121606262503`*^9, 3.4483126409231253`*^9, 3.448375331875*^9, 
   3.44837544909375*^9, {3.4483799259375*^9, 3.44837993728125*^9}, 
   3.44839880959375*^9, 3.44839886796875*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vvv", "/.", 
    RowBox[{"vin", "\[Rule]", "0"}]}], "/.", 
   RowBox[{"s", "\[Rule]", "0"}]}], "//", "PowerExpand"}]], "Input",
 CellChangeTimes->{{3.4475158586763687`*^9, 3.4475158877675114`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"r1", " ", "vref"}], 
  RowBox[{"r1", "+", "r2", "+", "r3"}]]], "Output",
 CellChangeTimes->{{3.447515866988124*^9, 3.447515913327721*^9}, 
   3.447516077422392*^9, 3.447517952764328*^9, 3.4480255255577497`*^9, 
   3.4481969067668753`*^9, 3.4483096873137503`*^9, 3.4483098002043753`*^9, 
   3.4483098642356253`*^9, 3.4483099246262503`*^9, 3.4483102376106253`*^9, 
   3.4483102715637503`*^9, 3.4483108288762503`*^9, 3.4483121606731253`*^9, 
   3.4483126409700003`*^9, 3.4483753323125*^9, 3.448375449125*^9, {
   3.448379925953125*^9, 3.4483799373125*^9}, 3.448398809625*^9, 
   3.448398867984375*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vdc", "=", 
  RowBox[{
   RowBox[{"vvv", "/.", 
    RowBox[{"s", "\[Rule]", "0"}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.4475159300293493`*^9, 3.44751598375891*^9}, {
  3.447516143432102*^9, 3.4475161646489506`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"r2", " ", "vin"}], "+", 
   RowBox[{"r3", " ", "vin"}], "+", 
   RowBox[{"r1", " ", "vref"}]}], 
  RowBox[{"r1", "+", "r2", "+", "r3"}]]], "Output",
 CellChangeTimes->{{3.4475159312792377`*^9, 3.4475159456529493`*^9}, {
   3.4475159769938912`*^9, 3.4475159840245113`*^9}, 3.447516081156432*^9, {
   3.447516143791445*^9, 3.447516165258271*^9}, 3.4475163385864897`*^9, 
   3.447517962685568*^9, 3.4480255256046247`*^9, 3.4481969068137503`*^9, 
   3.4483096873450003`*^9, 3.4483098002356253`*^9, 3.4483098642825003`*^9, 
   3.4483099246731253`*^9, 3.4483102376418753`*^9, 3.4483102715950003`*^9, 
   3.4483108289075003`*^9, 3.4483121607043753`*^9, 3.4483126410012503`*^9, 
   3.448375332421875*^9, 3.44837544915625*^9, {3.44837992596875*^9, 
   3.448379937328125*^9}, 3.448398809671875*^9, 3.448398868015625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"prm", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"r1", "\[Rule]", "1*^3"}], ",", 
    RowBox[{"r3", "\[Rule]", 
     RowBox[{"6.27273", "r2"}]}], ",", 
    RowBox[{"C", "\[Rule]", "80*^-6"}], ",", 
    RowBox[{"vref", "\[Rule]", "15."}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"vdc", "\[Equal]", "10"}], "/.", 
    RowBox[{"vin", "\[Rule]", "0"}]}], "}"}], "/.", 
  "prm"}], "\[IndentingNewLine]", 
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"%", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
   RowBox[{"{", "r2", "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"vdc", "/.", 
    RowBox[{"vin", "\[Rule]", 
     RowBox[{"-", "10"}]}]}], "/.", "prm"}], "/.", 
  RowBox[{
  "%", "\[LeftDoubleBracket]", "1", 
   "\[RightDoubleBracket]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"vdc", "/.", 
    RowBox[{"vin", "\[Rule]", 
     RowBox[{"+", "10"}]}]}], "/.", "prm"}], "/.", 
  RowBox[{
  "%%", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}]}], "Input",
 CellChangeTimes->{{3.4475161676643057`*^9, 3.4475162067858*^9}, {
   3.4475163183226805`*^9, 3.4475165110563107`*^9}, {3.447516541960187*^9, 
   3.4475166395776896`*^9}, {3.4475166695910096`*^9, 3.447516701994771*^9}, {
   3.447516732508052*^9, 3.4475167601934257`*^9}, {3.447516870059987*^9, 
   3.447516889839718*^9}, {3.447517989902576*^9, 3.447518082131048*^9}, {
   3.4475181236596403`*^9, 3.447518178687368*^9}, {3.447518263291328*^9, 
   3.447518344770488*^9}, {3.447518402407424*^9, 3.447518447263928*^9}, {
   3.44751848769884*^9, 3.4475185292435756`*^9}, {3.447518635363142*^9, 
   3.447518641034726*^9}, {3.447518678329692*^9, 3.447518864960761*^9}, 
   3.4475189119427304`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"r1", "\[Rule]", "1000"}], ",", 
   RowBox[{"r3", "\[Rule]", 
    RowBox[{"6.27273`", " ", "r2"}]}], ",", 
   RowBox[{"C", "\[Rule]", 
    FractionBox["1", "12500"]}], ",", 
   RowBox[{"vref", "\[Rule]", "15.`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.447518435530304*^9, 3.447518447451416*^9}, {
   3.447518488261304*^9, 3.4475185298685436`*^9}, 3.447518641519077*^9, {
   3.447518678751545*^9, 3.4475188651794996`*^9}, 3.4475189124583287`*^9, 
   3.4480255256514997`*^9, 3.4481969068450003`*^9, 3.4483096873918753`*^9, 
   3.4483098002668753`*^9, 3.4483098643293753`*^9, 3.4483099247200003`*^9, 
   3.4483102376887503`*^9, 3.4483102716262503`*^9, 3.4483108289231253`*^9, 
   3.4483121607512503`*^9, 3.4483126410481253`*^9, 3.44837533278125*^9, 
   3.448375449203125*^9, {3.448379925984375*^9, 3.448379937359375*^9}, 
   3.44839880971875*^9, 3.448398868046875*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["15000.`", 
    RowBox[{"1000", "+", 
     RowBox[{"7.27273`", " ", "r2"}]}]], "\[Equal]", "10"}], "}"}]], "Output",\

 CellChangeTimes->{{3.447518435530304*^9, 3.447518447451416*^9}, {
   3.447518488261304*^9, 3.4475185298685436`*^9}, 3.447518641519077*^9, {
   3.447518678751545*^9, 3.4475188651794996`*^9}, 3.4475189124583287`*^9, 
   3.4480255256514997`*^9, 3.4481969068450003`*^9, 3.4483096873918753`*^9, 
   3.4483098002668753`*^9, 3.4483098643293753`*^9, 3.4483099247200003`*^9, 
   3.4483102376887503`*^9, 3.4483102716262503`*^9, 3.4483108289231253`*^9, 
   3.4483121607512503`*^9, 3.4483126410481253`*^9, 3.44837533278125*^9, 
   3.448375449203125*^9, {3.448379925984375*^9, 3.448379937359375*^9}, 
   3.44839880971875*^9, 3.448398868046875*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"r2", "\[Rule]", "68.74997421875966`"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.447518435530304*^9, 3.447518447451416*^9}, {
   3.447518488261304*^9, 3.4475185298685436`*^9}, 3.447518641519077*^9, {
   3.447518678751545*^9, 3.4475188651794996`*^9}, 3.4475189124583287`*^9, 
   3.4480255256514997`*^9, 3.4481969068450003`*^9, 3.4483096873918753`*^9, 
   3.4483098002668753`*^9, 3.4483098643293753`*^9, 3.4483099247200003`*^9, 
   3.4483102376887503`*^9, 3.4483102716262503`*^9, 3.4483108289231253`*^9, 
   3.4483121607512503`*^9, 3.4483126410481253`*^9, 3.44837533278125*^9, 
   3.448375449203125*^9, {3.448379925984375*^9, 3.448379937359375*^9}, 
   3.44839880971875*^9, 3.448398868046875*^9}],

Cell[BoxData["6.666666666666666`"], "Output",
 CellChangeTimes->{{3.447518435530304*^9, 3.447518447451416*^9}, {
   3.447518488261304*^9, 3.4475185298685436`*^9}, 3.447518641519077*^9, {
   3.447518678751545*^9, 3.4475188651794996`*^9}, 3.4475189124583287`*^9, 
   3.4480255256514997`*^9, 3.4481969068450003`*^9, 3.4483096873918753`*^9, 
   3.4483098002668753`*^9, 3.4483098643293753`*^9, 3.4483099247200003`*^9, 
   3.4483102376887503`*^9, 3.4483102716262503`*^9, 3.4483108289231253`*^9, 
   3.4483121607512503`*^9, 3.4483126410481253`*^9, 3.44837533278125*^9, 
   3.448375449203125*^9, {3.448379925984375*^9, 3.448379937359375*^9}, 
   3.44839880971875*^9, 3.4483988680625*^9}],

Cell[BoxData["13.333333333333332`"], "Output",
 CellChangeTimes->{{3.447518435530304*^9, 3.447518447451416*^9}, {
   3.447518488261304*^9, 3.4475185298685436`*^9}, 3.447518641519077*^9, {
   3.447518678751545*^9, 3.4475188651794996`*^9}, 3.4475189124583287`*^9, 
   3.4480255256514997`*^9, 3.4481969068450003`*^9, 3.4483096873918753`*^9, 
   3.4483098002668753`*^9, 3.4483098643293753`*^9, 3.4483099247200003`*^9, 
   3.4483102376887503`*^9, 3.4483102716262503`*^9, 3.4483108289231253`*^9, 
   3.4483121607512503`*^9, 3.4483126410481253`*^9, 3.44837533278125*^9, 
   3.448375449203125*^9, {3.448379925984375*^9, 3.448379937359375*^9}, 
   3.44839880971875*^9, 3.4483988680625*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"tr", "[", "f_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"r2", "+", 
      FractionBox["1", 
       RowBox[{"s", " ", "C"}]]}], 
     RowBox[{"r1", "+", "r2", "+", 
      FractionBox["1", 
       RowBox[{"s", " ", "C"}]]}]], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", "f"}]}]}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"r1", "\[Rule]", 
      RowBox[{"25", "*", "50"}]}], ",", 
     RowBox[{"r2", "\[Rule]", "50"}], ",", 
     RowBox[{"C", "\[Rule]", "20*^-6"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.447524608664061*^9, 3.447524678365693*^9}, {
  3.447524709740091*^9, 3.447524742458213*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BodePlot", "[", 
  RowBox[{
   RowBox[{"tr", "[", "f", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", "1", ",", "1000"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.44752468477182*^9, 3.447524704974557*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVzns0lHkcx/ExO6Iwo/DIji70cEoX2pUk+T4pdxGtNtdmdEy5lWizZNXI
nsqtJOyKUq2sXVF0cxm/x7U6tjaWIa2QOBNyG8ZlBvvbPz7nfV7/fQwCT3kG
MRkMhhve/72fm3Mt2irYZk3luWNfrEXIxCKo5DjpAPz1ltsDHERoWvvsrh3k
99Byr7W41UOEfBIXF7nkcTAMLSlrEoiQRnUdn0NGQ3bdSf3310RosIPUWk5e
gmVW7xKfDojQPwPtw8pkNpyZsyigrtegV2HbjrDIQthWdj9wWIZQc6lv8KY1
z+FB9Tihm1OL3kX8YVn3uRZSBsa3nLatRx9PH3O/VPgC6p9ZlSSoNqKSydxD
PX2voas482Xchhfow/Ffbkk6W+DrO2mbZU6vkH2W4YrNS20g1K5iL4ibUcXs
CqggOuGgJGaVIOsNcr2SL9Ce6wLd1jvJVx+9RbXeMlaF3gcYtmnJ0PNpRSbF
CufMhF5Y1/2+kq3WhmLtts5Kx/sgSNpRVN7ZjqoWRbzo+H7QbFRLKZnvQOru
Bbb8iU+wqZ7l3WPUhdzQSM+pi4Pge1fHvuDJvyjTqZ9PsiWQ9VyiHXKmB42E
mPlD/GcI47o9PrC2D5kXd2ud1xiGp57LbLtrP6KUxL59RgkjsFHKP68e+gm1
x9mZjuuMQoy6qUj16CDacPXIEu/uGPi39XVGnpGgvfp8Uj9pHEpH+tp+SxtC
EkaTcY7nBBBcw05H5S9Id7s4qFljEvaqnHbVEI4hp9E92e6NkyA3jWP/wJlA
UVVexoIUKaQ76D32yJpERm2rJ03tp+CQtcXZ3Wun0FtFMjeFMw3CliYfYnAa
/VR2eOfu9mmYCLS7nNQ0g8rK/7qalyoDF8OpWx4Fc6i3YdLuutcMXMkIB+pv
OcoyaLC00pyFsZm2a2qyBeSu9mXNjhezoMUNC96nx6AZyk28utQ5cPvEI1MD
lehdzs69TId5OFBUsLu8kEmH3I4XtXPksD5A5r9Sn0VvoAI6fJvl8Dp60LY8
SZnuCc/sN7+ogIpMtq8aS4W+8WfcgXznBbByWNX94yNVusWcM1XDWgTOHnGN
sdcKetkbj9lTbxbB8bZrdYSZOm0zNTwadWMJPvo0d+TpsumlstXpmcYMar/4
weiWcQ79PirDuzKJQakcOjkzr7SSPtd1jLaUMKiDbpHP1n61is5V4eX37lOi
Lpn4cr1UtOhKa/NSj0IlqlaaoBlrok3n6gb46bOYVHvoZu5GWx06dv6o5cMT
TGqJlMofxhB0uM53NtXY6s43q8TYPDPH/S+xj8r55xTY9gKzg73YJkwXuUMs
Qa9sZZzQDGZSMTeTFR+wfy+6kx2BbSNuYmnEEbT4SL/MLIRJMS3ILcHxBP0q
qkNhjU2k5Y2lYVenNTOdsIfCdpQ/xr7bUM7mY2vX0FaM8/iPWaJxOvbtIjuX
bGyWqtHhCeyGeNXIxgsEPWOo57eA3bU1ZOcw9tAejcDloUxqgDek0BQS9Nuo
6XAD7G897S/7Yd/safzZA7vCLyxfip02X5Hsj11sXCfQSyDoCzol6cHY26Is
tgK2wCUrT4jtlBFbmYTtLUi6l4otFDgLH2K7CuOLfsXOqbJ0FGNDbmRpAXbY
dTuOAvubZ4Inj7DrhyLEBhcJ+j81WlzE
          "]]}}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVx384E3gcwPE1jM2azY+Rk/yqEc2M5pS6T7lEXJ6K8FyRzo/rxDJKpuuw
niijzpLHnHTP1XBkyI/S3fm0eh6UHyW6iq3SDy2Vo18npfveH+/n/bwcd4o3
J1ApFMpG0v//MG2gaUqmgjzbYs5RxsVdKwVUlxQqXJNXK87lc/GObNvak6lU
OMRzVfrJudhu2aqRplFhtLtqZnMpFzNEiVcCMqkguriKUljNxVdZ3VeH86iQ
7zloy+7l4hilqGumnAqSA+qZFCtr7GFx+9Z0U8FWlPc+vdYaTwgpxhUeBvDi
vtW3Lv/YoPPHr+5/c9QA+hclWnzg2aK3vE6w9KkBODkoFnXEfoHgMtk4EGwI
L9eP4boLdsjZWTDQrzKE5piJKcnnhairnrErMzUCub1/VWfSIvRoOfmoINUI
zj9NCdiT5ICrE48EDV0zAt909VV3jiOGOoSPPuPTYLurnzLruiPa52SwIuU0
cP00zovOdkKJCi++GqdB2vPSg2I3Z9QMPVaEhRjDsTfSPuNnzni7JobJqDGG
3o+Qs6XCBZ8eajxfxDSBSZo6fEHsYtzP4w+tEJvAYDJXUuKwBPvF8xRrrptA
ZdYBnsHtJeiA9TkcTzpUHpxOuFzBQ1HbOeZKOR3U6fWV3AhXDGo53LVsig5I
jRsrt3fDkf2Fs8HhDFCdjeDMe+KGwkdP+jobGbBAdO3N/lNL8XCEzcCcpSnc
0XeO3k5yx1Mpp1PLJKZAOycxn3P2QN/Q8PzoflPIDQiuyBr1wF7hg/7HXkz4
aWi7RnZmGS7uvNzSU8yE7wO1utkYPkq3ZPdkvmYCrdhj50VXT9zUsCMybOt8
2Ct7fjPolSe+aKiQ5TTPh+nuR2FzmwUoa2/QSbksyMxOPeDXJkBdgvWd/nQW
JGvsRsTmXthxr25D6AALovkfzeJ2e6Ei0uZFidAM/rhRti6hzwsF0nvu3sfM
YNBm/VgoT4g9ZzKUv7w2A6eRuWyDAiEqVjTfUruy4ZIXVX/0oRCpNOSqtrJB
X7NWIPvSG8XDflM5BWy4suCWtbbUG//K1ClN2tlQGBBwfHbCG03tJ0cy9GxI
WaqtXBjkg+XVpXff2nLAX98X8vWvPkg3TFI5B3NAbxVYuOy1D2bGn2GIsjmw
2N1yIn/DcuwqY65+W8uBS+47Ik4pl2NUA4Pf8zcHvpvk7K4fX47j3RmtuXRz
UBZXMuR+IoxqozPHfc0hb4W21f+QCLuqGR8EP5iD7waW2P+WCKHV8JOIWGor
xXXEHZq5z/7E0XY6ThhxvXbaKJi4raW4JY64xGKEE0fcKyqZOUwc81Od28/E
+n1OeTeJ320NjZ4iplckFSUOiXBPfOC298RFR+5qxcT6NIj9RLypJoCfRTwq
90mgJ5tD8j7KQCGxRmOX5kjcscWO3URcxH9ZsIk4hK49PktM8x8vjCRufHfz
geGwCHOCHxZvJ6616BSwiCXxwyd2ETuN5t5wII5S/nk6l9hKVWsWSDxY3f5b
PrGOtSM2jDiktUlVRPxAxVJHEa++cba+nDglPnxjMvEFbZW6injsyERlBrHX
RHnzWeJEnfTlj8S//6torSOejKOuyid2oRVfaCLea5knP078H6HTP70=
          "]]}}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV0Hs01HkYBvBxyYZ1acx9dETOVpxmSc2Y+U31IrXbicp0ukxJtS5LJpWK
rAaFJK1LUVZrc9mdSqtRbOLEKxXaRuqgjY3IGF2slCaF7Hf+eM9zPuc5zz+v
466ogBBjGo3mT86QM0v/ravYTYeBqpV5WR1ChOZ3PRGRdKhxYCy72inEmDcz
p+cq6OA1b6hZ80SIg4uXLM/bQwfFg6zjFl1CvHv3VH3cPjqUagIvHu0R4lHd
MvSJoQOnrDJaoRPipEtRQ8dROsQXf7RZ+EmIIxUhdz7l00HbPmeTzF6E7Y3y
nd88oINlQWbtUKgICy7GaaY/0yElO+j84csiLNnrph+ebwcyE2lG5SsRXpIG
/IVyO7Cba/WdrcATs7sLfeGEHTSqPd5fi/DEGOWmyNJaO1j/U0Hqf5c8sdD0
j7Wzh+3gYHHQskNaT1QFOhj78BlQRgms1TwxlteYrvHzY8BU/vWy3vViPPuK
EWIaz4CaqVsfjI+JsWGqRtJ2iQG7u/JPjqnF+JKhUSV2MyBQNh0uey7G91/M
B56ZM2FcwssQW0hw4s21Gw5SJswS2Re4LpHgirrRVYcUTGBXmow+3ybBqF1b
VYcLmOBZXW5zL0GC5yzcC3dqmGAWv+i4vESCJSnuwfoJJqxpfUxPvC3BK6aF
DVECFoTYJtKY/RLUh17ongpiwfbIBd4TXyTodF5zx/NnFqQcLHs0l0Phmo5Q
383IgqRkl3vp7hRu7nPJdR5hwUbH5i25qygsbUsumjGbDX1u+fHXt1I40rja
929/NthaWknfRVFon05VLz3ChtOBjyL2JlG4asO522eusqHqtXObPofCa0Yn
T9D62BD7QmD2sJjC6aSLDlwbDugl80Oi1RSuNlvkx/LiQF0bLZxVR2FM4OD3
GMWB8XLeFU0LhdqzbiYJv3LA6sykf1g7hes7B2VODzngVd2tm+ih8DddU/T+
KQ4I8hJDrYYofD3JcFV9y4XLLk1Z9FEKudqMirTtXBgbu5l6f5zCNPUvY8oM
LqgC5Nn10xR+SGA83FLHBVn8hMVlMymucLoZ2/eGCxaNs1Q5X0sxu7nlpp8D
D4qWpDYq6FJ0CNh7o3UdD+Rh7cFlbClmlnslTyp5YGfiJHK2l+KUdcKQdQUP
1vVmPsiZI0U/bx2/tZcH73/43UjuLMWezVrLYis+hAW3zqyfJ0VF9NrT8uV8
MNafzLR3Jf2OgZf1Cj5sWPo29vNCsg/QPjG/wIcSU7pHm5sU7wX1dtkQj5jc
SjEYFE+fMYmHbcP+MXhxmuaFIzFtQ/WRR8S8uqoRMXGXcm3zY+LBBalfRRDf
CF8X2EGsNJonuk88Q3U+tYt43NpR0kacunPBU4P32fOXdhJbulS5dhMHi2x8
+ok9tC1tBq9WfPT/TLzSdIj3jJj1tCnUpYgPTTp9eS9x1mBDuBvx8LEDRs+J
zcdqI4XEvoJRmcGT1ur93sTZf+rGDe5fcU4pJx7b2OLdT7wtICdpB/Hb4OW5
BncEZSSHEnskVeoMbo5LTN9PnD9QkPGC2Dst7lQsMbpa9xpcm3sgS0ksSUpw
HzD8p2TP6WRic+3IMYPL1T/mpRMLNgV1Gvw/RblHMg==
          "]]}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0., -5.628058767930898},
      DisplayFunction->Identity,
      Frame->True,
      FrameLabel->{
        FormBox["\"Hz\"", TraditionalForm], 
        FormBox["\"dB\"", TraditionalForm]},
      FrameTicks->{{Automatic, Automatic}, {{{0., 
           FormBox[
            TagBox[
             InterpretationBox["\"1.0\"", 1., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {2.302585092994046, 
           FormBox[
            TagBox[
             InterpretationBox["\"10.0\"", 10., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {1.6094379124341003`, 
           FormBox[
            TagBox[
             InterpretationBox["\"5.0\"", 5., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {3.912023005428146, 
           FormBox[
            TagBox[
             InterpretationBox["\"50.0\"", 50., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"2.0\"", 2., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {2.995732273553991, 
           FormBox[
            TagBox[
             InterpretationBox["\"20.0\"", 20., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {1.0986122886681098`, 
           FormBox[
            TagBox[
             InterpretationBox["\"3.0\"", 3., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {3.4011973816621555`, 
           FormBox[
            TagBox[
             InterpretationBox["\"30.0\"", 30., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {0.4054651081081644, 
           FormBox[
            TagBox[
             InterpretationBox["\"1.5\"", 1.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {2.70805020110221, 
           FormBox[
            TagBox[
             InterpretationBox["\"15.0\"", 15., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {1.9459101490553132`, 
           FormBox[
            TagBox[
             InterpretationBox["\"7.0\"", 7., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {4.248495242049359, 
           FormBox[
            TagBox[
             InterpretationBox["\"70.0\"", 70., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {0.09531017980432493, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.1823215567939548, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.26236426446749106`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.336472236621213, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.47000362924573563`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.5306282510621705, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.5877866649021191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6418538861723948, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {
           NCache[
            Log[4], 1.3862943611198906`], 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {
           NCache[
            Log[6], 1.791759469228055], 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.3978952727983707`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.4849066497880004`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.5649493574615367`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.6390573296152584`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.772588722239781, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.833213344056216, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.8903717578961645`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.9444389791664403`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {
           NCache[
            Log[40], 3.6888794541139363`], 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {
           NCache[
            Log[60], 4.0943445622221], 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{0., 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm]}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm]}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm]}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm]}, {0.4054651081081644, 
           FormBox["\" \"", TraditionalForm]}, {2.70805020110221, 
           FormBox["\" \"", TraditionalForm]}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm]}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm]}, {0.09531017980432493, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.1823215567939548, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.26236426446749106`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.336472236621213, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.47000362924573563`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.5306282510621705, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.5877866649021191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6418538861723948, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {
           NCache[
            Log[4], 1.3862943611198906`], 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {
           NCache[
            Log[6], 1.791759469228055], 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.3978952727983707`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.4849066497880004`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.5649493574615367`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.6390573296152584`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.772588722239781, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.833213344056216, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.8903717578961645`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.9444389791664403`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {
           NCache[
            Log[40], 3.6888794541139363`], 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {
           NCache[
            Log[60], 4.0943445622221], 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->
       NCache[{{
         0., 2.302585092994046, 1.6094379124341003`, 3.912023005428146, 
          0.6931471805599453, 2.995732273553991, 1.0986122886681098`, 
          3.4011973816621555`, 0.4054651081081644, 2.70805020110221, 
          1.9459101490553132`, 4.248495242049359, 0.09531017980432493, 
          0.1823215567939548, 0.26236426446749106`, 0.336472236621213, 
          0.47000362924573563`, 0.5306282510621705, 0.5877866649021191, 
          0.6418538861723948, 
          Log[4], 
          Log[6], 2.0794415416798357`, 2.1972245773362196`, 
          2.3978952727983707`, 2.4849066497880004`, 2.5649493574615367`, 
          2.6390573296152584`, 2.772588722239781, 2.833213344056216, 
          2.8903717578961645`, 2.9444389791664403`, 
          Log[40], 
          Log[60]}, Automatic}, {{0., 2.302585092994046, 1.6094379124341003`, 
         3.912023005428146, 0.6931471805599453, 2.995732273553991, 
         1.0986122886681098`, 3.4011973816621555`, 0.4054651081081644, 
         2.70805020110221, 1.9459101490553132`, 4.248495242049359, 
         0.09531017980432493, 0.1823215567939548, 0.26236426446749106`, 
         0.336472236621213, 0.47000362924573563`, 0.5306282510621705, 
         0.5877866649021191, 0.6418538861723948, 1.3862943611198906`, 
         1.791759469228055, 2.0794415416798357`, 2.1972245773362196`, 
         2.3978952727983707`, 2.4849066497880004`, 2.5649493574615367`, 
         2.6390573296152584`, 2.772588722239781, 2.833213344056216, 
         2.8903717578961645`, 2.9444389791664403`, 3.6888794541139363`, 
         4.0943445622221}, Automatic}],
      Method->{},
      PlotLabel->FormBox["\"Magnitude\"", TraditionalForm],
      PlotRange->{{0., 6.907755231990604}, {-28.190991781498433`, 0.}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{0., 
          FormBox[
           TagBox[
            InterpretationBox["\"1.0\"", 1., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {2.302585092994046, 
          FormBox[
           TagBox[
            InterpretationBox["\"10.0\"", 10., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {1.6094379124341003`, 
          FormBox[
           TagBox[
            InterpretationBox["\"5.0\"", 5., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {3.912023005428146, 
          FormBox[
           TagBox[
            InterpretationBox["\"50.0\"", 50., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {0.6931471805599453, 
          FormBox[
           TagBox[
            InterpretationBox["\"2.0\"", 2., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {2.995732273553991, 
          FormBox[
           TagBox[
            InterpretationBox["\"20.0\"", 20., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {1.0986122886681098`, 
          FormBox[
           TagBox[
            InterpretationBox["\"3.0\"", 3., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {3.4011973816621555`, 
          FormBox[
           TagBox[
            InterpretationBox["\"30.0\"", 30., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {0.4054651081081644, 
          FormBox[
           TagBox[
            InterpretationBox["\"1.5\"", 1.5, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {2.70805020110221, 
          FormBox[
           TagBox[
            InterpretationBox["\"15.0\"", 15., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {1.9459101490553132`, 
          FormBox[
           TagBox[
            InterpretationBox["\"7.0\"", 7., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {4.248495242049359, 
          FormBox[
           TagBox[
            InterpretationBox["\"70.0\"", 70., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {0.09531017980432493, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.1823215567939548, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.26236426446749106`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.336472236621213, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.47000362924573563`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.5306282510621705, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.5877866649021191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.6418538861723948, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {
          NCache[
           Log[4], 1.3862943611198906`], 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {
          NCache[
           Log[6], 1.791759469228055], 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.3978952727983707`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.4849066497880004`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.5649493574615367`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.6390573296152584`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.772588722239781, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.833213344056216, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.8903717578961645`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.9444389791664403`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {
          NCache[
           Log[40], 3.6888794541139363`], 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {
          NCache[
           Log[60], 4.0943445622221], 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic}], {189., -118.66252583997979`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
     GraphicsBox[{{{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVx38803kcwPHZQ13RsjucVC5jo0ibTCH2+foxsa1EJc6P28rPxWMu5B6J
a3S6k58dq6u50w/0k26ljqh3HiStOlwjlV+tuiGFrOZH3Of+eD1ejydttyQo
mkwikbbi/n+l/GRRmls8R77EJNOgiwZ2G6KrY+mbkZnP863OPTTQmux3dabv
QuOuQReFL2jw7eG5uRX0WPS34Vm9upc0oDQ0iYzoaWhv4HJ20nsavOmmGy+m
H0Esam29bpEV/PNaNbKAfhyVvCgb3OduBW0J60L06VWIU53lRK2wAmVNWPwa
i78QM1UYfKnQGnqSLro0Dd1FDMmN3ooUOrz8fk/AkapWlG6ekHI/kgHVE/Lt
/YOPEDswaZU21gb6Yk/8rnnagWZTHR9tE9uCr8zKwH7+CcpWK9UlBauhTmeA
6r5+iiI3RTDC69eA4JfyGJOpZ6i63TLuSa8d3A39qF9n3ofGXlWMOtquBbvL
s7zSrAEUlOtpkhPrAAe4DroPY4Mor0UxrLmyDm7NNQrTMtWoxCI6e4URC5YE
VHiJxl+hLv1Ddg13WbD1ztt+SfYbtDT1ZttIriOU+qtF9KUadKposMw5ZD28
FbMiUOYQcvSw9K/9xgnYl3uNf6SMoBnV/J3mz06Qd3jQm5H1FnUylKIAFRtU
B7nMMdN36IGjdEp9zxmsC0PmhWfeI3J8/WmHhg3guVJEX5k7hq6n7zJ0Or8R
NKR7NieDxtF2qtSgu8YFzBy7opWUCUTzbD1Gu+IK/u88jge0TKDajlHjqUtu
kHxrp01M3gfU120qkLZuAsaTZRNM30lkeaG1P6XLHdpnj67IM9KioXPLb9SQ
OZChCN64SaVFlRTK+0omAsW1h4Vl+R+RPalnttGGgIHmCe6xnZ+Q4H75WqKZ
ABmt2cWNqkPCDBVbFOoJAYajFs6tOvRw+JDCa9QTSAvuCZvyp9Btpn2vX6EX
uPJ4A+TN06h1Dc9PZusN4j8yG1VGM6iDyU39+ZE3WBOR3WHKGWSS9wPj3zgf
6E8sVbOzZ9ERQXoVoceFkksHt5TzPqObvU1Wqyq50ME2mrytP4c8vLwkHOQL
Cx8H6iSP59CD4uUHRtS+wJkceZdcMo+Cldbil9mbYV6xrLjUhkTsyyiirDfz
g+fJv4bW55KIkc6MY0nX/SD92R5w0ZCIsBxxSL6PP8i/EJYPeOsRinyt/dxj
f6h3Z9cEVukRnVFfyapFPJCbRYav1CcTs/MJcVNveHBg+juXq3FkQrb/6kP3
ZD4kmu7gNGDv9DHmb8EWsvx87mNbTEe1RWD7xrC2DWALLFQtmdhfdpLiqPFk
4jZH0wjY5y+cPp6EfbCz56JPCh+6QtQfWWIy0ScaShOk8qEtuXvWHdtscvVk
OHZDgZLsjy0R70pKxD7TfG2pCHuGLI0rwE5kHbYpxqYNLAxpx9ZfxAgex+Yw
e5127OfDJyvz8M/YikmDmijsYQ/K7sV7yUSA3NYuFbs9WZtIw84tdrCUYZ/q
b/kpELuImmD4FLtguu5oBPZrNTVHg33ItLo4Hjv2xDnSFHYMX1Ymxc44d0Jr
nsaH0Jjcs/nYnTM6iR22QJp54TfsHie/YTdsJN9XU4GdIsiJ4mOvvxlT+ye2
lHutLwz7P9pjVfI=
          "]]}}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k4VWsXAHBD1NnvptBVua5KNKgM1S0SrSalc7B1jXEbJBUhRYTPmCFl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          "]]}}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVx308FHYcwHGaQivp3J17oOvOQ0OJ5qE85Ovc7XLnxGll14PHs4pD6hVu
zfVwW5SUXaInsSxpS5wWatOXFGrSEy3msVxrnZdapQdkv/3xeX1eb25sikwx
zcjIKJT0/83K/mqoTqRA+q2wwe2LJAit//ZtTqIA6Loi01wkmG4wm7JTUuB+
qYVW6SRBvYdnwJFkCvxc3bEyzkGC168fuKraQgGzeE+DxFaCu58ux6B0CvRq
C3+fO1uCE86ljZ27KfC6jrUw1SDG0WpF8/ujFJBumV/wzTkxPrgmj3H8gwJ1
UYKRZIYYj59VtU99oIAu/23t/txgPJ3qNjbymRXMK7RYpjAKxgo/2SWUW8EF
G3dNpGIF5vcUCyHHCobiPKId74kwPWtNUtkVK2hY1Vke5ibCYpMzK21HrGD8
qNu53Qe/wPL1nGlBbCpMswvtdH0nxMrLJiFSKRXWjOypsIwQYuE/VIXJDir0
WtrPktcJsHHyss+dCiqcUg60auYL8Bm1vXxnDxVkCbpoox1B+Oqj+ZNecxrA
6O29lMd8HDfoajl+NDgzUyFYvZyPgoaXou1KGsQ5CONmFQdiSuza8szjNEhY
DWKXmYFYNNO9OKadBucz5lF6EwFPf+cePzZOg/B1/WFVFwPwF5PixhRXOuS4
lli2ZS3HsYSSnskoOhgH9Bflr/JH3on25qV5dChjqm+6CPwwpDNBGIl06G5b
35Nn54uRg84F9qN0CPQXPbpo44NldzSl022tgR8TMHcbdxmOXhMLb4VaQ8xP
0X4hjKVos8+3zv9ba4iyffXx7QJvFK0qajp8wRpSNjxxjHLxQp3x/hyjQWs4
nG/3XOnriVO7znKYcxjg012/82GsB4pnLJHSAxnQeIzTd0/9Oaav1wdjCgMY
yTWmULMEhwvdPlGfZID2JrVs70t3DO/SR/A6GNBWw/QdcHTHU09btqZNMkAU
OZbSkuqGzyeoLuWLmZDfHPZnjWIxModzq7M3MIHbFlTSZOmK2VXHXmflMmGz
bkMuu2MhvlFTO75qYEK0qVffe7ULCnj1GYMGJswqfjFxI8IZ81vb6qUcFkwv
MlxuYTshR5ZaezuMBZ6a/u7ssQV4sDJQM5HFgpOpDxJXvHDESQv13xbVLLgU
45LZ1e+AUv5T9u1+FlhSjg9IDPbYFzn86Y+z2dCmjzgTYWqPyq0rtfIANnQ0
PpRlMu2wL/rJs6tKNvALDpnRhTyUyoYfmpewYWuTqkW/kYs3ovq75xB7fFln
2U4Myke9NOLOPJa8htgju/0xl3jqTciImpjV8OvoMuJXeZtoTGK90/emm4l1
TbuSJF9zMct4gfdN4ibDQq8qBRffWXB97hA/MJ7ac4R4iw3bv4t4svbN3R3E
8d5zgoaI788ITw4mFivfhn4gznG6enYonov0Ry0JzqVsUMkz7WnEh/SNm9yI
eYkF28bjuGj++kqSF/Eks6t5kHjCoiqNT7w3/LqiknhIUJQlJ+7ira0QEa+T
/bArmniYc+LDIuLOqFxNAnFdvXEIlbhVtXNfGvHdJp/RgVgu8rNVBzKIf3O3
CGwhvlKw7VAWcZXfDO15Yo/TyVoNccZj3rCWuLJq45F9xAMO8d4q4v8Abwg8
ew==
          "]]}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0., -54.93249114755145},
      DisplayFunction->Identity,
      Frame->True,
      FrameLabel->{
        FormBox["\"Hz\"", TraditionalForm], 
        FormBox["\"degree\"", TraditionalForm]},
      FrameTicks->{{Automatic, Automatic}, {{{0., 
           FormBox[
            TagBox[
             InterpretationBox["\"1.0\"", 1., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {2.302585092994046, 
           FormBox[
            TagBox[
             InterpretationBox["\"10.0\"", 10., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {1.6094379124341003`, 
           FormBox[
            TagBox[
             InterpretationBox["\"5.0\"", 5., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {3.912023005428146, 
           FormBox[
            TagBox[
             InterpretationBox["\"50.0\"", 50., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"2.0\"", 2., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {2.995732273553991, 
           FormBox[
            TagBox[
             InterpretationBox["\"20.0\"", 20., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {1.0986122886681098`, 
           FormBox[
            TagBox[
             InterpretationBox["\"3.0\"", 3., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {3.4011973816621555`, 
           FormBox[
            TagBox[
             InterpretationBox["\"30.0\"", 30., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {0.4054651081081644, 
           FormBox[
            TagBox[
             InterpretationBox["\"1.5\"", 1.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {2.70805020110221, 
           FormBox[
            TagBox[
             InterpretationBox["\"15.0\"", 15., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {1.9459101490553132`, 
           FormBox[
            TagBox[
             InterpretationBox["\"7.0\"", 7., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {4.248495242049359, 
           FormBox[
            TagBox[
             InterpretationBox["\"70.0\"", 70., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
            TraditionalForm]}, {0.09531017980432493, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.1823215567939548, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.26236426446749106`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.336472236621213, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.47000362924573563`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.5306282510621705, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.5877866649021191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6418538861723948, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {
           NCache[
            Log[4], 1.3862943611198906`], 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {
           NCache[
            Log[6], 1.791759469228055], 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.3978952727983707`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.4849066497880004`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.5649493574615367`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.6390573296152584`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.772588722239781, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.833213344056216, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.8903717578961645`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.9444389791664403`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {
           NCache[
            Log[40], 3.6888794541139363`], 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {
           NCache[
            Log[60], 4.0943445622221], 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{0., 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm]}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm]}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm]}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm]}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm]}, {0.4054651081081644, 
           FormBox["\" \"", TraditionalForm]}, {2.70805020110221, 
           FormBox["\" \"", TraditionalForm]}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm]}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm]}, {0.09531017980432493, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.1823215567939548, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.26236426446749106`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.336472236621213, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.47000362924573563`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.5306282510621705, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.5877866649021191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6418538861723948, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {
           NCache[
            Log[4], 1.3862943611198906`], 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {
           NCache[
            Log[6], 1.791759469228055], 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.3978952727983707`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.4849066497880004`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.5649493574615367`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.6390573296152584`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.772588722239781, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.833213344056216, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.8903717578961645`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.9444389791664403`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {
           NCache[
            Log[40], 3.6888794541139363`], 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {
           NCache[
            Log[60], 4.0943445622221], 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->
       NCache[{{
         0., 2.302585092994046, 1.6094379124341003`, 3.912023005428146, 
          0.6931471805599453, 2.995732273553991, 1.0986122886681098`, 
          3.4011973816621555`, 0.4054651081081644, 2.70805020110221, 
          1.9459101490553132`, 4.248495242049359, 0.09531017980432493, 
          0.1823215567939548, 0.26236426446749106`, 0.336472236621213, 
          0.47000362924573563`, 0.5306282510621705, 0.5877866649021191, 
          0.6418538861723948, 
          Log[4], 
          Log[6], 2.0794415416798357`, 2.1972245773362196`, 
          2.3978952727983707`, 2.4849066497880004`, 2.5649493574615367`, 
          2.6390573296152584`, 2.772588722239781, 2.833213344056216, 
          2.8903717578961645`, 2.9444389791664403`, 
          Log[40], 
          Log[60]}, Automatic}, {{0., 2.302585092994046, 1.6094379124341003`, 
         3.912023005428146, 0.6931471805599453, 2.995732273553991, 
         1.0986122886681098`, 3.4011973816621555`, 0.4054651081081644, 
         2.70805020110221, 1.9459101490553132`, 4.248495242049359, 
         0.09531017980432493, 0.1823215567939548, 0.26236426446749106`, 
         0.336472236621213, 0.47000362924573563`, 0.5306282510621705, 
         0.5877866649021191, 0.6418538861723948, 1.3862943611198906`, 
         1.791759469228055, 2.0794415416798357`, 2.1972245773362196`, 
         2.3978952727983707`, 2.4849066497880004`, 2.5649493574615367`, 
         2.6390573296152584`, 2.772588722239781, 2.833213344056216, 
         2.8903717578961645`, 2.9444389791664403`, 3.6888794541139363`, 
         4.0943445622221}, Automatic}],
      Method->{},
      PlotLabel->FormBox["\"Phase\"", TraditionalForm],
      PlotRange->{{0., 
       6.907755231990604}, {-67.80839337552966, -8.6923386869193}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{0., 
          FormBox[
           TagBox[
            InterpretationBox["\"1.0\"", 1., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {2.302585092994046, 
          FormBox[
           TagBox[
            InterpretationBox["\"10.0\"", 10., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {1.6094379124341003`, 
          FormBox[
           TagBox[
            InterpretationBox["\"5.0\"", 5., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {3.912023005428146, 
          FormBox[
           TagBox[
            InterpretationBox["\"50.0\"", 50., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {0.6931471805599453, 
          FormBox[
           TagBox[
            InterpretationBox["\"2.0\"", 2., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {2.995732273553991, 
          FormBox[
           TagBox[
            InterpretationBox["\"20.0\"", 20., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {1.0986122886681098`, 
          FormBox[
           TagBox[
            InterpretationBox["\"3.0\"", 3., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {3.4011973816621555`, 
          FormBox[
           TagBox[
            InterpretationBox["\"30.0\"", 30., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {0.4054651081081644, 
          FormBox[
           TagBox[
            InterpretationBox["\"1.5\"", 1.5, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {2.70805020110221, 
          FormBox[
           TagBox[
            InterpretationBox["\"15.0\"", 15., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {1.9459101490553132`, 
          FormBox[
           TagBox[
            InterpretationBox["\"7.0\"", 7., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {4.248495242049359, 
          FormBox[
           TagBox[
            InterpretationBox["\"70.0\"", 70., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {0.09531017980432493, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.1823215567939548, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.26236426446749106`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.336472236621213, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.47000362924573563`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.5306282510621705, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.5877866649021191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.6418538861723948, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {
          NCache[
           Log[4], 1.3862943611198906`], 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {
          NCache[
           Log[6], 1.791759469228055], 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.3978952727983707`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.4849066497880004`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.5649493574615367`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.6390573296152584`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.772588722239781, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.833213344056216, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.8903717578961645`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.9444389791664403`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {
          NCache[
           Log[40], 3.6888794541139363`], 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {
          NCache[
           Log[60], 4.0943445622221], 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic}], {189., -355.98757751993935`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {}},
  ContentSelectable->True,
  ImageSize->{420.80000000000007`, Automatic},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.4475247451456614`*^9, 3.4480255260733747`*^9, 3.4481969072981253`*^9, 
   3.4483096877825003`*^9, 3.4483098005325003`*^9, 3.4483098647668753`*^9, 
   3.4483099251575003`*^9, 3.4483102380168753`*^9, 3.4483102719856253`*^9, 
   3.4483108292356253`*^9, 3.4483121612043753`*^9, 3.4483126413450003`*^9, 
   3.448375332859375*^9, 3.448375449234375*^9, {3.44837992646875*^9, 
   3.448379937515625*^9}, 3.448380189703125*^9, 3.448398809953125*^9, 
   3.448398868265625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"vout", "/.", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"v1", "-", "vref"}], "R1"], "+", 
       FractionBox[
        RowBox[{"vadj", "-", "vref"}], "R3"], "+", 
       FractionBox[
        RowBox[{"vinj", "-", "vref"}], "R4"], "+", 
       FractionBox[
        RowBox[{"vout", "-", "vref"}], "R2"]}], "\[Equal]", "0"}], ",", 
     "vout"}], "]"}], "\[LeftDoubleBracket]", "1", 
   "\[RightDoubleBracket]"}]}], "\[IndentingNewLine]", 
 RowBox[{"%", "//", "Expand"}], "\[IndentingNewLine]", 
 RowBox[{"%", "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"R1", "\[Rule]", "10*^3"}], ",", 
    RowBox[{"R2", "\[Rule]", "7.39*^3"}], ",", 
    RowBox[{"R3", "\[Rule]", "50*^3"}], ",", 
    RowBox[{"R4", "\[Rule]", "100*^3"}]}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.4481969200793753`*^9, 3.4481970420637503`*^9}, {
  3.4481975809856253`*^9, 3.4481976410168753`*^9}, {3.4481976785012503`*^9, 
  3.4481977123450003`*^9}, {3.4481977602356253`*^9, 3.4481977923606253`*^9}, {
  3.4481978241887503`*^9, 3.4481978260012503`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"R1", " ", "R3", " ", "R4"}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "R2"}], " ", "R3", " ", "R4", " ", "v1"}], "-", 
    RowBox[{"R1", " ", "R2", " ", "R4", " ", "vadj"}], "-", 
    RowBox[{"R1", " ", "R2", " ", "R3", " ", "vinj"}], "+", 
    RowBox[{"R1", " ", "R2", " ", "R3", " ", "vref"}], "+", 
    RowBox[{"R1", " ", "R2", " ", "R4", " ", "vref"}], "+", 
    RowBox[{"R1", " ", "R3", " ", "R4", " ", "vref"}], "+", 
    RowBox[{"R2", " ", "R3", " ", "R4", " ", "vref"}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.4481970021887503`*^9, 3.4481970423606253`*^9}, {
   3.4481976193293753`*^9, 3.4481976416575003`*^9}, {3.4481976791106253`*^9, 
   3.4481977128606253`*^9}, {3.4481977605168753`*^9, 3.4481977925637503`*^9}, 
   3.4481978266418753`*^9, 3.4483096879387503`*^9, 3.4483098006887503`*^9, 
   3.4483098649543753`*^9, 3.4483099253606253`*^9, 3.4483102381575003`*^9, 
   3.4483102721262503`*^9, 3.4483108294231253`*^9, 3.4483121613762503`*^9, 
   3.4483126415325003`*^9, 3.4483753329375*^9, 3.44837544928125*^9, {
   3.4483799265625*^9, 3.448379937609375*^9}, 3.448398810046875*^9, 
   3.44839886834375*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"R2", " ", "v1"}], "R1"]}], "-", 
  FractionBox[
   RowBox[{"R2", " ", "vadj"}], "R3"], "-", 
  FractionBox[
   RowBox[{"R2", " ", "vinj"}], "R4"], "+", "vref", "+", 
  FractionBox[
   RowBox[{"R2", " ", "vref"}], "R1"], "+", 
  FractionBox[
   RowBox[{"R2", " ", "vref"}], "R3"], "+", 
  FractionBox[
   RowBox[{"R2", " ", "vref"}], "R4"]}]], "Output",
 CellChangeTimes->{{3.4481970021887503`*^9, 3.4481970423606253`*^9}, {
   3.4481976193293753`*^9, 3.4481976416575003`*^9}, {3.4481976791106253`*^9, 
   3.4481977128606253`*^9}, {3.4481977605168753`*^9, 3.4481977925637503`*^9}, 
   3.4481978266418753`*^9, 3.4483096879387503`*^9, 3.4483098006887503`*^9, 
   3.4483098649543753`*^9, 3.4483099253606253`*^9, 3.4483102381575003`*^9, 
   3.4483102721262503`*^9, 3.4483108294231253`*^9, 3.4483121613762503`*^9, 
   3.4483126415325003`*^9, 3.4483753329375*^9, 3.44837544928125*^9, {
   3.4483799265625*^9, 3.448379937609375*^9}, 3.448398810046875*^9, 
   3.448398868359375*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "0.739`"}], " ", "v1"}], "-", 
  RowBox[{"0.14780000000000001`", " ", "vadj"}], "-", 
  RowBox[{"0.07390000000000001`", " ", "vinj"}], "+", 
  RowBox[{"1.9607`", " ", "vref"}]}]], "Output",
 CellChangeTimes->{{3.4481970021887503`*^9, 3.4481970423606253`*^9}, {
   3.4481976193293753`*^9, 3.4481976416575003`*^9}, {3.4481976791106253`*^9, 
   3.4481977128606253`*^9}, {3.4481977605168753`*^9, 3.4481977925637503`*^9}, 
   3.4481978266418753`*^9, 3.4483096879387503`*^9, 3.4483098006887503`*^9, 
   3.4483098649543753`*^9, 3.4483099253606253`*^9, 3.4483102381575003`*^9, 
   3.4483102721262503`*^9, 3.4483108294231253`*^9, 3.4483121613762503`*^9, 
   3.4483126415325003`*^9, 3.4483753329375*^9, 3.44837544928125*^9, {
   3.4483799265625*^9, 3.448379937609375*^9}, 3.448398810046875*^9, 
   3.448398868359375*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"vout", "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox[
         RowBox[{"vout", "-", "vin"}], "R1"], "+", 
        FractionBox[
         RowBox[{"vref", "-", "vin"}], "Z2"]}], "\[Equal]", "0"}], ",", 
      "vout"}], "]"}], "\[LeftDoubleBracket]", "1", 
    "\[RightDoubleBracket]"}]}], "//", "Expand"}]], "Input",
 CellChangeTimes->{{3.4482163100793753`*^9, 3.4482163838606253`*^9}}],

Cell[BoxData[
 RowBox[{"vin", "+", 
  FractionBox[
   RowBox[{"R1", " ", "vin"}], "Z2"], "-", 
  FractionBox[
   RowBox[{"R1", " ", "vref"}], "Z2"]}]], "Output",
 CellChangeTimes->{{3.4482163354075003`*^9, 3.4482163453293753`*^9}, {
   3.4482163785950003`*^9, 3.4482163840168753`*^9}, 3.4483096879856253`*^9, 
   3.4483098007200003`*^9, 3.4483098650637503`*^9, 3.4483099254075003`*^9, 
   3.4483102382043753`*^9, 3.4483102722200003`*^9, 3.4483108294543753`*^9, 
   3.4483121615325003`*^9, 3.4483126415637503`*^9, 3.448375333015625*^9, 
   3.4483754493125*^9, {3.44837992659375*^9, 3.448379937640625*^9}, 
   3.44839881009375*^9, 3.448398868390625*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{864, 1070},
WindowMargins->{{220, Automatic}, {0, Automatic}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
ShowSelection->True,
Magnification->1.25,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 110, 1, 103, "Title"],
Cell[703, 26, 222, 8, 108, "Subsubtitle"],
Cell[CellGroupData[{
Cell[950, 38, 40, 0, 62, "Subtitle"],
Cell[993, 40, 496, 10, 97, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1526, 55, 34, 0, 62, "Subtitle"],
Cell[1563, 57, 191, 6, 55, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1791, 68, 25, 0, 62, "Subtitle"],
Cell[1819, 70, 579, 10, 80, "Input"],
Cell[2401, 82, 222, 6, 35, "Input"],
Cell[2626, 90, 1066, 29, 102, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3729, 124, 104, 1, 62, "Subtitle"],
Cell[3836, 127, 356, 8, 37, "Input"],
Cell[4195, 137, 193, 4, 35, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4425, 146, 88, 1, 62, "Subtitle"],
Cell[4516, 149, 2016, 30, 325, "Text"],
Cell[CellGroupData[{
Cell[6557, 183, 200, 3, 35, "Subsubtitle"],
Cell[6760, 188, 199, 5, 76, "Text"],
Cell[CellGroupData[{
Cell[6984, 197, 1257, 33, 266, "Input"],
Cell[8244, 232, 587, 10, 35, "Output"],
Cell[8834, 244, 607, 11, 35, "Output"],
Cell[9444, 257, 611, 11, 35, "Output"],
Cell[10058, 270, 614, 11, 35, "Output"],
Cell[10675, 283, 638, 12, 35, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[11362, 301, 160, 2, 35, "Subsubtitle"],
Cell[11525, 305, 965, 23, 91, "Input"],
Cell[CellGroupData[{
Cell[12515, 332, 1349, 31, 124, "Input"],
Cell[13867, 365, 33024, 593, 354, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[46940, 964, 164, 2, 35, "Subsubtitle"],
Cell[CellGroupData[{
Cell[47129, 970, 747, 21, 35, "Input"],
Cell[47879, 993, 878, 23, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48794, 1021, 746, 15, 39, "Input"],
Cell[49543, 1038, 821, 16, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[50401, 1059, 1576, 39, 102, "Input"],
Cell[51980, 1100, 2953, 53, 299, "Output"]
}, Open  ]],
Cell[54948, 1156, 899, 22, 91, "Input"],
Cell[CellGroupData[{
Cell[55872, 1182, 1361, 31, 124, "Input"],
Cell[57236, 1215, 32657, 598, 354, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[89942, 1819, 199, 3, 35, "Subsubtitle"],
Cell[90144, 1824, 1415, 38, 170, "Input"],
Cell[CellGroupData[{
Cell[91584, 1866, 1377, 31, 124, "Input"],
Cell[92964, 1899, 34740, 632, 354, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[127753, 2537, 225, 3, 35, "Subsubtitle"],
Cell[127981, 2542, 1456, 39, 170, "Input"],
Cell[CellGroupData[{
Cell[129462, 2585, 1444, 33, 124, "Input"],
Cell[130909, 2620, 26029, 478, 354, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[156987, 3104, 268, 3, 35, "Subsubtitle"],
Cell[157258, 3109, 2223, 54, 201, "Input"],
Cell[159484, 3165, 1519, 31, 91, "Input"],
Cell[CellGroupData[{
Cell[161028, 3200, 1434, 33, 102, "Input"],
Cell[162465, 3235, 29338, 534, 354, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[191852, 3775, 325, 4, 35, "Subsubtitle"],
Cell[CellGroupData[{
Cell[192202, 3783, 843, 22, 35, "Input"],
Cell[193048, 3807, 943, 24, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[194028, 3836, 798, 16, 39, "Input"],
Cell[194829, 3854, 891, 16, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[195757, 3875, 1576, 39, 102, "Input"],
Cell[197336, 3916, 3020, 54, 299, "Output"]
}, Open  ]],
Cell[200371, 3973, 946, 22, 91, "Input"],
Cell[CellGroupData[{
Cell[201342, 3999, 1416, 32, 124, "Input"],
Cell[202761, 4033, 29345, 533, 354, "Output"]
}, Open  ]],
Cell[232121, 4569, 1465, 36, 113, "Input"],
Cell[CellGroupData[{
Cell[233611, 4609, 1480, 33, 102, "Input"],
Cell[235094, 4644, 29539, 536, 354, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[264682, 5186, 348, 5, 35, "Subsubtitle"],
Cell[265033, 5193, 2010, 48, 135, "Input"],
Cell[267046, 5243, 1588, 39, 135, "Input"],
Cell[CellGroupData[{
Cell[268659, 5286, 1525, 34, 102, "Input"],
Cell[270187, 5322, 29502, 536, 354, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[299738, 5864, 436, 7, 35, "Subsubtitle"],
Cell[300177, 5873, 2051, 49, 157, "Input"],
Cell[302231, 5924, 1677, 40, 135, "Input"],
Cell[CellGroupData[{
Cell[303933, 5968, 1580, 35, 124, "Input"],
Cell[305516, 6005, 29802, 541, 354, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[335367, 6552, 460, 6, 35, "Subsubtitle"],
Cell[335830, 6560, 1781, 37, 113, "Input"],
Cell[CellGroupData[{
Cell[337636, 6601, 1738, 38, 124, "Input"],
Cell[339377, 6641, 30258, 549, 354, "Output"]
}, Open  ]],
Cell[369650, 7193, 395, 6, 35, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[370082, 7204, 471, 7, 35, "Subsubtitle"],
Cell[CellGroupData[{
Cell[370578, 7215, 6472, 151, 410, "Input"],
Cell[377053, 7368, 48943, 852, 445, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[426033, 8225, 7605, 175, 513, "Input"],
Cell[433641, 8402, 74922, 1330, 427, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[508612, 9738, 516, 7, 35, "Subsubtitle"],
Cell[CellGroupData[{
Cell[509153, 9749, 715, 21, 80, "Input"],
Cell[509871, 9772, 1449, 36, 134, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[511381, 9815, 154, 2, 62, "Subtitle"],
Cell[511538, 9819, 206, 3, 35, "Subsubtitle"],
Cell[CellGroupData[{
Cell[511769, 9826, 1334, 30, 131, "Input"],
Cell[513106, 9858, 59708, 1113, 349, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[572851, 10976, 263, 3, 35, "Subsubtitle"],
Cell[573117, 10981, 231, 6, 35, "Input"],
Cell[CellGroupData[{
Cell[573373, 10991, 1464, 33, 149, "Input"],
Cell[574840, 11026, 61691, 1137, 348, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[636592, 12170, 260, 3, 62, "Subtitle"],
Cell[636855, 12175, 52, 0, 35, "Subsubtitle"],
Cell[636910, 12177, 455, 13, 86, "Input"],
Cell[CellGroupData[{
Cell[637390, 12194, 121, 5, 35, "Subsubtitle"],
Cell[637514, 12201, 330, 7, 97, "Text"],
Cell[637847, 12210, 402, 12, 73, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[638286, 12227, 40, 0, 35, "Subsubtitle"],
Cell[638329, 12229, 379, 9, 138, "Text"],
Cell[638711, 12240, 2738, 84, 216, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[641486, 12329, 39, 0, 35, "Subsubtitle"],
Cell[641528, 12331, 96, 2, 34, "Text"],
Cell[CellGroupData[{
Cell[641649, 12337, 892, 23, 111, "Input"],
Cell[642544, 12362, 15927, 331, 329, "Output"]
}, Open  ]],
Cell[658486, 12696, 92, 2, 34, "Text"],
Cell[CellGroupData[{
Cell[658603, 12702, 893, 23, 111, "Input"],
Cell[659499, 12727, 15901, 332, 329, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[675449, 13065, 47, 0, 35, "Subsubtitle"],
Cell[675499, 13067, 92, 2, 34, "Text"],
Cell[675594, 13071, 254, 8, 35, "Input"],
Cell[675851, 13081, 97, 2, 34, "Text"],
Cell[675951, 13085, 883, 28, 88, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[676871, 13118, 36, 0, 35, "Subsubtitle"],
Cell[676910, 13120, 40, 0, 34, "Text"],
Cell[676953, 13122, 986, 30, 58, "Input"],
Cell[677942, 13154, 31, 0, 34, "Text"],
Cell[677976, 13156, 1550, 43, 172, "Input"],
Cell[679529, 13201, 39, 0, 34, "Text"],
Cell[679571, 13203, 3238, 84, 291, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[682846, 13292, 313, 4, 35, "Subsubtitle"],
Cell[683162, 13298, 121, 2, 34, "Text"],
Cell[683286, 13302, 1018, 29, 124, "Input"],
Cell[684307, 13333, 121, 2, 34, "Text"],
Cell[684431, 13337, 1018, 29, 124, "Input"],
Cell[685452, 13368, 149, 2, 34, "Text"],
Cell[685604, 13372, 1766, 46, 189, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[687407, 13423, 359, 5, 35, "Subsubtitle"],
Cell[687769, 13430, 4205, 105, 336, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[692011, 13540, 354, 5, 35, "Subsubtitle"],
Cell[692368, 13547, 1548, 40, 141, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[693953, 13592, 403, 5, 35, "Subsubtitle"],
Cell[694359, 13599, 1521, 38, 170, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[695917, 13642, 459, 6, 35, "Subsubtitle"],
Cell[696379, 13650, 1657, 41, 181, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[698073, 13696, 502, 7, 35, "Subsubtitle"],
Cell[698578, 13705, 711, 19, 80, "Input"],
Cell[CellGroupData[{
Cell[699314, 13728, 1317, 35, 80, "Input"],
Cell[700634, 13765, 2665, 58, 187, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[703336, 13828, 1686, 43, 133, "Input"],
Cell[705025, 13873, 1864, 36, 175, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[706926, 13914, 1770, 40, 153, "Input"],
Cell[708699, 13956, 63535, 1174, 349, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[772283, 15136, 575, 7, 35, "Subsubtitle"],
Cell[CellGroupData[{
Cell[772883, 15147, 5210, 129, 405, "Input"],
Cell[778098, 15279, 82844, 1459, 420, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[860991, 16744, 608, 8, 35, "Subsubtitle"],
Cell[861602, 16754, 2193, 46, 124, "Input"],
Cell[863798, 16802, 2481, 55, 141, "Input"],
Cell[CellGroupData[{
Cell[866304, 16861, 434, 13, 35, "Input"],
Cell[866741, 16876, 693, 11, 35, "Output"]
}, Open  ]],
Cell[867449, 16890, 817, 20, 80, "Input"],
Cell[CellGroupData[{
Cell[868291, 16914, 109, 1, 46, "Subsection"],
Cell[CellGroupData[{
Cell[868425, 16919, 1596, 41, 119, "Input"],
Cell[870024, 16962, 2008, 40, 187, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[872069, 17007, 2447, 60, 210, "Input"],
Cell[874519, 17069, 1958, 37, 175, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[876526, 17112, 116, 1, 46, "Subsection"],
Cell[CellGroupData[{
Cell[876667, 17117, 1420, 36, 80, "Input"],
Cell[878090, 17155, 2908, 59, 187, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[881035, 17219, 1907, 48, 133, "Input"],
Cell[882945, 17269, 2607, 46, 175, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[885613, 17322, 397, 5, 35, "Subsubtitle"],
Cell[CellGroupData[{
Cell[886035, 17331, 828, 22, 63, "Input"],
Cell[886866, 17355, 1268, 26, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[888171, 17386, 244, 6, 35, "Input"],
Cell[888418, 17394, 701, 13, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[889156, 17412, 258, 6, 35, "Input"],
Cell[889417, 17420, 939, 20, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[890393, 17445, 1171, 32, 102, "Input"],
Cell[891567, 17479, 877, 14, 35, "Output"],
Cell[892447, 17495, 1385, 32, 54, "Output"],
Cell[893835, 17529, 952, 17, 35, "Output"],
Cell[894790, 17548, 779, 10, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[895606, 17563, 787, 23, 51, "Input"],
Cell[896396, 17588, 905, 18, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[897338, 17611, 244, 6, 35, "Input"],
Cell[897585, 17619, 637, 11, 51, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[898259, 17635, 258, 6, 35, "Input"],
Cell[898520, 17643, 861, 15, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[899418, 17663, 1788, 43, 124, "Input"],
Cell[901209, 17708, 920, 17, 51, "Output"],
Cell[902132, 17727, 809, 15, 52, "Output"],
Cell[902944, 17744, 757, 12, 35, "Output"],
Cell[903704, 17758, 679, 9, 35, "Output"],
Cell[904386, 17769, 680, 9, 35, "Output"]
}, Open  ]],
Cell[905081, 17781, 718, 21, 73, "Input"],
Cell[CellGroupData[{
Cell[905824, 17806, 241, 6, 35, "Input"],
Cell[906068, 17814, 49840, 965, 638, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[955945, 18784, 1119, 28, 96, "Input"],
Cell[957067, 18814, 1196, 22, 75, "Output"],
Cell[958266, 18838, 1042, 23, 52, "Output"],
Cell[959311, 18863, 861, 15, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[960209, 18883, 483, 14, 51, "Input"],
Cell[960695, 18899, 651, 12, 52, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
